Class: SyntaxTree::Binary

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Binary represents any expression that involves two sub-expressions with an operator in between. This can be something that looks like a mathematical operation:

1 + 1

but can also be something like pushing a value onto an array:

array << value

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(left:, operator:, right:, location:) ⇒ Binary



2029
2030
2031
2032
2033
2034
2035
# File 'lib/syntax_tree/node.rb', line 2029

def initialize(left:, operator:, right:, location:)
  @left = left
  @operator = operator
  @right = right
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



2027
2028
2029
# File 'lib/syntax_tree/node.rb', line 2027

def comments
  @comments
end

#leftObject (readonly)

Node

the left-hand side of the expression



2018
2019
2020
# File 'lib/syntax_tree/node.rb', line 2018

def left
  @left
end

#operatorObject (readonly)

Symbol

the operator used between the two expressions



2021
2022
2023
# File 'lib/syntax_tree/node.rb', line 2021

def operator
  @operator
end

#rightObject (readonly)

Node

the right-hand side of the expression



2024
2025
2026
# File 'lib/syntax_tree/node.rb', line 2024

def right
  @right
end

Instance Method Details

#===(other) ⇒ Object



2092
2093
2094
2095
# File 'lib/syntax_tree/node.rb', line 2092

def ===(other)
  other.is_a?(Binary) && left === other.left &&
    operator === other.operator && right === other.right
end

#accept(visitor) ⇒ Object



2037
2038
2039
# File 'lib/syntax_tree/node.rb', line 2037

def accept(visitor)
  visitor.visit_binary(self)
end

#child_nodesObject Also known as: deconstruct



2041
2042
2043
# File 'lib/syntax_tree/node.rb', line 2041

def child_nodes
  [left, right]
end

#copy(left: nil, operator: nil, right: nil, location: nil) ⇒ Object



2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/syntax_tree/node.rb', line 2045

def copy(left: nil, operator: nil, right: nil, location: nil)
  node =
    Binary.new(
      left: left || self.left,
      operator: operator || self.operator,
      right: right || self.right,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



2060
2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/syntax_tree/node.rb', line 2060

def deconstruct_keys(_keys)
  {
    left: left,
    operator: operator,
    right: right,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
# File 'lib/syntax_tree/node.rb', line 2070

def format(q)
  power = operator == :**

  q.group do
    q.group { q.format(left) }
    q.text(" ") unless power

    if operator == :<<
      q.text("<< ")
      q.format(right)
    else
      q.group do
        q.text(operator.name)
        q.indent do
          power ? q.breakable_empty : q.breakable_space
          q.format(right)
        end
      end
    end
  end
end