Class: SyntaxTree::CallNode

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

CallNode represents a method call.

receiver.message

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(receiver:, operator:, message:, arguments:, location:) ⇒ CallNode

Returns a new instance of CallNode.



2919
2920
2921
2922
2923
2924
2925
2926
# File 'lib/syntax_tree/node.rb', line 2919

def initialize(receiver:, operator:, message:, arguments:, location:)
  @receiver = receiver
  @operator = operator
  @message = message
  @arguments = arguments
  @location = location
  @comments = []
end

Instance Attribute Details

#argumentsObject (readonly)

nil | ArgParen | Args

the arguments to the method call



2914
2915
2916
# File 'lib/syntax_tree/node.rb', line 2914

def arguments
  @arguments
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



2917
2918
2919
# File 'lib/syntax_tree/node.rb', line 2917

def comments
  @comments
end

#messageObject (readonly)

:call | Backtick | Const | Ident | Op

the message being sent



2911
2912
2913
# File 'lib/syntax_tree/node.rb', line 2911

def message
  @message
end

#operatorObject (readonly)

nil | :“::” | Op | Period

the operator being used to send the message



2908
2909
2910
# File 'lib/syntax_tree/node.rb', line 2908

def operator
  @operator
end

#receiverObject (readonly)

nil | Node

the receiver of the method call



2905
2906
2907
# File 'lib/syntax_tree/node.rb', line 2905

def receiver
  @receiver
end

Instance Method Details

#===(other) ⇒ Object



3014
3015
3016
3017
3018
# File 'lib/syntax_tree/node.rb', line 3014

def ===(other)
  other.is_a?(CallNode) && receiver === other.receiver &&
    operator === other.operator && message === other.message &&
    arguments === other.arguments
end

#accept(visitor) ⇒ Object



2928
2929
2930
# File 'lib/syntax_tree/node.rb', line 2928

def accept(visitor)
  visitor.visit_call(self)
end

#arityObject



3060
3061
3062
# File 'lib/syntax_tree/node.rb', line 3060

def arity
  arguments&.arity || 0
end

#child_nodesObject Also known as: deconstruct



2932
2933
2934
2935
2936
2937
2938
2939
# File 'lib/syntax_tree/node.rb', line 2932

def child_nodes
  [
    receiver,
    (operator if operator != :"::"),
    (message if message != :call),
    arguments
  ]
end

#copy(receiver: nil, operator: nil, message: nil, arguments: nil, location: nil) ⇒ Object



2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
# File 'lib/syntax_tree/node.rb', line 2941

def copy(
  receiver: nil,
  operator: nil,
  message: nil,
  arguments: nil,
  location: nil
)
  node =
    CallNode.new(
      receiver: receiver || self.receiver,
      operator: operator || self.operator,
      message: message || self.message,
      arguments: arguments || self.arguments,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
# File 'lib/syntax_tree/node.rb', line 2963

def deconstruct_keys(_keys)
  {
    receiver: receiver,
    operator: operator,
    message: message,
    arguments: arguments,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/syntax_tree/node.rb', line 2974

def format(q)
  if receiver
    # If we're at the top of a call chain, then we're going to do some
    # specialized printing in case we can print it nicely. We _only_ do this
    # at the top of the chain to avoid weird recursion issues.
    if CallChainFormatter.chained?(receiver) &&
         !CallChainFormatter.chained?(q.parent)
      q.group do
        q
          .if_break { CallChainFormatter.new(self).format(q) }
          .if_flat { format_contents(q) }
      end
    else
      format_contents(q)
    end
  else
    q.format(message)

    # Note that this explicitly leaves parentheses in place even if they are
    # empty. There are two reasons we would need to do this. The first is if
    # we're calling something that looks like a constant, as in:
    #
    #     Foo()
    #
    # In this case if we remove the parentheses then this becomes a constant
    # reference and not a method call. The second is if we're calling a
    # method that is the same name as a local variable that is in scope, as
    # in:
    #
    #     foo = foo()
    #
    # In this case we have to keep the parentheses or else it treats this
    # like assigning nil to the local variable. Note that we could attempt
    # to be smarter about this by tracking the local variables that are in
    # scope, but for now it's simpler and more efficient to just leave the
    # parentheses in place.
    q.format(arguments) if arguments
  end
end

#format_arguments(q) ⇒ Object

Print out the arguments to this call. If there are no arguments, then do nothing.



3022
3023
3024
3025
3026
3027
3028
3029
3030
# File 'lib/syntax_tree/node.rb', line 3022

def format_arguments(q)
  case arguments
  when ArgParen
    q.format(arguments)
  when Args
    q.text(" ")
    q.format(arguments)
  end
end

#format_contents(q) ⇒ Object



3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
# File 'lib/syntax_tree/node.rb', line 3032

def format_contents(q)
  call_operator = CallOperatorFormatter.new(operator)

  q.group do
    q.format(receiver)

    # If there are trailing comments on the call operator, then we need to
    # use the trailing form as opposed to the leading form.
    q.format(call_operator) if call_operator.comments.any?

    q.group do
      q.indent do
        if receiver.comments.any? || call_operator.comments.any?
          q.breakable_force
        end

        if call_operator.comments.empty?
          q.format(call_operator, stackable: false)
        end

        q.format(message) if message != :call
      end

      format_arguments(q)
    end
  end
end