Class: SyntaxTree::ClassDeclaration
- Defined in:
- lib/syntax_tree/node.rb
Overview
Class represents defining a class using the class keyword.
class Container
end
Classes can have path names as their class name in case it’s being nested under a namespace, as in:
class Namespace::Container
end
Classes can also be defined as a top-level path, in the case that it’s already in a namespace but you want to define it at the top-level instead, as in:
module OtherNamespace
class ::Namespace::Container
end
end
All of these declarations can also have an optional superclass reference, as in:
class Child < Parent
end
That superclass can actually be any Ruby expression, it doesn’t necessarily need to be a constant, as in:
class Child < method
end
Instance Attribute Summary collapse
-
#bodystmt ⇒ Object
readonly
- BodyStmt
-
the expressions to execute within the context of the class.
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#constant ⇒ Object
readonly
- ConstPathRef | ConstRef | TopConstRef
-
the name of the class being defined.
-
#superclass ⇒ Object
readonly
- nil | Node
-
the optional superclass declaration.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(constant: nil, superclass: nil, bodystmt: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(constant:, superclass:, bodystmt:, location:) ⇒ ClassDeclaration
constructor
A new instance of ClassDeclaration.
Methods inherited from Node
#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(constant:, superclass:, bodystmt:, location:) ⇒ ClassDeclaration
Returns a new instance of ClassDeclaration.
3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/syntax_tree/node.rb', line 3286 def initialize(constant:, superclass:, bodystmt:, location:) @constant = constant @superclass = superclass @bodystmt = bodystmt @location = location @comments = [] end |
Instance Attribute Details
#bodystmt ⇒ Object (readonly)
- BodyStmt
-
the expressions to execute within the context of the class
3281 3282 3283 |
# File 'lib/syntax_tree/node.rb', line 3281 def bodystmt @bodystmt end |
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
3284 3285 3286 |
# File 'lib/syntax_tree/node.rb', line 3284 def comments @comments end |
#constant ⇒ Object (readonly)
- ConstPathRef | ConstRef | TopConstRef
-
the name of the class being
defined
3275 3276 3277 |
# File 'lib/syntax_tree/node.rb', line 3275 def constant @constant end |
#superclass ⇒ Object (readonly)
- nil | Node
-
the optional superclass declaration
3278 3279 3280 |
# File 'lib/syntax_tree/node.rb', line 3278 def superclass @superclass end |
Instance Method Details
#===(other) ⇒ Object
3349 3350 3351 3352 |
# File 'lib/syntax_tree/node.rb', line 3349 def ===(other) other.is_a?(ClassDeclaration) && constant === other.constant && superclass === other.superclass && bodystmt === other.bodystmt end |
#accept(visitor) ⇒ Object
3294 3295 3296 |
# File 'lib/syntax_tree/node.rb', line 3294 def accept(visitor) visitor.visit_class(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
3298 3299 3300 |
# File 'lib/syntax_tree/node.rb', line 3298 def child_nodes [constant, superclass, bodystmt] end |
#copy(constant: nil, superclass: nil, bodystmt: nil, location: nil) ⇒ Object
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 |
# File 'lib/syntax_tree/node.rb', line 3302 def copy(constant: nil, superclass: nil, bodystmt: nil, location: nil) node = ClassDeclaration.new( constant: constant || self.constant, superclass: superclass || self.superclass, bodystmt: bodystmt || self.bodystmt, location: location || self.location ) node.comments.concat(comments.map(&:copy)) node end |
#deconstruct_keys(_keys) ⇒ Object
3317 3318 3319 3320 3321 3322 3323 3324 3325 |
# File 'lib/syntax_tree/node.rb', line 3317 def deconstruct_keys(_keys) { constant: constant, superclass: superclass, bodystmt: bodystmt, location: location, comments: comments } end |
#format(q) ⇒ Object
3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 |
# File 'lib/syntax_tree/node.rb', line 3327 def format(q) if bodystmt.empty? q.group do format_declaration(q) q.breakable_force q.text("end") end else q.group do format_declaration(q) q.indent do q.breakable_force q.format(bodystmt) end q.breakable_force q.text("end") end end end |