Class: SyntaxTree::CommandCall

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

CommandCall represents a method call on an object with arguments and no parentheses.

object.method argument

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(receiver:, operator:, message:, arguments:, block:, location:) ⇒ CommandCall

Returns a new instance of CommandCall.



3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/syntax_tree/node.rb', line 3539

def initialize(
  receiver:,
  operator:,
  message:,
  arguments:,
  block:,
  location:
)
  @receiver = receiver
  @operator = operator
  @message = message
  @arguments = arguments
  @block = block
  @location = location
  @comments = []
end

Instance Attribute Details

#argumentsObject (readonly)

nil | Args | ArgParen

the arguments going along with the message



3531
3532
3533
# File 'lib/syntax_tree/node.rb', line 3531

def arguments
  @arguments
end

#blockObject (readonly)

nil | BlockNode

the block associated with this method call



3534
3535
3536
# File 'lib/syntax_tree/node.rb', line 3534

def block
  @block
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



3537
3538
3539
# File 'lib/syntax_tree/node.rb', line 3537

def comments
  @comments
end

#messageObject (readonly)

:call | Const | Ident | Op

the message being send



3528
3529
3530
# File 'lib/syntax_tree/node.rb', line 3528

def message
  @message
end

#operatorObject (readonly)

nil | :“::” | Op | Period

the operator used to send the message



3525
3526
3527
# File 'lib/syntax_tree/node.rb', line 3525

def operator
  @operator
end

#receiverObject (readonly)

nil | Node

the receiver of the message



3522
3523
3524
# File 'lib/syntax_tree/node.rb', line 3522

def receiver
  @receiver
end

Instance Method Details

#===(other) ⇒ Object



3639
3640
3641
3642
3643
# File 'lib/syntax_tree/node.rb', line 3639

def ===(other)
  other.is_a?(CommandCall) && receiver === other.receiver &&
    operator === other.operator && message === other.message &&
    arguments === other.arguments && block === other.block
end

#accept(visitor) ⇒ Object



3556
3557
3558
# File 'lib/syntax_tree/node.rb', line 3556

def accept(visitor)
  visitor.visit_command_call(self)
end

#arityObject



3645
3646
3647
# File 'lib/syntax_tree/node.rb', line 3645

def arity
  arguments&.arity || 0
end

#child_nodesObject Also known as: deconstruct



3560
3561
3562
# File 'lib/syntax_tree/node.rb', line 3560

def child_nodes
  [receiver, message, arguments, block]
end

#copy(receiver: nil, operator: nil, message: nil, arguments: nil, block: nil, location: nil) ⇒ Object



3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
# File 'lib/syntax_tree/node.rb', line 3564

def copy(
  receiver: nil,
  operator: nil,
  message: nil,
  arguments: nil,
  block: nil,
  location: nil
)
  node =
    CommandCall.new(
      receiver: receiver || self.receiver,
      operator: operator || self.operator,
      message: message || self.message,
      arguments: arguments || self.arguments,
      block: block || self.block,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



3588
3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
# File 'lib/syntax_tree/node.rb', line 3588

def deconstruct_keys(_keys)
  {
    receiver: receiver,
    operator: operator,
    message: message,
    arguments: arguments,
    block: block,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
3634
3635
3636
3637
# File 'lib/syntax_tree/node.rb', line 3600

def format(q)
  q.group do
    doc =
      q.nest(0) do
        q.format(receiver)

        # If there are leading comments on the message then we know we have
        # a newline in the source that is forcing these things apart. In
        # this case we will have to use a trailing operator.
        if message.comments.any?(&:leading?)
          q.format(CallOperatorFormatter.new(operator), stackable: false)
          q.indent do
            q.breakable_empty
            q.format(message)
          end
        else
          q.format(CallOperatorFormatter.new(operator), stackable: false)
          q.format(message)
        end
      end

    # Format the arguments for this command call here. If there are no
    # arguments, then print nothing.
    if arguments
      parts = arguments.parts

      if parts.length == 1 && parts.first.is_a?(IfOp)
        q.if_flat { q.text(" ") }
        q.format(arguments)
      else
        q.text(" ")
        q.nest(argument_alignment(q, doc)) { q.format(arguments) }
      end
    end
  end

  q.format(block) if block
end