Class: SyntaxTree::Dot2
Overview
Dot2 represents using the .. operator between two expressions. Usually this is to create a range object.
1..2
Sometimes this operator is used to create a flip-flop.
if value == 5 .. value == 10
end
One of the sides of the expression may be nil, but not both.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#left ⇒ Object
readonly
[nil | untyped] the left side of the expression.
-
#right ⇒ Object
readonly
[nil | untyped] the right side of the expression.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(left:, right:, location:, comments: []) ⇒ Dot2
constructor
A new instance of Dot2.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(left:, right:, location:, comments: []) ⇒ Dot2
Returns a new instance of Dot2.
3782 3783 3784 3785 3786 3787 |
# File 'lib/syntax_tree/node.rb', line 3782 def initialize(left:, right:, location:, comments: []) @left = left @right = right @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
3780 3781 3782 |
# File 'lib/syntax_tree/node.rb', line 3780 def comments @comments end |
#left ⇒ Object (readonly)
[nil | untyped] the left side of the expression
3774 3775 3776 |
# File 'lib/syntax_tree/node.rb', line 3774 def left @left end |
#right ⇒ Object (readonly)
[nil | untyped] the right side of the expression
3777 3778 3779 |
# File 'lib/syntax_tree/node.rb', line 3777 def right @right end |
Instance Method Details
#accept(visitor) ⇒ Object
3789 3790 3791 |
# File 'lib/syntax_tree/node.rb', line 3789 def accept(visitor) visitor.visit_dot2(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
3793 3794 3795 |
# File 'lib/syntax_tree/node.rb', line 3793 def child_nodes [left, right] end |
#deconstruct_keys(_keys) ⇒ Object
3799 3800 3801 |
# File 'lib/syntax_tree/node.rb', line 3799 def deconstruct_keys(_keys) { left: left, right: right, location: location, comments: comments } end |
#format(q) ⇒ Object
3803 3804 3805 |
# File 'lib/syntax_tree/node.rb', line 3803 def format(q) DotFormatter.new("..", self).format(q) end |