Class: SyntaxTree::ENDBlock

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

ENDBlock represents the use of the END keyword, which hooks into the lifecycle of the interpreter. Whatever is inside the block will get executed when the program ends.

END {
}

Interestingly, the END keyword doesn’t allow the do and end keywords for the block. Only braces are permitted.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Constructor Details

#initialize(lbrace:, statements:, location:, comments: []) ⇒ ENDBlock

Returns a new instance of ENDBlock.



236
237
238
239
240
241
# File 'lib/syntax_tree/node.rb', line 236

def initialize(lbrace:, statements:, location:, comments: [])
  @lbrace = lbrace
  @statements = statements
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



234
235
236
# File 'lib/syntax_tree/node.rb', line 234

def comments
  @comments
end

#lbraceObject (readonly)

LBrace

the left brace that is seen after the keyword



228
229
230
# File 'lib/syntax_tree/node.rb', line 228

def lbrace
  @lbrace
end

#statementsObject (readonly)

Statements

the expressions to be executed



231
232
233
# File 'lib/syntax_tree/node.rb', line 231

def statements
  @statements
end

Instance Method Details

#child_nodesObject Also known as: deconstruct



243
244
245
# File 'lib/syntax_tree/node.rb', line 243

def child_nodes
  [lbrace, statements]
end

#deconstruct_keys(keys) ⇒ Object



249
250
251
252
253
254
255
256
# File 'lib/syntax_tree/node.rb', line 249

def deconstruct_keys(keys)
  {
    lbrace: lbrace,
    statements: statements,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/syntax_tree/node.rb', line 258

def format(q)
  q.group do
    q.text("END ")
    q.format(lbrace)
    q.indent do
      q.breakable
      q.format(statements)
    end
    q.breakable
    q.text("}")
  end
end

#pretty_print(q) ⇒ Object



271
272
273
274
275
276
277
278
279
280
# File 'lib/syntax_tree/node.rb', line 271

def pretty_print(q)
  q.group(2, "(", ")") do
    q.text("END")

    q.breakable
    q.pp(statements)

    q.pp(Comment::List.new(comments))
  end
end

#to_json(*opts) ⇒ Object



282
283
284
285
286
287
288
289
290
# File 'lib/syntax_tree/node.rb', line 282

def to_json(*opts)
  {
    type: :END,
    lbrace: lbrace,
    stmts: statements,
    loc: location,
    cmts: comments
  }.to_json(*opts)
end