Class: SyntaxTree::EmbExprEnd

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

EmbExprEnd represents the ending token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).

"Hello, #{person}!"

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ EmbExprEnd

Returns a new instance of EmbExprEnd.



4971
4972
4973
4974
# File 'lib/syntax_tree/node.rb', line 4971

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the } used in the string



4969
4970
4971
# File 'lib/syntax_tree/node.rb', line 4969

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



4997
4998
4999
# File 'lib/syntax_tree/node.rb', line 4997

def ===(other)
  other.is_a?(EmbExprEnd) && value === other.value
end

#accept(visitor) ⇒ Object



4976
4977
4978
# File 'lib/syntax_tree/node.rb', line 4976

def accept(visitor)
  visitor.visit_embexpr_end(self)
end

#child_nodesObject Also known as: deconstruct



4980
4981
4982
# File 'lib/syntax_tree/node.rb', line 4980

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



4984
4985
4986
4987
4988
4989
# File 'lib/syntax_tree/node.rb', line 4984

def copy(value: nil, location: nil)
  EmbExprEnd.new(
    value: value || self.value,
    location: location || self.location
  )
end

#deconstruct_keys(_keys) ⇒ Object



4993
4994
4995
# File 'lib/syntax_tree/node.rb', line 4993

def deconstruct_keys(_keys)
  { value: value, location: location }
end