Class: SyntaxTree::ExcessedComma

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

ExcessedComma represents a trailing comma in a list of block parameters. It changes the block parameters such that they will destructure.

[[1, 2, 3], [2, 3, 4]].each do |first, second,|
end

In the above example, an ExcessedComma node would appear in the third position of the Params node that is used to declare that block. The third position typically represents a rest-type parameter, but in this case is used to indicate that a trailing comma was used.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(value:, location:) ⇒ ExcessedComma

Returns a new instance of ExcessedComma.



5194
5195
5196
5197
5198
# File 'lib/syntax_tree/node.rb', line 5194

def initialize(value:, location:)
  @value = value
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



5192
5193
5194
# File 'lib/syntax_tree/node.rb', line 5192

def comments
  @comments
end

#valueObject (readonly)

String

the comma



5189
5190
5191
# File 'lib/syntax_tree/node.rb', line 5189

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



5229
5230
5231
# File 'lib/syntax_tree/node.rb', line 5229

def ===(other)
  other.is_a?(ExcessedComma) && value === other.value
end

#accept(visitor) ⇒ Object



5200
5201
5202
# File 'lib/syntax_tree/node.rb', line 5200

def accept(visitor)
  visitor.visit_excessed_comma(self)
end

#child_nodesObject Also known as: deconstruct



5204
5205
5206
# File 'lib/syntax_tree/node.rb', line 5204

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
# File 'lib/syntax_tree/node.rb', line 5208

def copy(value: nil, location: nil)
  node =
    ExcessedComma.new(
      value: value || self.value,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



5221
5222
5223
# File 'lib/syntax_tree/node.rb', line 5221

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



5225
5226
5227
# File 'lib/syntax_tree/node.rb', line 5225

def format(q)
  q.text(value)
end