Class: SyntaxTree::FCall

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

FCall represents the piece of a method call that comes before any arguments (i.e., just the name of the method). It is used in places where the parser is sure that it is a method call and not potentially a local variable.

method(argument)

In the above example, it's referring to the method segment.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, arguments:, location:, comments: []) ⇒ FCall

Returns a new instance of FCall.



4388
4389
4390
4391
4392
4393
# File 'lib/syntax_tree/node.rb', line 4388

def initialize(value:, arguments:, location:, comments: [])
  @value = value
  @arguments = arguments
  @location = location
  @comments = comments
end

Instance Attribute Details

#arguments ⇒ Object (readonly)

[nil | ArgParen | Args] the arguments to the method call



4383
4384
4385
# File 'lib/syntax_tree/node.rb', line 4383

def arguments
  @arguments
end

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



4386
4387
4388
# File 'lib/syntax_tree/node.rb', line 4386

def comments
  @comments
end

#value ⇒ Object (readonly)

[Const | Ident] the name of the method



4380
4381
4382
# File 'lib/syntax_tree/node.rb', line 4380

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



4395
4396
4397
# File 'lib/syntax_tree/node.rb', line 4395

def accept(visitor)
  visitor.visit_fcall(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



4399
4400
4401
# File 'lib/syntax_tree/node.rb', line 4399

def child_nodes
  [value, arguments]
end

#deconstruct_keys(_keys) ⇒ Object



4405
4406
4407
4408
4409
4410
4411
4412
# File 'lib/syntax_tree/node.rb', line 4405

def deconstruct_keys(_keys)
  {
    value: value,
    arguments: arguments,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
# File 'lib/syntax_tree/node.rb', line 4414

def format(q)
  q.format(value)

  if arguments.is_a?(ArgParen) && arguments.arguments.nil? &&
       !value.is_a?(Const)
    # If you're using an explicit set of parentheses on something that looks
    # like a constant, then we need to match that in order to maintain valid
    # Ruby. For example, you could do something like Foo(), on which we
    # would need to keep the parentheses to make it look like a method call.
  else
    q.format(arguments)
  end
end