Module: SyntaxTree::HashKeyFormatter

Defined in:
lib/syntax_tree/node.rb

Overview

This module is responsible for formatting the assocs contained within a hash or bare hash. It first determines if every key in the hash can use labels. If it can, it uses labels. Otherwise it uses hash rockets.

Defined Under Namespace

Classes: Identity, Labels, Rockets

Class Method Summary collapse

Class Method Details

.for(container) ⇒ Object



1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
# File 'lib/syntax_tree/node.rb', line 1782

def self.for(container)
  labels =
    container.assocs.all? do |assoc|
      next true if assoc.is_a?(AssocSplat)

      case assoc.key
      when Label
        true
      when SymbolLiteral
        # When attempting to convert a hash rocket into a hash label,
        # you need to take care because only certain patterns are
        # allowed. Ruby source says that they have to match keyword
        # arguments to methods, but don't specify what that is. After
        # some experimentation, it looks like it's:
        value = assoc.key.value.value
        value.match?(/^[_A-Za-z]/) && !value.end_with?("=")
      when DynaSymbol
        true
      else
        false
      end
    end

  (labels ? Labels : Rockets).new
end