Class: SyntaxTree::Node

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

This is the parent node of all of the syntax tree nodes. It’s pretty much exclusively here to make it easier to operate with the tree in cases where you’re trying to monkey-patch or strictly type.

Direct Known Subclasses

ARef, ARefField, Alias, ArgBlock, ArgParen, ArgStar, Args, ArgsForward, ArrayLiteral, AryPtn, Assign, Assoc, AssocSplat, BEGINBlock, Backref, Backtick, BareAssocHash, Begin, Binary, BlockArg, BlockVar, BodyStmt, BraceBlock, Break, CHAR, CVar, Call, Case, ClassDeclaration, Comma, Command, CommandCall, Comment, Const, ConstPathField, ConstPathRef, ConstRef, Def, DefEndless, Defined, Defs, DoBlock, Dot2, Dot3, DynaSymbol, ENDBlock, Else, Elsif, EmbDoc, EmbExprBeg, EmbExprEnd, EmbVar, EndContent, Ensure, ExcessedComma, FCall, Field, FloatLiteral, FndPtn, For, GVar, HashLiteral, Heredoc, HeredocBeg, HshPtn, IVar, Ident, If, IfMod, IfOp, Imaginary, In, Int, Kw, KwRestParam, LBrace, LBracket, LParen, Label, LabelEnd, Lambda, MAssign, MLHS, MLHSParen, MRHS, MethodAddBlock, ModuleDeclaration, Next, Not, Op, OpAssign, Params, Paren, Period, PinnedBegin, PinnedVarRef, Program, QSymbols, QSymbolsBeg, QWords, QWordsBeg, RAssign, RBrace, RBracket, RParen, RationalLiteral, Redo, RegexpBeg, RegexpContent, RegexpEnd, RegexpLiteral, Rescue, RescueEx, RescueMod, RestParam, Retry, Return, Return0, SClass, Statements, StringConcat, StringContent, StringDVar, StringEmbExpr, StringLiteral, Super, SymBeg, SymbolContent, SymbolLiteral, Symbols, SymbolsBeg, TLamBeg, TLambda, TStringBeg, TStringContent, TStringEnd, TopConstField, TopConstRef, Unary, Undef, Unless, UnlessMod, Until, UntilMod, VCall, VarAlias, VarField, VarRef, VoidStmt, When, While, WhileMod, Word, Words, WordsBeg, XString, XStringLiteral, Yield, Yield0, ZSuper

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#locationObject (readonly)

Location

the location of this node



57
58
59
# File 'lib/syntax_tree/node.rb', line 57

def location
  @location
end

Instance Method Details

#child_nodesObject

Raises:

  • (NotImplementedError)


59
60
61
# File 'lib/syntax_tree/node.rb', line 59

def child_nodes
  raise NotImplementedError
end

#deconstructObject

Raises:

  • (NotImplementedError)


63
64
65
# File 'lib/syntax_tree/node.rb', line 63

def deconstruct
  raise NotImplementedError
end

#deconstruct_keys(keys) ⇒ Object

Raises:

  • (NotImplementedError)


67
68
69
# File 'lib/syntax_tree/node.rb', line 67

def deconstruct_keys(keys)
  raise NotImplementedError
end

#format(q) ⇒ Object

Raises:

  • (NotImplementedError)


71
72
73
# File 'lib/syntax_tree/node.rb', line 71

def format(q)
  raise NotImplementedError
end

#pretty_print(q) ⇒ Object

Raises:

  • (NotImplementedError)


75
76
77
# File 'lib/syntax_tree/node.rb', line 75

def pretty_print(q)
  raise NotImplementedError
end

#to_json(*opts) ⇒ Object

Raises:

  • (NotImplementedError)


79
80
81
# File 'lib/syntax_tree/node.rb', line 79

def to_json(*opts)
  raise NotImplementedError
end