Class: SyntaxTree::QWordsBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

QWordsBeg represents the beginning of a string literal array.

%w[one two three]

In the snippet above, QWordsBeg represents the “%w[” token. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %w| or %w<).

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #format, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(value:, location:) ⇒ QWordsBeg

Returns a new instance of QWordsBeg.



8814
8815
8816
8817
# File 'lib/syntax_tree/node.rb', line 8814

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the beginning of the array literal



8812
8813
8814
# File 'lib/syntax_tree/node.rb', line 8812

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



8840
8841
8842
# File 'lib/syntax_tree/node.rb', line 8840

def ===(other)
  other.is_a?(QWordsBeg) && value === other.value
end

#accept(visitor) ⇒ Object



8819
8820
8821
# File 'lib/syntax_tree/node.rb', line 8819

def accept(visitor)
  visitor.visit_qwords_beg(self)
end

#child_nodesObject Also known as: deconstruct



8823
8824
8825
# File 'lib/syntax_tree/node.rb', line 8823

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



8827
8828
8829
8830
8831
8832
# File 'lib/syntax_tree/node.rb', line 8827

def copy(value: nil, location: nil)
  QWordsBeg.new(
    value: value || self.value,
    location: location || self.location
  )
end

#deconstruct_keys(_keys) ⇒ Object



8836
8837
8838
# File 'lib/syntax_tree/node.rb', line 8836

def deconstruct_keys(_keys)
  { value: value, location: location }
end