Class: SyntaxTree::RegexpEnd
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::RegexpEnd
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
RegexpEnd represents the end of a regular expression literal.
/.+/m
In the example above, the RegexpEnd event represents the /m at the end of the regular expression literal. You can also declare regular expression literals using %r, as in:
%r{.+}m
Instance Attribute Summary collapse
Attributes inherited from Node
#location
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #end_char, #format, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(value:, location:) ⇒ RegexpEnd
9181
9182
9183
9184
|
# File 'lib/syntax_tree/node.rb', line 9181
def initialize(value:, location:)
@value = value
@location = location
end
|
Instance Attribute Details
#value ⇒ Object
- String
-
the end of the regular expression
9179
9180
9181
|
# File 'lib/syntax_tree/node.rb', line 9179
def value
@value
end
|
Instance Method Details
#===(other) ⇒ Object
9207
9208
9209
|
# File 'lib/syntax_tree/node.rb', line 9207
def ===(other)
other.is_a?(RegexpEnd) && value === other.value
end
|
#accept(visitor) ⇒ Object
9186
9187
9188
|
# File 'lib/syntax_tree/node.rb', line 9186
def accept(visitor)
visitor.visit_regexp_end(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
9190
9191
9192
|
# File 'lib/syntax_tree/node.rb', line 9190
def child_nodes
[]
end
|
#copy(value: nil, location: nil) ⇒ Object
9194
9195
9196
9197
9198
9199
|
# File 'lib/syntax_tree/node.rb', line 9194
def copy(value: nil, location: nil)
RegexpEnd.new(
value: value || self.value,
location: location || self.location
)
end
|
#deconstruct_keys(_keys) ⇒ Object
9203
9204
9205
|
# File 'lib/syntax_tree/node.rb', line 9203
def deconstruct_keys(_keys)
{ value: value, location: location }
end
|