Class: SyntaxTree::Rescue

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Rescue represents the use of the rescue keyword inside of a BodyStmt node.

begin
rescue
end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(keyword:, exception:, statements:, consequent:, location:) ⇒ Rescue

Returns a new instance of Rescue.



9376
9377
9378
9379
9380
9381
9382
9383
# File 'lib/syntax_tree/node.rb', line 9376

def initialize(keyword:, exception:, statements:, consequent:, location:)
  @keyword = keyword
  @exception = exception
  @statements = statements
  @consequent = consequent
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



9374
9375
9376
# File 'lib/syntax_tree/node.rb', line 9374

def comments
  @comments
end

#consequentObject (readonly)

nil | Rescue

the optional next clause in the chain



9371
9372
9373
# File 'lib/syntax_tree/node.rb', line 9371

def consequent
  @consequent
end

#exceptionObject (readonly)

nil | RescueEx

the exceptions being rescued



9365
9366
9367
# File 'lib/syntax_tree/node.rb', line 9365

def exception
  @exception
end

#keywordObject (readonly)

Kw

the rescue keyword



9362
9363
9364
# File 'lib/syntax_tree/node.rb', line 9362

def keyword
  @keyword
end

#statementsObject (readonly)

Statements

the expressions to evaluate when an error is rescued



9368
9369
9370
# File 'lib/syntax_tree/node.rb', line 9368

def statements
  @statements
end

Instance Method Details

#===(other) ⇒ Object



9472
9473
9474
9475
9476
# File 'lib/syntax_tree/node.rb', line 9472

def ===(other)
  other.is_a?(Rescue) && keyword === other.keyword &&
    exception === other.exception && statements === other.statements &&
    consequent === other.consequent
end

#accept(visitor) ⇒ Object



9407
9408
9409
# File 'lib/syntax_tree/node.rb', line 9407

def accept(visitor)
  visitor.visit_rescue(self)
end

#bind_end(end_char, end_column) ⇒ Object



9385
9386
9387
9388
9389
9390
9391
9392
9393
9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
# File 'lib/syntax_tree/node.rb', line 9385

def bind_end(end_char, end_column)
  @location =
    Location.new(
      start_line: location.start_line,
      start_char: location.start_char,
      start_column: location.start_column,
      end_line: location.end_line,
      end_char: end_char,
      end_column: end_column
    )

  if consequent
    consequent.bind_end(end_char, end_column)
    statements.bind_end(
      consequent.location.start_char,
      consequent.location.start_column
    )
  else
    statements.bind_end(end_char, end_column)
  end
end

#child_nodesObject Also known as: deconstruct



9411
9412
9413
# File 'lib/syntax_tree/node.rb', line 9411

def child_nodes
  [keyword, exception, statements, consequent]
end

#copy(keyword: nil, exception: nil, statements: nil, consequent: nil, location: nil) ⇒ Object



9415
9416
9417
9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
# File 'lib/syntax_tree/node.rb', line 9415

def copy(
  keyword: nil,
  exception: nil,
  statements: nil,
  consequent: nil,
  location: nil
)
  node =
    Rescue.new(
      keyword: keyword || self.keyword,
      exception: exception || self.exception,
      statements: statements || self.statements,
      consequent: consequent || self.consequent,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
# File 'lib/syntax_tree/node.rb', line 9437

def deconstruct_keys(_keys)
  {
    keyword: keyword,
    exception: exception,
    statements: statements,
    consequent: consequent,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
9459
9460
9461
9462
9463
9464
9465
9466
9467
9468
9469
9470
# File 'lib/syntax_tree/node.rb', line 9448

def format(q)
  q.group do
    q.format(keyword)

    if exception
      q.nest(keyword.value.length + 1) { q.format(exception) }
    else
      q.text(" StandardError")
    end

    unless statements.empty?
      q.indent do
        q.breakable_force
        q.format(statements)
      end
    end

    if consequent
      q.breakable_force
      q.format(consequent)
    end
  end
end