Class: SyntaxTree::TLamBeg
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::TLamBeg
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
TLamBeg represents the beginning of the body of a lambda literal using braces.
-> { value }
In the example above the TLamBeg represents the { operator.
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the beginning of the body of the lambda literal.
Attributes inherited from Node
#location
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #end_char, #format, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(value:, location:) ⇒ TLamBeg
10802
10803
10804
10805
|
# File 'lib/syntax_tree/node.rb', line 10802
def initialize(value:, location:)
@value = value
@location = location
end
|
Instance Attribute Details
#value ⇒ Object
- String
-
the beginning of the body of the lambda literal
10800
10801
10802
|
# File 'lib/syntax_tree/node.rb', line 10800
def value
@value
end
|
Instance Method Details
#===(other) ⇒ Object
10828
10829
10830
|
# File 'lib/syntax_tree/node.rb', line 10828
def ===(other)
other.is_a?(TLamBeg) && value === other.value
end
|
#accept(visitor) ⇒ Object
10807
10808
10809
|
# File 'lib/syntax_tree/node.rb', line 10807
def accept(visitor)
visitor.visit_tlambeg(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
10811
10812
10813
|
# File 'lib/syntax_tree/node.rb', line 10811
def child_nodes
[]
end
|
#copy(value: nil, location: nil) ⇒ Object
10815
10816
10817
10818
10819
10820
|
# File 'lib/syntax_tree/node.rb', line 10815
def copy(value: nil, location: nil)
TLamBeg.new(
value: value || self.value,
location: location || self.location
)
end
|
#deconstruct_keys(_keys) ⇒ Object
10824
10825
10826
|
# File 'lib/syntax_tree/node.rb', line 10824
def deconstruct_keys(_keys)
{ value: value, location: location }
end
|