Class: SyntaxTree::UntilMod
Overview
UntilMod represents the modifier form of a until loop.
expression until predicate
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#predicate ⇒ Object
readonly
[untyped] the expression to be checked.
-
#statement ⇒ Object
readonly
[untyped] the expression to be executed.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(statement:, predicate:, location:, comments: []) ⇒ UntilMod
constructor
A new instance of UntilMod.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(statement:, predicate:, location:, comments: []) ⇒ UntilMod
Returns a new instance of UntilMod.
9331 9332 9333 9334 9335 9336 |
# File 'lib/syntax_tree/node.rb', line 9331 def initialize(statement:, predicate:, location:, comments: []) @statement = statement @predicate = predicate @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
9329 9330 9331 |
# File 'lib/syntax_tree/node.rb', line 9329 def comments @comments end |
#predicate ⇒ Object (readonly)
[untyped] the expression to be checked
9326 9327 9328 |
# File 'lib/syntax_tree/node.rb', line 9326 def predicate @predicate end |
#statement ⇒ Object (readonly)
[untyped] the expression to be executed
9323 9324 9325 |
# File 'lib/syntax_tree/node.rb', line 9323 def statement @statement end |
Instance Method Details
#accept(visitor) ⇒ Object
9338 9339 9340 |
# File 'lib/syntax_tree/node.rb', line 9338 def accept(visitor) visitor.visit_until_mod(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9342 9343 9344 |
# File 'lib/syntax_tree/node.rb', line 9342 def child_nodes [statement, predicate] end |
#deconstruct_keys(_keys) ⇒ Object
9348 9349 9350 9351 9352 9353 9354 9355 |
# File 'lib/syntax_tree/node.rb', line 9348 def deconstruct_keys(_keys) { statement: statement, predicate: predicate, location: location, comments: comments } end |
#format(q) ⇒ Object
9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 9373 9374 9375 9376 9377 9378 9379 |
# File 'lib/syntax_tree/node.rb', line 9357 def format(q) # If we're in the modifier form and we're modifying a `begin`, then this # is a special case where we need to explicitly use the modifier form # because otherwise the semantic meaning changes. This looks like: # # begin # foo # end until bar # # Also, if the statement of the modifier includes an assignment, then we # can't know for certain that it won't impact the predicate, so we need to # force it to stay as it is. This looks like: # # foo = bar until foo # if statement.is_a?(Begin) || ContainsAssignment.call(statement) q.format(statement) q.text(" until ") q.format(predicate) else LoopFormatter.new("until", self, statement).format(q) end end |