Class: SyntaxTree::When::Separator

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

We have a special separator here for when clauses which causes them to fill as much of the line as possible as opposed to everything breaking into its own line as soon as you hit the print limit.

Instance Method Summary collapse

Instance Method Details

#call(q) ⇒ Object



11829
11830
11831
11832
11833
11834
# File 'lib/syntax_tree/node.rb', line 11829

def call(q)
  q.group do
    q.text(",")
    q.breakable_space
  end
end