Class: SyntaxTree::Word
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::Word
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
Word represents an element within a special array literal that accepts
interpolation.
%W[a#{b}c xyz]
In the example above, there would be two Word nodes within a parent Words
node.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#parts ⇒ Object
readonly
[Array[ StringEmbExpr | StringDVar | TStringContent ]] the parts of the word.
Attributes inherited from Node
#location
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(parts:, location:) ⇒ Word
12031
12032
12033
12034
12035
|
# File 'lib/syntax_tree/node.rb', line 12031
def initialize(parts:, location:)
@parts = parts
@location = location
= []
end
|
Instance Attribute Details
[Array[ Comment | EmbDoc ]] the comments attached to this node
12029
12030
12031
|
# File 'lib/syntax_tree/node.rb', line 12029
def
end
|
#parts ⇒ Object
[Array[ StringEmbExpr | StringDVar | TStringContent ]] the parts of the
word
12026
12027
12028
|
# File 'lib/syntax_tree/node.rb', line 12026
def parts
@parts
end
|
Instance Method Details
#===(other) ⇒ Object
12070
12071
12072
|
# File 'lib/syntax_tree/node.rb', line 12070
def ===(other)
other.is_a?(Word) && ArrayMatch.call(parts, other.parts)
end
|
#accept(visitor) ⇒ Object
12041
12042
12043
|
# File 'lib/syntax_tree/node.rb', line 12041
def accept(visitor)
visitor.visit_word(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
12045
12046
12047
|
# File 'lib/syntax_tree/node.rb', line 12045
def child_nodes
parts
end
|
#copy(parts: nil, location: nil) ⇒ Object
12049
12050
12051
12052
12053
12054
12055
12056
12057
12058
|
# File 'lib/syntax_tree/node.rb', line 12049
def copy(parts: nil, location: nil)
node =
Word.new(
parts: parts || self.parts,
location: location || self.location
)
node..concat(.map(&:copy))
node
end
|
#deconstruct_keys(_keys) ⇒ Object
12062
12063
12064
|
# File 'lib/syntax_tree/node.rb', line 12062
def deconstruct_keys(_keys)
{ parts: parts, location: location, comments: }
end
|
12066
12067
12068
|
# File 'lib/syntax_tree/node.rb', line 12066
def format(q)
q.format_each(parts)
end
|
#match?(pattern) ⇒ Boolean
12037
12038
12039
|
# File 'lib/syntax_tree/node.rb', line 12037
def match?(pattern)
parts.any? { |part| part.is_a?(TStringContent) && part.match?(pattern) }
end
|