Class: SyntaxTree::WordsBeg
Overview
WordsBeg represents the beginning of a string literal array with interpolation.
%W[one two three]
In the snippet above, a WordsBeg would be created with the value of “%W[”. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %W| or %W<).
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the start of the word literal array.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ WordsBeg
constructor
A new instance of WordsBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ WordsBeg
Returns a new instance of WordsBeg.
12005 12006 12007 12008 |
# File 'lib/syntax_tree/node.rb', line 12005 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the start of the word literal array
12003 12004 12005 |
# File 'lib/syntax_tree/node.rb', line 12003 def value @value end |
Instance Method Details
#===(other) ⇒ Object
12031 12032 12033 |
# File 'lib/syntax_tree/node.rb', line 12031 def ===(other) other.is_a?(WordsBeg) && value === other.value end |
#accept(visitor) ⇒ Object
12010 12011 12012 |
# File 'lib/syntax_tree/node.rb', line 12010 def accept(visitor) visitor.visit_words_beg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
12014 12015 12016 |
# File 'lib/syntax_tree/node.rb', line 12014 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
12018 12019 12020 12021 12022 12023 |
# File 'lib/syntax_tree/node.rb', line 12018 def copy(value: nil, location: nil) WordsBeg.new( value: value || self.value, location: location || self.location ) end |
#deconstruct_keys(_keys) ⇒ Object
12027 12028 12029 |
# File 'lib/syntax_tree/node.rb', line 12027 def deconstruct_keys(_keys) { value: value, location: location } end |