Class: SyntaxTree::YARV::OptGT

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree/yarv/instructions.rb

Overview

### Summary

opt_gt is a specialization of the opt_send_without_block instruction that occurs when the > operator is used. Fast paths exist when both operands are integers or floats. It pops both the receiver and the argument off the stack and pushes on the result.

### Usage

~~~ruby 4 > 3 ~~~

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(calldata) ⇒ OptGT



3529
3530
3531
# File 'lib/syntax_tree/yarv/instructions.rb', line 3529

def initialize(calldata)
  @calldata = calldata
end

Instance Attribute Details

#calldataObject (readonly)

Returns the value of attribute calldata.



3527
3528
3529
# File 'lib/syntax_tree/yarv/instructions.rb', line 3527

def calldata
  @calldata
end

Instance Method Details

#==(other) ⇒ Object



3545
3546
3547
# File 'lib/syntax_tree/yarv/instructions.rb', line 3545

def ==(other)
  other.is_a?(OptGT) && other.calldata == calldata
end

#call(vm) ⇒ Object



3565
3566
3567
# File 'lib/syntax_tree/yarv/instructions.rb', line 3565

def call(vm)
  canonical.call(vm)
end

#canonicalObject



3561
3562
3563
# File 'lib/syntax_tree/yarv/instructions.rb', line 3561

def canonical
  Send.new(calldata, nil)
end

#deconstruct_keys(_keys) ⇒ Object



3541
3542
3543
# File 'lib/syntax_tree/yarv/instructions.rb', line 3541

def deconstruct_keys(_keys)
  { calldata: calldata }
end

#disasm(fmt) ⇒ Object



3533
3534
3535
# File 'lib/syntax_tree/yarv/instructions.rb', line 3533

def disasm(fmt)
  fmt.instruction("opt_gt", [fmt.calldata(calldata)])
end

#lengthObject



3549
3550
3551
# File 'lib/syntax_tree/yarv/instructions.rb', line 3549

def length
  2
end

#popsObject



3553
3554
3555
# File 'lib/syntax_tree/yarv/instructions.rb', line 3553

def pops
  2
end

#pushesObject



3557
3558
3559
# File 'lib/syntax_tree/yarv/instructions.rb', line 3557

def pushes
  1
end

#to_a(_iseq) ⇒ Object



3537
3538
3539
# File 'lib/syntax_tree/yarv/instructions.rb', line 3537

def to_a(_iseq)
  [:opt_gt, calldata.to_h]
end