Class: SyntaxTree::YARV::SetLocalWC1

Inherits:
Instruction show all
Defined in:
lib/syntax_tree/yarv/instructions.rb

Overview

### Summary

setlocal_WC_1 is a specialized version of the setlocal instruction. It sets the value of a local variable on the parent frame to the value at the top of the stack as determined by the index given as its only argument.

### Usage

~~~ruby value = 5 self.then { value = 10 } ~~~

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Instruction

#branch_targets, #falls_through?, #leaves?, #pushes, #side_effects?

Constructor Details

#initialize(index) ⇒ SetLocalWC1

Returns a new instance of SetLocalWC1.



5324
5325
5326
# File 'lib/syntax_tree/yarv/instructions.rb', line 5324

def initialize(index)
  @index = index
end

Instance Attribute Details

#indexObject (readonly)

Returns the value of attribute index.



5322
5323
5324
# File 'lib/syntax_tree/yarv/instructions.rb', line 5322

def index
  @index
end

Instance Method Details

#==(other) ⇒ Object



5340
5341
5342
# File 'lib/syntax_tree/yarv/instructions.rb', line 5340

def ==(other)
  other.is_a?(SetLocalWC1) && other.index == index
end

#call(vm) ⇒ Object



5356
5357
5358
# File 'lib/syntax_tree/yarv/instructions.rb', line 5356

def call(vm)
  canonical.call(vm)
end

#canonicalObject



5352
5353
5354
# File 'lib/syntax_tree/yarv/instructions.rb', line 5352

def canonical
  SetLocal.new(index, 1)
end

#deconstruct_keys(_keys) ⇒ Object



5336
5337
5338
# File 'lib/syntax_tree/yarv/instructions.rb', line 5336

def deconstruct_keys(_keys)
  { index: index }
end

#disasm(fmt) ⇒ Object



5328
5329
5330
# File 'lib/syntax_tree/yarv/instructions.rb', line 5328

def disasm(fmt)
  fmt.instruction("setlocal_WC_1", [fmt.local(index, implicit: 1)])
end

#lengthObject



5344
5345
5346
# File 'lib/syntax_tree/yarv/instructions.rb', line 5344

def length
  2
end

#popsObject



5348
5349
5350
# File 'lib/syntax_tree/yarv/instructions.rb', line 5348

def pops
  1
end

#to_a(iseq) ⇒ Object



5332
5333
5334
# File 'lib/syntax_tree/yarv/instructions.rb', line 5332

def to_a(iseq)
  [:setlocal_WC_1, iseq.parent_iseq.local_table.offset(index)]
end