Method: SyntaxTree::BasicVisitor.visit_methods
- Defined in:
- lib/syntax_tree/basic_visitor.rb
.visit_methods ⇒ Object
This method is here to help folks write visitors.
Within the given block, every method that is defined will be checked to ensure it’s a valid visit method using the BasicVisitor::visit_method method defined above.
97 98 99 100 101 102 |
# File 'lib/syntax_tree/basic_visitor.rb', line 97 def visit_methods checker = VisitMethodsChecker.new extend(checker) yield checker.disable! end |