Class: SyntaxTree::Assign
Overview
Assign represents assigning something to a variable or constant. Generally, the left side of the assignment is going to be any node that ends with the name "Field".
variable = value
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#target ⇒ Object
readonly
[ARefField | ConstPathField | Field | TopConstField | VarField] the target to assign the result of the expression to.
-
#value ⇒ Object
readonly
[untyped] the expression to be assigned.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(target:, value:, location:, comments: []) ⇒ Assign
constructor
A new instance of Assign.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(target:, value:, location:, comments: []) ⇒ Assign
Returns a new instance of Assign.
1188 1189 1190 1191 1192 1193 |
# File 'lib/syntax_tree/node.rb', line 1188 def initialize(target:, value:, location:, comments: []) @target = target @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
1186 1187 1188 |
# File 'lib/syntax_tree/node.rb', line 1186 def comments @comments end |
#target ⇒ Object (readonly)
[ARefField | ConstPathField | Field | TopConstField | VarField] the target to assign the result of the expression to
1180 1181 1182 |
# File 'lib/syntax_tree/node.rb', line 1180 def target @target end |
#value ⇒ Object (readonly)
[untyped] the expression to be assigned
1183 1184 1185 |
# File 'lib/syntax_tree/node.rb', line 1183 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
1195 1196 1197 |
# File 'lib/syntax_tree/node.rb', line 1195 def accept(visitor) visitor.visit_assign(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
1199 1200 1201 |
# File 'lib/syntax_tree/node.rb', line 1199 def child_nodes [target, value] end |
#deconstruct_keys(_keys) ⇒ Object
1205 1206 1207 |
# File 'lib/syntax_tree/node.rb', line 1205 def deconstruct_keys(_keys) { target: target, value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/syntax_tree/node.rb', line 1209 def format(q) q.group do q.format(target) q.text(" =") if skip_indent? q.text(" ") q.format(value) else q.indent do q.breakable q.format(value) end end end end |