Class: SyntaxTree::Assoc
Overview
Assoc represents a key-value pair within a hash. It is a child node of either an AssocListFromArgs or a BareAssocHash.
{ key1: value1, key2: value2 }
In the above example, the would be two AssocNew nodes.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#key ⇒ Object
readonly
[untyped] the key of this pair.
-
#value ⇒ Object
readonly
[untyped] the value of this pair.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(key:, value:, location:, comments: []) ⇒ Assoc
constructor
A new instance of Assoc.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(key:, value:, location:, comments: []) ⇒ Assoc
Returns a new instance of Assoc.
1250 1251 1252 1253 1254 1255 |
# File 'lib/syntax_tree/node.rb', line 1250 def initialize(key:, value:, location:, comments: []) @key = key @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
1248 1249 1250 |
# File 'lib/syntax_tree/node.rb', line 1248 def comments @comments end |
#key ⇒ Object (readonly)
[untyped] the key of this pair
1242 1243 1244 |
# File 'lib/syntax_tree/node.rb', line 1242 def key @key end |
#value ⇒ Object (readonly)
[untyped] the value of this pair
1245 1246 1247 |
# File 'lib/syntax_tree/node.rb', line 1245 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
1257 1258 1259 |
# File 'lib/syntax_tree/node.rb', line 1257 def accept(visitor) visitor.visit_assoc(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
1261 1262 1263 |
# File 'lib/syntax_tree/node.rb', line 1261 def child_nodes [key, value] end |
#deconstruct_keys(_keys) ⇒ Object
1267 1268 1269 |
# File 'lib/syntax_tree/node.rb', line 1267 def deconstruct_keys(_keys) { key: key, value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
1271 1272 1273 1274 1275 1276 1277 |
# File 'lib/syntax_tree/node.rb', line 1271 def format(q) if value.is_a?(HashLiteral) format_contents(q) else q.group { format_contents(q) } end end |