Class: SyntaxTree::Binary
Overview
Binary represents any expression that involves two sub-expressions with an operator in between. This can be something that looks like a mathematical operation:
1 + 1
but can also be something like pushing a value onto an array:
array << value
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#left ⇒ Object
readonly
[untyped] the left-hand side of the expression.
-
#operator ⇒ Object
readonly
[Symbol] the operator used between the two expressions.
-
#right ⇒ Object
readonly
[untyped] the right-hand side of the expression.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(left:, operator:, right:, location:, comments: []) ⇒ Binary
constructor
A new instance of Binary.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(left:, operator:, right:, location:, comments: []) ⇒ Binary
Returns a new instance of Binary.
1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/syntax_tree/node.rb', line 1638 def initialize(left:, operator:, right:, location:, comments: []) @left = left @operator = operator @right = right @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
1636 1637 1638 |
# File 'lib/syntax_tree/node.rb', line 1636 def comments @comments end |
#left ⇒ Object (readonly)
[untyped] the left-hand side of the expression
1627 1628 1629 |
# File 'lib/syntax_tree/node.rb', line 1627 def left @left end |
#operator ⇒ Object (readonly)
[Symbol] the operator used between the two expressions
1630 1631 1632 |
# File 'lib/syntax_tree/node.rb', line 1630 def operator @operator end |
#right ⇒ Object (readonly)
[untyped] the right-hand side of the expression
1633 1634 1635 |
# File 'lib/syntax_tree/node.rb', line 1633 def right @right end |
Instance Method Details
#accept(visitor) ⇒ Object
1646 1647 1648 |
# File 'lib/syntax_tree/node.rb', line 1646 def accept(visitor) visitor.visit_binary(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
1650 1651 1652 |
# File 'lib/syntax_tree/node.rb', line 1650 def child_nodes [left, right] end |
#deconstruct_keys(_keys) ⇒ Object
1656 1657 1658 1659 1660 1661 1662 1663 1664 |
# File 'lib/syntax_tree/node.rb', line 1656 def deconstruct_keys(_keys) { left: left, operator: operator, right: right, location: location, comments: comments } end |
#format(q) ⇒ Object
1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 |
# File 'lib/syntax_tree/node.rb', line 1666 def format(q) power = operator == :** q.group do q.group { q.format(left) } q.text(" ") unless power if operator == :<< q.text(operator.to_s) q.text(" ") q.format(right) else q.group do q.text(operator.to_s) q.indent do q.breakable(power ? "" : " ") q.format(right) end end end end end |