Class: SyntaxTree::BodyStmt
Overview
bodystmt can't actually determine its bounds appropriately because it doesn't necessarily know where it started. So the parent node needs to report back down into this one where it goes.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#else_clause ⇒ Object
readonly
[nil | Statements] the optional set of statements inside the else clause.
-
#else_keyword ⇒ Object
readonly
[nil | Kw] the optional else keyword.
-
#ensure_clause ⇒ Object
readonly
[nil | Ensure] the optional ensure clause.
-
#rescue_clause ⇒ Object
readonly
[nil | Rescue] the optional rescue chain attached to the begin clause.
-
#statements ⇒ Object
readonly
[Statements] the list of statements inside the begin clause.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #bind(start_char, start_column, end_char, end_column) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #empty? ⇒ Boolean
- #format(q) ⇒ Object
-
#initialize(statements:, rescue_clause:, else_keyword:, else_clause:, ensure_clause:, location:, comments: []) ⇒ BodyStmt
constructor
A new instance of BodyStmt.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(statements:, rescue_clause:, else_keyword:, else_clause:, ensure_clause:, location:, comments: []) ⇒ BodyStmt
Returns a new instance of BodyStmt.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 |
# File 'lib/syntax_tree/node.rb', line 1800 def initialize( statements:, rescue_clause:, else_keyword:, else_clause:, ensure_clause:, location:, comments: [] ) @statements = statements @rescue_clause = rescue_clause @else_keyword = else_keyword @else_clause = else_clause @ensure_clause = ensure_clause @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
1798 1799 1800 |
# File 'lib/syntax_tree/node.rb', line 1798 def comments @comments end |
#else_clause ⇒ Object (readonly)
[nil | Statements] the optional set of statements inside the else clause
1792 1793 1794 |
# File 'lib/syntax_tree/node.rb', line 1792 def else_clause @else_clause end |
#else_keyword ⇒ Object (readonly)
[nil | Kw] the optional else keyword
1789 1790 1791 |
# File 'lib/syntax_tree/node.rb', line 1789 def else_keyword @else_keyword end |
#ensure_clause ⇒ Object (readonly)
[nil | Ensure] the optional ensure clause
1795 1796 1797 |
# File 'lib/syntax_tree/node.rb', line 1795 def ensure_clause @ensure_clause end |
#rescue_clause ⇒ Object (readonly)
[nil | Rescue] the optional rescue chain attached to the begin clause
1786 1787 1788 |
# File 'lib/syntax_tree/node.rb', line 1786 def rescue_clause @rescue_clause end |
#statements ⇒ Object (readonly)
[Statements] the list of statements inside the begin clause
1783 1784 1785 |
# File 'lib/syntax_tree/node.rb', line 1783 def statements @statements end |
Instance Method Details
#accept(visitor) ⇒ Object
1854 1855 1856 |
# File 'lib/syntax_tree/node.rb', line 1854 def accept(visitor) visitor.visit_bodystmt(self) end |
#bind(start_char, start_column, end_char, end_column) ⇒ Object
1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 |
# File 'lib/syntax_tree/node.rb', line 1818 def bind(start_char, start_column, end_char, end_column) @location = Location.new( start_line: location.start_line, start_char: start_char, start_column: start_column, end_line: location.end_line, end_char: end_char, end_column: end_column ) parts = [rescue_clause, else_clause, ensure_clause] # Here we're going to determine the bounds for the statements consequent = parts.compact.first statements.bind( start_char, start_column, consequent ? consequent.location.start_char : end_char, consequent ? consequent.location.start_column : end_column ) # Next we're going to determine the rescue clause if there is one if rescue_clause consequent = parts.drop(1).compact.first rescue_clause.bind_end( consequent ? consequent.location.start_char : end_char, consequent ? consequent.location.start_column : end_column ) end end |
#child_nodes ⇒ Object Also known as: deconstruct
1858 1859 1860 |
# File 'lib/syntax_tree/node.rb', line 1858 def child_nodes [statements, rescue_clause, else_keyword, else_clause, ensure_clause] end |
#deconstruct_keys(_keys) ⇒ Object
1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/syntax_tree/node.rb', line 1864 def deconstruct_keys(_keys) { statements: statements, rescue_clause: rescue_clause, else_clause: else_clause, ensure_clause: ensure_clause, location: location, comments: comments } end |
#empty? ⇒ Boolean
1850 1851 1852 |
# File 'lib/syntax_tree/node.rb', line 1850 def empty? statements.empty? && !rescue_clause && !else_clause && !ensure_clause end |
#format(q) ⇒ Object
1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 |
# File 'lib/syntax_tree/node.rb', line 1875 def format(q) q.group do q.format(statements) unless statements.empty? if rescue_clause q.nest(-2) do q.breakable(force: true) q.format(rescue_clause) end end if else_clause q.nest(-2) do q.breakable(force: true) q.format(else_keyword) end unless else_clause.empty? q.breakable(force: true) q.format(else_clause) end end if ensure_clause q.nest(-2) do q.breakable(force: true) q.format(ensure_clause) end end end end |