Class: SyntaxTree::CLI::Options
- Inherits:
-
Object
- Object
- SyntaxTree::CLI::Options
- Defined in:
- lib/syntax_tree/cli.rb
Overview
This represents all of the options that can be passed to the CLI. It is responsible for parsing the list and then returning the file paths at the end.
Instance Attribute Summary collapse
-
#ignore_files ⇒ Object
readonly
Returns the value of attribute ignore_files.
-
#plugins ⇒ Object
readonly
Returns the value of attribute plugins.
-
#print_width ⇒ Object
readonly
Returns the value of attribute print_width.
-
#scripts ⇒ Object
readonly
Returns the value of attribute scripts.
-
#target_ruby_version ⇒ Object
readonly
Returns the value of attribute target_ruby_version.
Instance Method Summary collapse
- #formatter_options ⇒ Object
-
#initialize ⇒ Options
constructor
A new instance of Options.
- #parse(arguments) ⇒ Object
Constructor Details
#initialize ⇒ Options
Returns a new instance of Options.
382 383 384 385 386 387 388 |
# File 'lib/syntax_tree/cli.rb', line 382 def initialize @ignore_files = [] @plugins = [] @print_width = DEFAULT_PRINT_WIDTH @scripts = [] @target_ruby_version = DEFAULT_RUBY_VERSION end |
Instance Attribute Details
#ignore_files ⇒ Object (readonly)
Returns the value of attribute ignore_files.
376 377 378 |
# File 'lib/syntax_tree/cli.rb', line 376 def ignore_files @ignore_files end |
#plugins ⇒ Object (readonly)
Returns the value of attribute plugins.
376 377 378 |
# File 'lib/syntax_tree/cli.rb', line 376 def plugins @plugins end |
#print_width ⇒ Object (readonly)
Returns the value of attribute print_width.
376 377 378 |
# File 'lib/syntax_tree/cli.rb', line 376 def print_width @print_width end |
#scripts ⇒ Object (readonly)
Returns the value of attribute scripts.
376 377 378 |
# File 'lib/syntax_tree/cli.rb', line 376 def scripts @scripts end |
#target_ruby_version ⇒ Object (readonly)
Returns the value of attribute target_ruby_version.
376 377 378 |
# File 'lib/syntax_tree/cli.rb', line 376 def target_ruby_version @target_ruby_version end |
Instance Method Details
#formatter_options ⇒ Object
390 391 392 393 |
# File 'lib/syntax_tree/cli.rb', line 390 def @formatter_options ||= Formatter::Options.new(target_ruby_version: target_ruby_version) end |
#parse(arguments) ⇒ Object
395 396 397 |
# File 'lib/syntax_tree/cli.rb', line 395 def parse(arguments) parser.parse!(arguments) end |