Class: SyntaxTree::CallNode
Overview
CallNode represents a method call.
receiver.
Instance Attribute Summary collapse
-
#arguments ⇒ Object
readonly
- nil | ArgParen | Args
-
the arguments to the method call.
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#message ⇒ Object
readonly
- :call | Backtick | Const | Ident | Op
-
the message being sent.
-
#operator ⇒ Object
readonly
- nil | :“::” | Op | Period
-
the operator being used to send the message.
-
#receiver ⇒ Object
readonly
- nil | untyped
-
the receiver of the method call.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #arity ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(receiver: nil, operator: nil, message: nil, arguments: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#format_arguments(q) ⇒ Object
Print out the arguments to this call.
- #format_contents(q) ⇒ Object
-
#initialize(receiver:, operator:, message:, arguments:, location:) ⇒ CallNode
constructor
A new instance of CallNode.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(receiver:, operator:, message:, arguments:, location:) ⇒ CallNode
Returns a new instance of CallNode.
2885 2886 2887 2888 2889 2890 2891 2892 |
# File 'lib/syntax_tree/node.rb', line 2885 def initialize(receiver:, operator:, message:, arguments:, location:) @receiver = receiver @operator = operator = @arguments = arguments @location = location @comments = [] end |
Instance Attribute Details
#arguments ⇒ Object (readonly)
- nil | ArgParen | Args
-
the arguments to the method call
2880 2881 2882 |
# File 'lib/syntax_tree/node.rb', line 2880 def arguments @arguments end |
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
2883 2884 2885 |
# File 'lib/syntax_tree/node.rb', line 2883 def comments @comments end |
#message ⇒ Object (readonly)
- :call | Backtick | Const | Ident | Op
-
the message being sent
2877 2878 2879 |
# File 'lib/syntax_tree/node.rb', line 2877 def end |
#operator ⇒ Object (readonly)
- nil | :“::” | Op | Period
-
the operator being used to send the message
2874 2875 2876 |
# File 'lib/syntax_tree/node.rb', line 2874 def operator @operator end |
#receiver ⇒ Object (readonly)
- nil | untyped
-
the receiver of the method call
2871 2872 2873 |
# File 'lib/syntax_tree/node.rb', line 2871 def receiver @receiver end |
Instance Method Details
#===(other) ⇒ Object
2980 2981 2982 2983 2984 |
# File 'lib/syntax_tree/node.rb', line 2980 def ===(other) other.is_a?(CallNode) && receiver === other.receiver && operator === other.operator && === other. && arguments === other.arguments end |
#accept(visitor) ⇒ Object
2894 2895 2896 |
# File 'lib/syntax_tree/node.rb', line 2894 def accept(visitor) visitor.visit_call(self) end |
#arity ⇒ Object
3026 3027 3028 |
# File 'lib/syntax_tree/node.rb', line 3026 def arity arguments&.arity || 0 end |
#child_nodes ⇒ Object Also known as: deconstruct
2898 2899 2900 2901 2902 2903 2904 2905 |
# File 'lib/syntax_tree/node.rb', line 2898 def child_nodes [ receiver, (operator if operator != :"::"), ( if != :call), arguments ] end |
#copy(receiver: nil, operator: nil, message: nil, arguments: nil, location: nil) ⇒ Object
2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 |
# File 'lib/syntax_tree/node.rb', line 2907 def copy( receiver: nil, operator: nil, message: nil, arguments: nil, location: nil ) node = CallNode.new( receiver: receiver || self.receiver, operator: operator || self.operator, message: || self., arguments: arguments || self.arguments, location: location || self.location ) node.comments.concat(comments.map(&:copy)) node end |
#deconstruct_keys(_keys) ⇒ Object
2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 |
# File 'lib/syntax_tree/node.rb', line 2929 def deconstruct_keys(_keys) { receiver: receiver, operator: operator, message: , arguments: arguments, location: location, comments: comments } end |
#format(q) ⇒ Object
2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 |
# File 'lib/syntax_tree/node.rb', line 2940 def format(q) if receiver # If we're at the top of a call chain, then we're going to do some # specialized printing in case we can print it nicely. We _only_ do this # at the top of the chain to avoid weird recursion issues. if CallChainFormatter.chained?(receiver) && !CallChainFormatter.chained?(q.parent) q.group do q .if_break { CallChainFormatter.new(self).format(q) } .if_flat { format_contents(q) } end else format_contents(q) end else q.format() # Note that this explicitly leaves parentheses in place even if they are # empty. There are two reasons we would need to do this. The first is if # we're calling something that looks like a constant, as in: # # Foo() # # In this case if we remove the parentheses then this becomes a constant # reference and not a method call. The second is if we're calling a # method that is the same name as a local variable that is in scope, as # in: # # foo = foo() # # In this case we have to keep the parentheses or else it treats this # like assigning nil to the local variable. Note that we could attempt # to be smarter about this by tracking the local variables that are in # scope, but for now it's simpler and more efficient to just leave the # parentheses in place. q.format(arguments) if arguments end end |
#format_arguments(q) ⇒ Object
Print out the arguments to this call. If there are no arguments, then do nothing.
2988 2989 2990 2991 2992 2993 2994 2995 2996 |
# File 'lib/syntax_tree/node.rb', line 2988 def format_arguments(q) case arguments when ArgParen q.format(arguments) when Args q.text(" ") q.format(arguments) end end |
#format_contents(q) ⇒ Object
2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/syntax_tree/node.rb', line 2998 def format_contents(q) call_operator = CallOperatorFormatter.new(operator) q.group do q.format(receiver) # If there are trailing comments on the call operator, then we need to # use the trailing form as opposed to the leading form. q.format(call_operator) if call_operator.comments.any? q.group do q.indent do if receiver.comments.any? || call_operator.comments.any? q.breakable_force end if call_operator.comments.empty? q.format(call_operator, stackable: false) end q.format() if != :call end format_arguments(q) end end end |