Class: SyntaxTree::ClassDeclaration
- Defined in:
- lib/syntax_tree/node.rb
Overview
Class represents defining a class using the class keyword.
class Container
end
Classes can have path names as their class name in case it’s being nested under a namespace, as in:
class Namespace::Container
end
Classes can also be defined as a top-level path, in the case that it’s already in a namespace but you want to define it at the top-level instead, as in:
module OtherNamespace
class ::Namespace::Container
end
end
All of these declarations can also have an optional superclass reference, as in:
class Child < Parent
end
That superclass can actually be any Ruby expression, it doesn’t necessarily need to be a constant, as in:
class Child < method
end
Instance Attribute Summary collapse
-
#bodystmt ⇒ Object
readonly
- BodyStmt
-
the expressions to execute within the context of the class.
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#constant ⇒ Object
readonly
- ConstPathRef | ConstRef | TopConstRef
-
the name of the class being defined.
-
#superclass ⇒ Object
readonly
- nil | untyped
-
the optional superclass declaration.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(constant: nil, superclass: nil, bodystmt: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(constant:, superclass:, bodystmt:, location:) ⇒ ClassDeclaration
constructor
A new instance of ClassDeclaration.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(constant:, superclass:, bodystmt:, location:) ⇒ ClassDeclaration
Returns a new instance of ClassDeclaration.
3252 3253 3254 3255 3256 3257 3258 |
# File 'lib/syntax_tree/node.rb', line 3252 def initialize(constant:, superclass:, bodystmt:, location:) @constant = constant @superclass = superclass @bodystmt = bodystmt @location = location @comments = [] end |
Instance Attribute Details
#bodystmt ⇒ Object (readonly)
- BodyStmt
-
the expressions to execute within the context of the class
3247 3248 3249 |
# File 'lib/syntax_tree/node.rb', line 3247 def bodystmt @bodystmt end |
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
3250 3251 3252 |
# File 'lib/syntax_tree/node.rb', line 3250 def comments @comments end |
#constant ⇒ Object (readonly)
- ConstPathRef | ConstRef | TopConstRef
-
the name of the class being
defined
3241 3242 3243 |
# File 'lib/syntax_tree/node.rb', line 3241 def constant @constant end |
#superclass ⇒ Object (readonly)
- nil | untyped
-
the optional superclass declaration
3244 3245 3246 |
# File 'lib/syntax_tree/node.rb', line 3244 def superclass @superclass end |
Instance Method Details
#===(other) ⇒ Object
3315 3316 3317 3318 |
# File 'lib/syntax_tree/node.rb', line 3315 def ===(other) other.is_a?(ClassDeclaration) && constant === other.constant && superclass === other.superclass && bodystmt === other.bodystmt end |
#accept(visitor) ⇒ Object
3260 3261 3262 |
# File 'lib/syntax_tree/node.rb', line 3260 def accept(visitor) visitor.visit_class(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
3264 3265 3266 |
# File 'lib/syntax_tree/node.rb', line 3264 def child_nodes [constant, superclass, bodystmt] end |
#copy(constant: nil, superclass: nil, bodystmt: nil, location: nil) ⇒ Object
3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 |
# File 'lib/syntax_tree/node.rb', line 3268 def copy(constant: nil, superclass: nil, bodystmt: nil, location: nil) node = ClassDeclaration.new( constant: constant || self.constant, superclass: superclass || self.superclass, bodystmt: bodystmt || self.bodystmt, location: location || self.location ) node.comments.concat(comments.map(&:copy)) node end |
#deconstruct_keys(_keys) ⇒ Object
3283 3284 3285 3286 3287 3288 3289 3290 3291 |
# File 'lib/syntax_tree/node.rb', line 3283 def deconstruct_keys(_keys) { constant: constant, superclass: superclass, bodystmt: bodystmt, location: location, comments: comments } end |
#format(q) ⇒ Object
3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 |
# File 'lib/syntax_tree/node.rb', line 3293 def format(q) if bodystmt.empty? q.group do format_declaration(q) q.breakable_force q.text("end") end else q.group do format_declaration(q) q.indent do q.breakable_force q.format(bodystmt) end q.breakable_force q.text("end") end end end |