Class: SyntaxTree::ClassDeclaration

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Class represents defining a class using the class keyword.

class Container
end

Classes can have path names as their class name in case it's being nested under a namespace, as in:

class Namespace::Container
end

Classes can also be defined as a top-level path, in the case that it's already in a namespace but you want to define it at the top-level instead, as in:

module OtherNamespace
  class ::Namespace::Container
  end
end

All of these declarations can also have an optional superclass reference, as in:

class Child < Parent
end

That superclass can actually be any Ruby expression, it doesn't necessarily need to be a constant, as in:

class Child < method
end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(constant:, superclass:, bodystmt:, location:, comments: []) ⇒ ClassDeclaration

Returns a new instance of ClassDeclaration.



2836
2837
2838
2839
2840
2841
2842
# File 'lib/syntax_tree/node.rb', line 2836

def initialize(constant:, superclass:, bodystmt:, location:, comments: [])
  @constant = constant
  @superclass = superclass
  @bodystmt = bodystmt
  @location = location
  @comments = comments
end

Instance Attribute Details

#bodystmt ⇒ Object (readonly)

[BodyStmt] the expressions to execute within the context of the class



2831
2832
2833
# File 'lib/syntax_tree/node.rb', line 2831

def bodystmt
  @bodystmt
end

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



2834
2835
2836
# File 'lib/syntax_tree/node.rb', line 2834

def comments
  @comments
end

#constant ⇒ Object (readonly)

[ConstPathRef | ConstRef | TopConstRef] the name of the class being defined



2825
2826
2827
# File 'lib/syntax_tree/node.rb', line 2825

def constant
  @constant
end

#superclass ⇒ Object (readonly)

[nil | untyped] the optional superclass declaration



2828
2829
2830
# File 'lib/syntax_tree/node.rb', line 2828

def superclass
  @superclass
end

Instance Method Details

#accept(visitor) ⇒ Object



2844
2845
2846
# File 'lib/syntax_tree/node.rb', line 2844

def accept(visitor)
  visitor.visit_class(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



2848
2849
2850
# File 'lib/syntax_tree/node.rb', line 2848

def child_nodes
  [constant, superclass, bodystmt]
end

#deconstruct_keys(_keys) ⇒ Object



2854
2855
2856
2857
2858
2859
2860
2861
2862
# File 'lib/syntax_tree/node.rb', line 2854

def deconstruct_keys(_keys)
  {
    constant: constant,
    superclass: superclass,
    bodystmt: bodystmt,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



2864
2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
# File 'lib/syntax_tree/node.rb', line 2864

def format(q)
  declaration = -> do
    q.group do
      q.text("class ")
      q.format(constant)

      if superclass
        q.text(" < ")
        q.format(superclass)
      end
    end
  end

  if bodystmt.empty?
    q.group do
      declaration.call
      q.breakable(force: true)
      q.text("end")
    end
  else
    q.group do
      declaration.call

      q.indent do
        q.breakable(force: true)
        q.format(bodystmt)
      end

      q.breakable(force: true)
      q.text("end")
    end
  end
end