Class: SyntaxTree::Comment
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::Comment
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
Comment represents a comment in the source.
Instance Attribute Summary collapse
-
#inline ⇒ Object
(also: #inline?)
readonly
[boolean] whether or not there is code on the same line as this comment.
-
#value ⇒ Object
readonly
[String] the contents of the comment.
Attributes inherited from Node
#location
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, inline:, location:) ⇒ Comment
Returns a new instance of Comment.
3122
3123
3124
3125
3126
3127
3128
3129
|
# File 'lib/syntax_tree/node.rb', line 3122
def initialize(value:, inline:, location:)
@value = value
@inline = inline
@location = location
@leading = false
@trailing = false
end
|
Instance Attribute Details
#inline ⇒ Object
Also known as:
inline?
[boolean] whether or not there is code on the same line as this comment.
If there is, then inline will be true.
3119
3120
3121
|
# File 'lib/syntax_tree/node.rb', line 3119
def inline
@inline
end
|
#value ⇒ Object
[String] the contents of the comment
3115
3116
3117
|
# File 'lib/syntax_tree/node.rb', line 3115
def value
@value
end
|
Instance Method Details
#accept(visitor) ⇒ Object
3155
3156
3157
|
# File 'lib/syntax_tree/node.rb', line 3155
def accept(visitor)
visitor.(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
3159
3160
3161
|
# File 'lib/syntax_tree/node.rb', line 3159
def child_nodes
[]
end
|
3151
3152
3153
|
# File 'lib/syntax_tree/node.rb', line 3151
def
[]
end
|
#deconstruct_keys(_keys) ⇒ Object
3165
3166
3167
|
# File 'lib/syntax_tree/node.rb', line 3165
def deconstruct_keys(_keys)
{ value: value, inline: inline, location: location }
end
|
3169
3170
3171
|
# File 'lib/syntax_tree/node.rb', line 3169
def format(q)
q.text(value)
end
|
#ignore? ⇒ Boolean
3147
3148
3149
|
# File 'lib/syntax_tree/node.rb', line 3147
def ignore?
value[1..].strip == "stree-ignore"
end
|
#leading! ⇒ Object
3131
3132
3133
|
# File 'lib/syntax_tree/node.rb', line 3131
def leading!
@leading = true
end
|
#leading? ⇒ Boolean
3135
3136
3137
|
# File 'lib/syntax_tree/node.rb', line 3135
def leading?
@leading
end
|
#trailing! ⇒ Object
3139
3140
3141
|
# File 'lib/syntax_tree/node.rb', line 3139
def trailing!
@trailing = true
end
|
#trailing? ⇒ Boolean
3143
3144
3145
|
# File 'lib/syntax_tree/node.rb', line 3143
def trailing?
@trailing
end
|