Class: SyntaxTree::Const

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Const represents a literal value that looks like a constant. This could actually be a reference to a constant:

Constant

It could also be something that looks like a constant in another context, as in a method call to a capitalized method:

object.Constant

or a symbol that starts with a capital letter:

:Constant

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ Const

Returns a new instance of Const.



3195
3196
3197
3198
3199
# File 'lib/syntax_tree/node.rb', line 3195

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



3193
3194
3195
# File 'lib/syntax_tree/node.rb', line 3193

def comments
  @comments
end

#value ⇒ Object (readonly)

[String] the name of the constant



3190
3191
3192
# File 'lib/syntax_tree/node.rb', line 3190

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



3201
3202
3203
# File 'lib/syntax_tree/node.rb', line 3201

def accept(visitor)
  visitor.visit_const(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



3205
3206
3207
# File 'lib/syntax_tree/node.rb', line 3205

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



3211
3212
3213
# File 'lib/syntax_tree/node.rb', line 3211

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



3215
3216
3217
# File 'lib/syntax_tree/node.rb', line 3215

def format(q)
  q.text(value)
end