Class: SyntaxTree::DefNode

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Def represents defining a regular method on the current self object.

def method(param) result end
def object.method(param) result end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(target:, operator:, name:, params:, bodystmt:, location:) ⇒ DefNode



4070
4071
4072
4073
4074
4075
4076
4077
4078
# File 'lib/syntax_tree/node.rb', line 4070

def initialize(target:, operator:, name:, params:, bodystmt:, location:)
  @target = target
  @operator = operator
  @name = name
  @params = params
  @bodystmt = bodystmt
  @location = location
  @comments = []
end

Instance Attribute Details

#bodystmtObject (readonly)

BodyStmt | untyped

the expressions to be executed by the method



4065
4066
4067
# File 'lib/syntax_tree/node.rb', line 4065

def bodystmt
  @bodystmt
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



4068
4069
4070
# File 'lib/syntax_tree/node.rb', line 4068

def comments
  @comments
end

#nameObject (readonly)

Backtick | Const | Ident | Kw | Op

the name of the method



4059
4060
4061
# File 'lib/syntax_tree/node.rb', line 4059

def name
  @name
end

#operatorObject (readonly)

nil | Op | Period

the operator being used to declare the method



4056
4057
4058
# File 'lib/syntax_tree/node.rb', line 4056

def operator
  @operator
end

#paramsObject (readonly)

nil | Params | Paren

the parameter declaration for the method



4062
4063
4064
# File 'lib/syntax_tree/node.rb', line 4062

def params
  @params
end

#targetObject (readonly)

nil | untyped

the target where the method is being defined



4053
4054
4055
# File 'lib/syntax_tree/node.rb', line 4053

def target
  @target
end

Instance Method Details

#===(other) ⇒ Object



4166
4167
4168
4169
4170
# File 'lib/syntax_tree/node.rb', line 4166

def ===(other)
  other.is_a?(DefNode) && target === other.target &&
    operator === other.operator && name === other.name &&
    params === other.params && bodystmt === other.bodystmt
end

#accept(visitor) ⇒ Object



4080
4081
4082
# File 'lib/syntax_tree/node.rb', line 4080

def accept(visitor)
  visitor.visit_def(self)
end

#child_nodesObject Also known as: deconstruct



4084
4085
4086
# File 'lib/syntax_tree/node.rb', line 4084

def child_nodes
  [target, operator, name, params, bodystmt]
end

#copy(target: nil, operator: nil, name: nil, params: nil, bodystmt: nil, location: nil) ⇒ Object



4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/syntax_tree/node.rb', line 4088

def copy(
  target: nil,
  operator: nil,
  name: nil,
  params: nil,
  bodystmt: nil,
  location: nil
)
  node =
    DefNode.new(
      target: target || self.target,
      operator: operator || self.operator,
      name: name || self.name,
      params: params || self.params,
      bodystmt: bodystmt || self.bodystmt,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



4112
4113
4114
4115
4116
4117
4118
4119
4120
4121
4122
# File 'lib/syntax_tree/node.rb', line 4112

def deconstruct_keys(_keys)
  {
    target: target,
    operator: operator,
    name: name,
    params: params,
    bodystmt: bodystmt,
    location: location,
    comments: comments
  }
end

#endless?Boolean

Returns true if the method was found in the source in the “endless” form, i.e. where the method body is defined using the ‘=` operator after the method name and parameters.



4175
4176
4177
# File 'lib/syntax_tree/node.rb', line 4175

def endless?
  !bodystmt.is_a?(BodyStmt)
end

#format(q) ⇒ Object



4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
4135
4136
4137
4138
4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
# File 'lib/syntax_tree/node.rb', line 4124

def format(q)
  q.group do
    q.group do
      q.text("def ")

      if target
        q.format(target)
        q.format(CallOperatorFormatter.new(operator), stackable: false)
      end

      q.format(name)

      case params
      when Paren
        q.format(params)
      when Params
        q.format(params) if !params.empty? || params.comments.any?
      end
    end

    if endless?
      q.text(" =")
      q.group do
        q.indent do
          q.breakable_space
          q.format(bodystmt)
        end
      end
    else
      unless bodystmt.empty?
        q.indent do
          q.breakable_force
          q.format(bodystmt)
        end
      end

      q.breakable_force
      q.text("end")
    end
  end
end