Class: SyntaxTree::DynaSymbol

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

DynaSymbol represents a symbol literal that uses quotes to dynamically define its value.

:"#{variable}"

They can also be used as a special kind of dynamic hash key, as in:

{ "#{key}": value }

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(parts:, quote:, location:) ⇒ DynaSymbol



4601
4602
4603
4604
4605
4606
# File 'lib/syntax_tree/node.rb', line 4601

def initialize(parts:, quote:, location:)
  @parts = parts
  @quote = quote
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



4599
4600
4601
# File 'lib/syntax_tree/node.rb', line 4599

def comments
  @comments
end

#partsObject (readonly)

Array[ StringDVar | StringEmbExpr | TStringContent ]

the parts of the

dynamic symbol



4593
4594
4595
# File 'lib/syntax_tree/node.rb', line 4593

def parts
  @parts
end

#quoteObject (readonly)

String

the quote used to delimit the dynamic symbol



4596
4597
4598
# File 'lib/syntax_tree/node.rb', line 4596

def quote
  @quote
end

Instance Method Details

#===(other) ⇒ Object



4663
4664
4665
4666
# File 'lib/syntax_tree/node.rb', line 4663

def ===(other)
  other.is_a?(DynaSymbol) && ArrayMatch.call(parts, other.parts) &&
    quote === other.quote
end

#accept(visitor) ⇒ Object



4608
4609
4610
# File 'lib/syntax_tree/node.rb', line 4608

def accept(visitor)
  visitor.visit_dyna_symbol(self)
end

#child_nodesObject Also known as: deconstruct



4612
4613
4614
# File 'lib/syntax_tree/node.rb', line 4612

def child_nodes
  parts
end

#copy(parts: nil, quote: nil, location: nil) ⇒ Object



4616
4617
4618
4619
4620
4621
4622
4623
4624
4625
4626
# File 'lib/syntax_tree/node.rb', line 4616

def copy(parts: nil, quote: nil, location: nil)
  node =
    DynaSymbol.new(
      parts: parts || self.parts,
      quote: quote || self.quote,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



4630
4631
4632
# File 'lib/syntax_tree/node.rb', line 4630

def deconstruct_keys(_keys)
  { parts: parts, quote: quote, location: location, comments: comments }
end

#format(q) ⇒ Object



4634
4635
4636
4637
4638
4639
4640
4641
4642
4643
4644
4645
4646
4647
4648
4649
4650
4651
4652
4653
4654
4655
4656
4657
4658
4659
4660
4661
# File 'lib/syntax_tree/node.rb', line 4634

def format(q)
  opening_quote, closing_quote = quotes(q)

  q.text(opening_quote)
  q.group do
    parts.each do |part|
      if part.is_a?(TStringContent)
        value = Quotes.normalize(part.value, closing_quote)
        first = true

        value.each_line(chomp: true) do |line|
          if first
            first = false
          else
            q.breakable_return
          end

          q.text(line)
        end

        q.breakable_return if value.end_with?("\n")
      else
        q.format(part)
      end
    end
  end
  q.text(closing_quote)
end