Class: SyntaxTree::EmbExprBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

EmbExprBeg represents the beginning token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).

"Hello, #{person}!"

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ EmbExprBeg

Returns a new instance of EmbExprBeg.



4192
4193
4194
4195
# File 'lib/syntax_tree/node.rb', line 4192

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#value ⇒ Object (readonly)

[String] the #{ used in the string



4190
4191
4192
# File 'lib/syntax_tree/node.rb', line 4190

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



4197
4198
4199
# File 'lib/syntax_tree/node.rb', line 4197

def accept(visitor)
  visitor.visit_embexpr_beg(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



4201
4202
4203
# File 'lib/syntax_tree/node.rb', line 4201

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



4207
4208
4209
# File 'lib/syntax_tree/node.rb', line 4207

def deconstruct_keys(_keys)
  { value: value, location: location }
end