Class: SyntaxTree::EmbExprBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

EmbExprBeg represents the beginning token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).

"Hello, #{person}!"

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ EmbExprBeg

Returns a new instance of EmbExprBeg.



4121
4122
4123
4124
# File 'lib/syntax_tree/node.rb', line 4121

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the #{ used in the string



4119
4120
4121
# File 'lib/syntax_tree/node.rb', line 4119

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



4126
4127
4128
# File 'lib/syntax_tree/node.rb', line 4126

def accept(visitor)
  visitor.visit_embexpr_beg(self)
end

#child_nodesObject Also known as: deconstruct



4130
4131
4132
# File 'lib/syntax_tree/node.rb', line 4130

def child_nodes
  []
end

#deconstruct_keys(keys) ⇒ Object



4136
4137
4138
# File 'lib/syntax_tree/node.rb', line 4136

def deconstruct_keys(keys)
  { value: value, location: location }
end