Class: SyntaxTree::EmbExprBeg
Overview
EmbExprBeg represents the beginning token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).
"Hello, #{person}!"
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the #{ used in the string.
Attributes inherited from Node
Instance Method Summary collapse
-
#initialize(value:, location:) ⇒ EmbExprBeg
constructor
A new instance of EmbExprBeg.
Methods inherited from Node
#child_nodes, #deconstruct, #deconstruct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ EmbExprBeg
Returns a new instance of EmbExprBeg.
4712 4713 4714 4715 |
# File 'lib/syntax_tree/node.rb', line 4712 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the #{ used in the string
4710 4711 4712 |
# File 'lib/syntax_tree/node.rb', line 4710 def value @value end |