Class: SyntaxTree::EmbExprBeg

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree.rb

Overview

EmbExprBeg represents the beginning token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).

"Hello, #{person}!"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value:, location:) ⇒ EmbExprBeg

Returns a new instance of EmbExprBeg.



5707
5708
5709
5710
# File 'lib/syntax_tree.rb', line 5707

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#locationObject (readonly)

Location

the location of this node



5705
5706
5707
# File 'lib/syntax_tree.rb', line 5705

def location
  @location
end

#valueObject (readonly)

String

the #{ used in the string



5702
5703
5704
# File 'lib/syntax_tree.rb', line 5702

def value
  @value
end