Class: SyntaxTree::EmbExprEnd

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

EmbExprEnd represents the ending token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).

"Hello, #{person}!"

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ EmbExprEnd

Returns a new instance of EmbExprEnd.



4985
4986
4987
4988
# File 'lib/syntax_tree/node.rb', line 4985

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the } used in the string



4983
4984
4985
# File 'lib/syntax_tree/node.rb', line 4983

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



5011
5012
5013
# File 'lib/syntax_tree/node.rb', line 5011

def ===(other)
  other.is_a?(EmbExprEnd) && value === other.value
end

#accept(visitor) ⇒ Object



4990
4991
4992
# File 'lib/syntax_tree/node.rb', line 4990

def accept(visitor)
  visitor.visit_embexpr_end(self)
end

#child_nodesObject Also known as: deconstruct



4994
4995
4996
# File 'lib/syntax_tree/node.rb', line 4994

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



4998
4999
5000
5001
5002
5003
# File 'lib/syntax_tree/node.rb', line 4998

def copy(value: nil, location: nil)
  EmbExprEnd.new(
    value: value || self.value,
    location: location || self.location
  )
end

#deconstruct_keys(_keys) ⇒ Object



5007
5008
5009
# File 'lib/syntax_tree/node.rb', line 5007

def deconstruct_keys(_keys)
  { value: value, location: location }
end