Class: SyntaxTree::EmbExprEnd
Overview
EmbExprEnd represents the ending token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).
"Hello, #{person}!"
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the } used in the string.
Attributes inherited from Node
Instance Method Summary collapse
-
#initialize(value:, location:) ⇒ EmbExprEnd
constructor
A new instance of EmbExprEnd.
Methods inherited from Node
#child_nodes, #deconstruct, #deconstruct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ EmbExprEnd
Returns a new instance of EmbExprEnd.
4728 4729 4730 4731 |
# File 'lib/syntax_tree/node.rb', line 4728 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the } used in the string
4726 4727 4728 |
# File 'lib/syntax_tree/node.rb', line 4726 def value @value end |