Class: SyntaxTree::EmbExprEnd
Overview
EmbExprEnd represents the ending token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).
"Hello, #{person}!"
Instance Attribute Summary collapse
-
#location ⇒ Object
readonly
- Location
-
the location of this node.
-
#value ⇒ Object
readonly
- String
-
the } used in the string.
Instance Method Summary collapse
-
#initialize(value:, location:) ⇒ EmbExprEnd
constructor
A new instance of EmbExprEnd.
Methods inherited from Node
#child_nodes, #deconstruct, #deconstruct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ EmbExprEnd
Returns a new instance of EmbExprEnd.
4887 4888 4889 4890 |
# File 'lib/syntax_tree/node.rb', line 4887 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#location ⇒ Object (readonly)
- Location
-
the location of this node
4885 4886 4887 |
# File 'lib/syntax_tree/node.rb', line 4885 def location @location end |
#value ⇒ Object (readonly)
- String
-
the } used in the string
4882 4883 4884 |
# File 'lib/syntax_tree/node.rb', line 4882 def value @value end |