Class: SyntaxTree::EmbExprEnd
- Inherits:
-
Object
- Object
- SyntaxTree::EmbExprEnd
- Defined in:
- lib/syntax_tree.rb
Overview
EmbExprEnd represents the ending token for using interpolation inside of a parent node that accepts string content (like a string or regular expression).
"Hello, #{person}!"
Instance Attribute Summary collapse
-
#location ⇒ Object
readonly
- Location
-
the location of this node.
-
#value ⇒ Object
readonly
- String
-
the } used in the string.
Instance Method Summary collapse
-
#initialize(value:, location:) ⇒ EmbExprEnd
constructor
A new instance of EmbExprEnd.
Constructor Details
#initialize(value:, location:) ⇒ EmbExprEnd
Returns a new instance of EmbExprEnd.
5739 5740 5741 5742 |
# File 'lib/syntax_tree.rb', line 5739 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#location ⇒ Object (readonly)
- Location
-
the location of this node
5737 5738 5739 |
# File 'lib/syntax_tree.rb', line 5737 def location @location end |
#value ⇒ Object (readonly)
- String
-
the } used in the string
5734 5735 5736 |
# File 'lib/syntax_tree.rb', line 5734 def value @value end |