Class: SyntaxTree::ExcessedComma
Overview
ExcessedComma represents a trailing comma in a list of block parameters. It changes the block parameters such that they will destructure.
[[1, 2, 3], [2, 3, 4]].each do |first, second,|
end
In the above example, an ExcessedComma node would appear in the third position of the Params node that is used to declare that block. The third position typically represents a rest-type parameter, but in this case is used to indicate that a trailing comma was used.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- String
-
the comma.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:) ⇒ ExcessedComma
constructor
A new instance of ExcessedComma.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ ExcessedComma
Returns a new instance of ExcessedComma.
5148 5149 5150 5151 5152 |
# File 'lib/syntax_tree/node.rb', line 5148 def initialize(value:, location:) @value = value @location = location @comments = [] end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
5146 5147 5148 |
# File 'lib/syntax_tree/node.rb', line 5146 def comments @comments end |
#value ⇒ Object (readonly)
- String
-
the comma
5143 5144 5145 |
# File 'lib/syntax_tree/node.rb', line 5143 def value @value end |
Instance Method Details
#===(other) ⇒ Object
5183 5184 5185 |
# File 'lib/syntax_tree/node.rb', line 5183 def ===(other) other.is_a?(ExcessedComma) && value === other.value end |
#accept(visitor) ⇒ Object
5154 5155 5156 |
# File 'lib/syntax_tree/node.rb', line 5154 def accept(visitor) visitor.visit_excessed_comma(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
5158 5159 5160 |
# File 'lib/syntax_tree/node.rb', line 5158 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/syntax_tree/node.rb', line 5162 def copy(value: nil, location: nil) node = ExcessedComma.new( value: value || self.value, location: location || self.location ) node.comments.concat(comments.map(&:copy)) node end |
#deconstruct_keys(_keys) ⇒ Object
5175 5176 5177 |
# File 'lib/syntax_tree/node.rb', line 5175 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
5179 5180 5181 |
# File 'lib/syntax_tree/node.rb', line 5179 def format(q) q.text(value) end |