Class: SyntaxTree::ExcessedComma

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

ExcessedComma represents a trailing comma in a list of block parameters. It changes the block parameters such that they will destructure.

[[1, 2, 3], [2, 3, 4]].each do |first, second,|
end

In the above example, an ExcessedComma node would appear in the third position of the Params node that is used to declare that block. The third position typically represents a rest-type parameter, but in this case is used to indicate that a trailing comma was used.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ ExcessedComma

Returns a new instance of ExcessedComma.



4346
4347
4348
4349
4350
# File 'lib/syntax_tree/node.rb', line 4346

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



4344
4345
4346
# File 'lib/syntax_tree/node.rb', line 4344

def comments
  @comments
end

#value ⇒ Object (readonly)

[String] the comma



4341
4342
4343
# File 'lib/syntax_tree/node.rb', line 4341

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



4352
4353
4354
# File 'lib/syntax_tree/node.rb', line 4352

def accept(visitor)
  visitor.visit_excessed_comma(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



4356
4357
4358
# File 'lib/syntax_tree/node.rb', line 4356

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



4362
4363
4364
# File 'lib/syntax_tree/node.rb', line 4362

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



4366
4367
4368
# File 'lib/syntax_tree/node.rb', line 4366

def format(q)
  q.text(value)
end