Class: SyntaxTree::ExcessedComma

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

ExcessedComma represents a trailing comma in a list of block parameters. It changes the block parameters such that they will destructure.

[[1, 2, 3], [2, 3, 4]].each do |first, second,|
end

In the above example, an ExcessedComma node would appear in the third position of the Params node that is used to declare that block. The third position typically represents a rest-type parameter, but in this case is used to indicate that a trailing comma was used.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ ExcessedComma

Returns a new instance of ExcessedComma.



4275
4276
4277
4278
4279
# File 'lib/syntax_tree/node.rb', line 4275

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



4273
4274
4275
# File 'lib/syntax_tree/node.rb', line 4273

def comments
  @comments
end

#valueObject (readonly)

String

the comma



4270
4271
4272
# File 'lib/syntax_tree/node.rb', line 4270

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



4281
4282
4283
# File 'lib/syntax_tree/node.rb', line 4281

def accept(visitor)
  visitor.visit_excessed_comma(self)
end

#child_nodesObject Also known as: deconstruct



4285
4286
4287
# File 'lib/syntax_tree/node.rb', line 4285

def child_nodes
  []
end

#deconstruct_keys(keys) ⇒ Object



4291
4292
4293
# File 'lib/syntax_tree/node.rb', line 4291

def deconstruct_keys(keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



4295
4296
4297
# File 'lib/syntax_tree/node.rb', line 4295

def format(q)
  q.text(value)
end