Class: SyntaxTree::ExcessedComma

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree.rb

Overview

ExcessedComma represents a trailing comma in a list of block parameters. It changes the block parameters such that they will destructure.

[[1, 2, 3], [2, 3, 4]].each do |first, second,|
end

In the above example, an ExcessedComma node would appear in the third position of the Params node that is used to declare that block. The third position typically represents a rest-type parameter, but in this case is used to indicate that a trailing comma was used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value:, location:, comments: []) ⇒ ExcessedComma

Returns a new instance of ExcessedComma.



5896
5897
5898
5899
5900
# File 'lib/syntax_tree.rb', line 5896

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



5894
5895
5896
# File 'lib/syntax_tree.rb', line 5894

def comments
  @comments
end

#locationObject (readonly)

Location

the location of this node



5891
5892
5893
# File 'lib/syntax_tree.rb', line 5891

def location
  @location
end

#valueObject (readonly)

String

the comma



5888
5889
5890
# File 'lib/syntax_tree.rb', line 5888

def value
  @value
end

Instance Method Details

#child_nodesObject



5902
5903
5904
# File 'lib/syntax_tree.rb', line 5902

def child_nodes
  []
end

#format(q) ⇒ Object



5906
5907
5908
# File 'lib/syntax_tree.rb', line 5906

def format(q)
  q.text(value)
end

#pretty_print(q) ⇒ Object



5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
# File 'lib/syntax_tree.rb', line 5910

def pretty_print(q)
  q.group(2, "(", ")") do
    q.text("excessed_comma")

    q.breakable
    q.pp(value)

    q.pp(Comment::List.new(comments))
  end
end

#to_json(*opts) ⇒ Object



5921
5922
5923
5924
5925
5926
5927
5928
# File 'lib/syntax_tree.rb', line 5921

def to_json(*opts)
  {
    type: :excessed_comma,
    value: value,
    loc: location,
    cmts: comments
  }.to_json(*opts)
end