Class: SyntaxTree::FCall

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree.rb

Overview

FCall represents the piece of a method call that comes before any arguments (i.e., just the name of the method). It is used in places where the parser is sure that it is a method call and not potentially a local variable.

method(argument)

In the above example, it’s referring to the method segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value:, arguments:, location:, comments: []) ⇒ FCall

Returns a new instance of FCall.



5962
5963
5964
5965
5966
5967
# File 'lib/syntax_tree.rb', line 5962

def initialize(value:, arguments:, location:, comments: [])
  @value = value
  @arguments = arguments
  @location = location
  @comments = comments
end

Instance Attribute Details

#argumentsObject (readonly)

nil | ArgParen | Args

the arguments to the method call



5954
5955
5956
# File 'lib/syntax_tree.rb', line 5954

def arguments
  @arguments
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



5960
5961
5962
# File 'lib/syntax_tree.rb', line 5960

def comments
  @comments
end

#locationObject (readonly)

Location

the location of this node



5957
5958
5959
# File 'lib/syntax_tree.rb', line 5957

def location
  @location
end

#valueObject (readonly)

Const | Ident

the name of the method



5951
5952
5953
# File 'lib/syntax_tree.rb', line 5951

def value
  @value
end

Instance Method Details

#child_nodesObject



5969
5970
5971
# File 'lib/syntax_tree.rb', line 5969

def child_nodes
  [value, arguments]
end

#format(q) ⇒ Object



5973
5974
5975
5976
# File 'lib/syntax_tree.rb', line 5973

def format(q)
  q.format(value)
  q.format(arguments)
end

#pretty_print(q) ⇒ Object



5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
# File 'lib/syntax_tree.rb', line 5978

def pretty_print(q)
  q.group(2, "(", ")") do
    q.text("fcall")

    q.breakable
    q.pp(value)

    if arguments
      q.breakable
      q.pp(arguments)
    end

    q.pp(Comment::List.new(comments))
  end
end

#to_json(*opts) ⇒ Object



5994
5995
5996
5997
5998
5999
6000
6001
6002
# File 'lib/syntax_tree.rb', line 5994

def to_json(*opts)
  {
    type: :fcall,
    value: value,
    args: arguments,
    loc: location,
    cmts: comments
  }.to_json(*opts)
end