Module: SyntaxTree::HashKeyFormatter

Defined in:
lib/syntax_tree/node.rb

Overview

This module is responsible for formatting the assocs contained within a hash or bare hash. It first determines if every key in the hash can use labels. If it can, it uses labels. Otherwise it uses hash rockets.

Defined Under Namespace

Classes: Labels, Rockets

Class Method Summary collapse

Class Method Details

.for(container) ⇒ Object



1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
# File 'lib/syntax_tree/node.rb', line 1757

def self.for(container)
  labels =
    container.assocs.all? do |assoc|
      next true if assoc.is_a?(AssocSplat)

      case assoc.key
      when Label
        true
      when SymbolLiteral
        # When attempting to convert a hash rocket into a hash label,
        # you need to take care because only certain patterns are
        # allowed. Ruby source says that they have to match keyword
        # arguments to methods, but don't specify what that is. After
        # some experimentation, it looks like it's:
        value = assoc.key.value.value
        value.match?(/^[_A-Za-z]/) && !value.end_with?("=")
      when DynaSymbol
        true
      else
        false
      end
    end

  (labels ? Labels : Rockets).new
end