Module: SyntaxTree::HashKeyFormatter

Defined in:
lib/syntax_tree.rb

Overview

This module is responsible for formatting the assocs contained within a hash or bare hash. It first determines if every key in the hash can use labels. If it can, it uses labels. Otherwise it uses hash rockets.

Defined Under Namespace

Classes: Labels, Rockets

Class Method Summary collapse

Class Method Details

.for(container) ⇒ Object



2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
# File 'lib/syntax_tree.rb', line 2194

def self.for(container)
  labels =
    container.assocs.all? do |assoc|
      next true if assoc.is_a?(AssocSplat)

      case assoc.key
      when Label
        true
      when SymbolLiteral
        # When attempting to convert a hash rocket into a hash label,
        # you need to take care because only certain patterns are
        # allowed. Ruby source says that they have to match keyword
        # arguments to methods, but don't specify what that is. After
        # some experimentation, it looks like it's:
        value = assoc.key.value.value
        value.match?(/^[_A-Za-z]/) && !value.end_with?("=")
      when DynaSymbol
        true
      else
        false
      end
    end

  (labels ? Labels : Rockets).new
end