Class: SyntaxTree::Ident

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Ident represents an identifier anywhere in code. It can represent a very large number of things, depending on where it is in the syntax tree.

value

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ Ident

Returns a new instance of Ident.



5093
5094
5095
5096
5097
# File 'lib/syntax_tree/node.rb', line 5093

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



5091
5092
5093
# File 'lib/syntax_tree/node.rb', line 5091

def comments
  @comments
end

#value ⇒ Object (readonly)

[String] the value of the identifier



5088
5089
5090
# File 'lib/syntax_tree/node.rb', line 5088

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



5099
5100
5101
# File 'lib/syntax_tree/node.rb', line 5099

def accept(visitor)
  visitor.visit_ident(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



5103
5104
5105
# File 'lib/syntax_tree/node.rb', line 5103

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



5109
5110
5111
# File 'lib/syntax_tree/node.rb', line 5109

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



5113
5114
5115
# File 'lib/syntax_tree/node.rb', line 5113

def format(q)
  q.text(value)
end