Class: SyntaxTree::Ident
Overview
Ident represents an identifier anywhere in code. It can represent a very large number of things, depending on where it is in the syntax tree.
value
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- String
-
the value of the identifier.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ Ident
constructor
A new instance of Ident.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:, comments: []) ⇒ Ident
Returns a new instance of Ident.
5138 5139 5140 5141 5142 |
# File 'lib/syntax_tree/node.rb', line 5138 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
5136 5137 5138 |
# File 'lib/syntax_tree/node.rb', line 5136 def comments @comments end |
#value ⇒ Object (readonly)
- String
-
the value of the identifier
5133 5134 5135 |
# File 'lib/syntax_tree/node.rb', line 5133 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
5144 5145 5146 |
# File 'lib/syntax_tree/node.rb', line 5144 def accept(visitor) visitor.visit_ident(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
5148 5149 5150 |
# File 'lib/syntax_tree/node.rb', line 5148 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
5154 5155 5156 |
# File 'lib/syntax_tree/node.rb', line 5154 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
5158 5159 5160 |
# File 'lib/syntax_tree/node.rb', line 5158 def format(q) q.text(value) end |