Class: SyntaxTree::Kw
Overview
Kw represents the use of a keyword. It can be almost anywhere in the syntax tree, so you end up seeing it quite a lot.
if value
end
In the above example, there would be two Kw nodes: one for the if and one for the end. Note that anything that matches the list of keywords in Ruby will use a Kw, so if you use a keyword in a symbol literal for instance:
:if
then the contents of the symbol node will contain a Kw node.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#name ⇒ Object
readonly
- Symbol
-
the symbol version of the value.
-
#value ⇒ Object
readonly
- String
-
the value of the keyword.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:) ⇒ Kw
constructor
A new instance of Kw.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ Kw
Returns a new instance of Kw.
6830 6831 6832 6833 6834 6835 |
# File 'lib/syntax_tree/node.rb', line 6830 def initialize(value:, location:) @value = value @name = value.to_sym @location = location @comments = [] end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
6828 6829 6830 |
# File 'lib/syntax_tree/node.rb', line 6828 def comments @comments end |
#name ⇒ Object (readonly)
- Symbol
-
the symbol version of the value
6825 6826 6827 |
# File 'lib/syntax_tree/node.rb', line 6825 def name @name end |
#value ⇒ Object (readonly)
- String
-
the value of the keyword
6822 6823 6824 |
# File 'lib/syntax_tree/node.rb', line 6822 def value @value end |
Instance Method Details
#===(other) ⇒ Object
6863 6864 6865 |
# File 'lib/syntax_tree/node.rb', line 6863 def ===(other) other.is_a?(Kw) && value === other.value end |
#accept(visitor) ⇒ Object
6837 6838 6839 |
# File 'lib/syntax_tree/node.rb', line 6837 def accept(visitor) visitor.visit_kw(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
6841 6842 6843 |
# File 'lib/syntax_tree/node.rb', line 6841 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
6845 6846 6847 6848 6849 6850 6851 |
# File 'lib/syntax_tree/node.rb', line 6845 def copy(value: nil, location: nil) node = Kw.new(value: value || self.value, location: location || self.location) node.comments.concat(comments.map(&:copy)) node end |
#deconstruct_keys(_keys) ⇒ Object
6855 6856 6857 |
# File 'lib/syntax_tree/node.rb', line 6855 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
6859 6860 6861 |
# File 'lib/syntax_tree/node.rb', line 6859 def format(q) q.text(value) end |