Class: SyntaxTree::Kw
Overview
Kw represents the use of a keyword. It can be almost anywhere in the syntax tree, so you end up seeing it quite a lot.
if value
end
In the above example, there would be two Kw nodes: one for the if and one for the end. Note that anything that matches the list of keywords in Ruby will use a Kw, so if you use a keyword in a symbol literal for instance:
:if
then the contents of the symbol node will contain a Kw node.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#value ⇒ Object
readonly
[String] the value of the keyword.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ Kw
constructor
A new instance of Kw.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:, comments: []) ⇒ Kw
Returns a new instance of Kw.
5771 5772 5773 5774 5775 |
# File 'lib/syntax_tree/node.rb', line 5771 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
5769 5770 5771 |
# File 'lib/syntax_tree/node.rb', line 5769 def comments @comments end |
#value ⇒ Object (readonly)
[String] the value of the keyword
5766 5767 5768 |
# File 'lib/syntax_tree/node.rb', line 5766 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
5777 5778 5779 |
# File 'lib/syntax_tree/node.rb', line 5777 def accept(visitor) visitor.visit_kw(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
5781 5782 5783 |
# File 'lib/syntax_tree/node.rb', line 5781 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
5787 5788 5789 |
# File 'lib/syntax_tree/node.rb', line 5787 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
5791 5792 5793 |
# File 'lib/syntax_tree/node.rb', line 5791 def format(q) q.text(value) end |