Class: SyntaxTree::LBrace
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::LBrace
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
LBrace represents the use of a left brace, i.e., {.
Instance Attribute Summary collapse
Attributes inherited from Node
#location
Class Method Summary
collapse
-
.default ⇒ Object
Because some nodes keep around a { token so that comments can be attached to it if they occur in the source, oftentimes an LBrace is a child of another node. This means it’s required at initialization time. To make it easier to create LBrace nodes without any specific value, this method provides a default node..
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(value:, location:) ⇒ LBrace
7339
7340
7341
7342
7343
|
# File 'lib/syntax_tree/node.rb', line 7339
def initialize(value:, location:)
@value = value
@location = location
= []
end
|
Instance Attribute Details
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
7337
7338
7339
|
# File 'lib/syntax_tree/node.rb', line 7337
def
end
|
#value ⇒ Object
7334
7335
7336
|
# File 'lib/syntax_tree/node.rb', line 7334
def value
@value
end
|
Class Method Details
.default ⇒ Object
Because some nodes keep around a { token so that comments can be attached to it if they occur in the source, oftentimes an LBrace is a child of another node. This means it’s required at initialization time. To make it easier to create LBrace nodes without any specific value, this method provides a default node.
7383
7384
7385
|
# File 'lib/syntax_tree/node.rb', line 7383
def self.default
new(value: "{", location: Location.default)
end
|
Instance Method Details
#===(other) ⇒ Object
7374
7375
7376
|
# File 'lib/syntax_tree/node.rb', line 7374
def ===(other)
other.is_a?(LBrace) && value === other.value
end
|
#accept(visitor) ⇒ Object
7345
7346
7347
|
# File 'lib/syntax_tree/node.rb', line 7345
def accept(visitor)
visitor.visit_lbrace(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
7349
7350
7351
|
# File 'lib/syntax_tree/node.rb', line 7349
def child_nodes
[]
end
|
#copy(value: nil, location: nil) ⇒ Object
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
|
# File 'lib/syntax_tree/node.rb', line 7353
def copy(value: nil, location: nil)
node =
LBrace.new(
value: value || self.value,
location: location || self.location
)
node..concat(.map(&:copy))
node
end
|
#deconstruct_keys(_keys) ⇒ Object
7366
7367
7368
|
# File 'lib/syntax_tree/node.rb', line 7366
def deconstruct_keys(_keys)
{ value: value, location: location, comments: }
end
|
7370
7371
7372
|
# File 'lib/syntax_tree/node.rb', line 7370
def format(q)
q.text(value)
end
|