Class: SyntaxTree::LBrace
Overview
LBrace represents the use of a left brace, i.e., {.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- String
-
the left brace.
Attributes inherited from Node
Class Method Summary collapse
-
.default ⇒ Object
Because some nodes keep around a { token so that comments can be attached to it if they occur in the source, oftentimes an LBrace is a child of another node. This means it’s required at initialization time. To make it easier to create LBrace nodes without any specific value, this method provides a default node..
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:) ⇒ LBrace
constructor
A new instance of LBrace.
Methods inherited from Node
#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(value:, location:) ⇒ LBrace
Returns a new instance of LBrace.
7282 7283 7284 7285 7286 |
# File 'lib/syntax_tree/node.rb', line 7282 def initialize(value:, location:) @value = value @location = location @comments = [] end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
7280 7281 7282 |
# File 'lib/syntax_tree/node.rb', line 7280 def comments @comments end |
#value ⇒ Object (readonly)
- String
-
the left brace
7277 7278 7279 |
# File 'lib/syntax_tree/node.rb', line 7277 def value @value end |
Class Method Details
.default ⇒ Object
Because some nodes keep around a { token so that comments can be attached to it if they occur in the source, oftentimes an LBrace is a child of another node. This means it’s required at initialization time. To make it easier to create LBrace nodes without any specific value, this method provides a default node.
7326 7327 7328 |
# File 'lib/syntax_tree/node.rb', line 7326 def self.default new(value: "{", location: Location.default) end |
Instance Method Details
#===(other) ⇒ Object
7317 7318 7319 |
# File 'lib/syntax_tree/node.rb', line 7317 def ===(other) other.is_a?(LBrace) && value === other.value end |
#accept(visitor) ⇒ Object
7288 7289 7290 |
# File 'lib/syntax_tree/node.rb', line 7288 def accept(visitor) visitor.visit_lbrace(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
7292 7293 7294 |
# File 'lib/syntax_tree/node.rb', line 7292 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
7296 7297 7298 7299 7300 7301 7302 7303 7304 7305 |
# File 'lib/syntax_tree/node.rb', line 7296 def copy(value: nil, location: nil) node = LBrace.new( value: value || self.value, location: location || self.location ) node.comments.concat(comments.map(&:copy)) node end |
#deconstruct_keys(_keys) ⇒ Object
7309 7310 7311 |
# File 'lib/syntax_tree/node.rb', line 7309 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
7313 7314 7315 |
# File 'lib/syntax_tree/node.rb', line 7313 def format(q) q.text(value) end |