Class: SyntaxTree::LBracket
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::LBracket
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
LBracket represents the use of a left bracket, i.e., [.
Instance Attribute Summary collapse
Attributes inherited from Node
#location
Class Method Summary
collapse
-
.default ⇒ Object
Because some nodes keep around a [ token so that comments can be attached to it if they occur in the source, oftentimes an LBracket is a child of another node. This means it’s required at initialization time. To make it easier to create LBracket nodes without any specific value, this method provides a default node..
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ LBracket
7279
7280
7281
7282
7283
|
# File 'lib/syntax_tree/node.rb', line 7279
def initialize(value:, location:)
@value = value
@location = location
= []
end
|
Instance Attribute Details
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
7277
7278
7279
|
# File 'lib/syntax_tree/node.rb', line 7277
def
end
|
#value ⇒ Object
7274
7275
7276
|
# File 'lib/syntax_tree/node.rb', line 7274
def value
@value
end
|
Class Method Details
.default ⇒ Object
Because some nodes keep around a [ token so that comments can be attached to it if they occur in the source, oftentimes an LBracket is a child of another node. This means it’s required at initialization time. To make it easier to create LBracket nodes without any specific value, this method provides a default node.
7323
7324
7325
|
# File 'lib/syntax_tree/node.rb', line 7323
def self.default
new(value: "[", location: Location.default)
end
|
Instance Method Details
#===(other) ⇒ Object
7314
7315
7316
|
# File 'lib/syntax_tree/node.rb', line 7314
def ===(other)
other.is_a?(LBracket) && value === other.value
end
|
#accept(visitor) ⇒ Object
7285
7286
7287
|
# File 'lib/syntax_tree/node.rb', line 7285
def accept(visitor)
visitor.visit_lbracket(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
7289
7290
7291
|
# File 'lib/syntax_tree/node.rb', line 7289
def child_nodes
[]
end
|
#copy(value: nil, location: nil) ⇒ Object
7293
7294
7295
7296
7297
7298
7299
7300
7301
7302
|
# File 'lib/syntax_tree/node.rb', line 7293
def copy(value: nil, location: nil)
node =
LBracket.new(
value: value || self.value,
location: location || self.location
)
node..concat(.map(&:copy))
node
end
|
#deconstruct_keys(_keys) ⇒ Object
7306
7307
7308
|
# File 'lib/syntax_tree/node.rb', line 7306
def deconstruct_keys(_keys)
{ value: value, location: location, comments: }
end
|
7310
7311
7312
|
# File 'lib/syntax_tree/node.rb', line 7310
def format(q)
q.text(value)
end
|