Class: SyntaxTree::LBracket
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::LBracket
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
LBracket represents the use of a left bracket, i.e., [.
Instance Attribute Summary collapse
Attributes inherited from Node
#location
Class Method Summary
collapse
-
.default ⇒ Object
Because some nodes keep around a [ token so that comments can be attached to it if they occur in the source, oftentimes an LBracket is a child of another node. This means it’s required at initialization time. To make it easier to create LBracket nodes without any specific value, this method provides a default node..
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ LBracket
7276
7277
7278
7279
7280
|
# File 'lib/syntax_tree/node.rb', line 7276
def initialize(value:, location:)
@value = value
@location = location
= []
end
|
Instance Attribute Details
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
7274
7275
7276
|
# File 'lib/syntax_tree/node.rb', line 7274
def
end
|
#value ⇒ Object
7271
7272
7273
|
# File 'lib/syntax_tree/node.rb', line 7271
def value
@value
end
|
Class Method Details
.default ⇒ Object
Because some nodes keep around a [ token so that comments can be attached to it if they occur in the source, oftentimes an LBracket is a child of another node. This means it’s required at initialization time. To make it easier to create LBracket nodes without any specific value, this method provides a default node.
7320
7321
7322
|
# File 'lib/syntax_tree/node.rb', line 7320
def self.default
new(value: "[", location: Location.default)
end
|
Instance Method Details
#===(other) ⇒ Object
7311
7312
7313
|
# File 'lib/syntax_tree/node.rb', line 7311
def ===(other)
other.is_a?(LBracket) && value === other.value
end
|
#accept(visitor) ⇒ Object
7282
7283
7284
|
# File 'lib/syntax_tree/node.rb', line 7282
def accept(visitor)
visitor.visit_lbracket(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
7286
7287
7288
|
# File 'lib/syntax_tree/node.rb', line 7286
def child_nodes
[]
end
|
#copy(value: nil, location: nil) ⇒ Object
7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
|
# File 'lib/syntax_tree/node.rb', line 7290
def copy(value: nil, location: nil)
node =
LBracket.new(
value: value || self.value,
location: location || self.location
)
node..concat(.map(&:copy))
node
end
|
#deconstruct_keys(_keys) ⇒ Object
7303
7304
7305
|
# File 'lib/syntax_tree/node.rb', line 7303
def deconstruct_keys(_keys)
{ value: value, location: location, comments: }
end
|
7307
7308
7309
|
# File 'lib/syntax_tree/node.rb', line 7307
def format(q)
q.text(value)
end
|