Class: SyntaxTree::Label

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Label represents the use of an identifier to associate with an object. You can find it in a hash key, as in:

{ key: value }

In this case “key:” would be the body of the label. You can also find it in pattern matching, as in:

case value
in key:
end

In this case “key:” would be the body of the label.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ Label

Returns a new instance of Label.



6938
6939
6940
6941
6942
# File 'lib/syntax_tree/node.rb', line 6938

def initialize(value:, location:)
  @value = value
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



6936
6937
6938
# File 'lib/syntax_tree/node.rb', line 6936

def comments
  @comments
end

#valueObject (readonly)

String

the value of the label



6933
6934
6935
# File 'lib/syntax_tree/node.rb', line 6933

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



6973
6974
6975
# File 'lib/syntax_tree/node.rb', line 6973

def ===(other)
  other.is_a?(Label) && value === other.value
end

#accept(visitor) ⇒ Object



6944
6945
6946
# File 'lib/syntax_tree/node.rb', line 6944

def accept(visitor)
  visitor.visit_label(self)
end

#child_nodesObject Also known as: deconstruct



6948
6949
6950
# File 'lib/syntax_tree/node.rb', line 6948

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



6952
6953
6954
6955
6956
6957
6958
6959
6960
6961
# File 'lib/syntax_tree/node.rb', line 6952

def copy(value: nil, location: nil)
  node =
    Label.new(
      value: value || self.value,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



6965
6966
6967
# File 'lib/syntax_tree/node.rb', line 6965

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



6969
6970
6971
# File 'lib/syntax_tree/node.rb', line 6969

def format(q)
  q.text(value)
end