Class: SyntaxTree::Label

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Label represents the use of an identifier to associate with an object. You can find it in a hash key, as in:

{ key: value }

In this case "key:" would be the body of the label. You can also find it in pattern matching, as in:

case value
in key:
end

In this case "key:" would be the body of the label.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ Label

Returns a new instance of Label.



5854
5855
5856
5857
5858
# File 'lib/syntax_tree/node.rb', line 5854

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



5852
5853
5854
# File 'lib/syntax_tree/node.rb', line 5852

def comments
  @comments
end

#value ⇒ Object (readonly)

[String] the value of the label



5849
5850
5851
# File 'lib/syntax_tree/node.rb', line 5849

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



5860
5861
5862
# File 'lib/syntax_tree/node.rb', line 5860

def accept(visitor)
  visitor.visit_label(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



5864
5865
5866
# File 'lib/syntax_tree/node.rb', line 5864

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



5870
5871
5872
# File 'lib/syntax_tree/node.rb', line 5870

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



5874
5875
5876
# File 'lib/syntax_tree/node.rb', line 5874

def format(q)
  q.text(value)
end