Class: SyntaxTree::Label
Overview
Label represents the use of an identifier to associate with an object. You can find it in a hash key, as in:
{ key: value }
In this case “key:” would be the body of the label. You can also find it in pattern matching, as in:
case value
in key:
end
In this case “key:” would be the body of the label.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- String
-
the value of the label.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ Label
constructor
A new instance of Label.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:, comments: []) ⇒ Label
Returns a new instance of Label.
5898 5899 5900 5901 5902 |
# File 'lib/syntax_tree/node.rb', line 5898 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
5896 5897 5898 |
# File 'lib/syntax_tree/node.rb', line 5896 def comments @comments end |
#value ⇒ Object (readonly)
- String
-
the value of the label
5893 5894 5895 |
# File 'lib/syntax_tree/node.rb', line 5893 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
5904 5905 5906 |
# File 'lib/syntax_tree/node.rb', line 5904 def accept(visitor) visitor.visit_label(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
5908 5909 5910 |
# File 'lib/syntax_tree/node.rb', line 5908 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
5914 5915 5916 |
# File 'lib/syntax_tree/node.rb', line 5914 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
5918 5919 5920 |
# File 'lib/syntax_tree/node.rb', line 5918 def format(q) q.text(value) end |