Class: SyntaxTree::Label
Overview
Label represents the use of an identifier to associate with an object. You can find it in a hash key, as in:
{ key: value }
In this case “key:” would be the body of the label. You can also find it in pattern matching, as in:
case value
in key:
end
In this case “key:” would be the body of the label.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- String
-
the value of the label.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ Label
constructor
A new instance of Label.
Methods inherited from Node
Constructor Details
#initialize(value:, location:, comments: []) ⇒ Label
Returns a new instance of Label.
5736 5737 5738 5739 5740 |
# File 'lib/syntax_tree/node.rb', line 5736 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
5734 5735 5736 |
# File 'lib/syntax_tree/node.rb', line 5734 def comments @comments end |
#value ⇒ Object (readonly)
- String
-
the value of the label
5731 5732 5733 |
# File 'lib/syntax_tree/node.rb', line 5731 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
5742 5743 5744 |
# File 'lib/syntax_tree/node.rb', line 5742 def accept(visitor) visitor.visit_label(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
5746 5747 5748 |
# File 'lib/syntax_tree/node.rb', line 5746 def child_nodes [] end |
#deconstruct_keys(keys) ⇒ Object
5752 5753 5754 |
# File 'lib/syntax_tree/node.rb', line 5752 def deconstruct_keys(keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
5756 5757 5758 |
# File 'lib/syntax_tree/node.rb', line 5756 def format(q) q.text(value) end |