Class: SyntaxTree::LoopFormatter
- Inherits:
-
Object
- Object
- SyntaxTree::LoopFormatter
- Defined in:
- lib/syntax_tree.rb
Overview
Formats an Until, UntilMod, While, or WhileMod node.
Instance Attribute Summary collapse
-
#keyword ⇒ Object
readonly
- String
-
the name of the keyword used for this loop.
-
#node ⇒ Object
readonly
- Until | UntilMod | While | WhileMod
-
the node that is being formatted.
-
#statements ⇒ Object
readonly
- untyped
-
the statements associated with the node.
Instance Method Summary collapse
- #format(q) ⇒ Object
-
#initialize(keyword, node, statements) ⇒ LoopFormatter
constructor
A new instance of LoopFormatter.
Constructor Details
#initialize(keyword, node, statements) ⇒ LoopFormatter
Returns a new instance of LoopFormatter.
12626 12627 12628 12629 12630 |
# File 'lib/syntax_tree.rb', line 12626 def initialize(keyword, node, statements) @keyword = keyword @node = node @statements = statements end |
Instance Attribute Details
#keyword ⇒ Object (readonly)
- String
-
the name of the keyword used for this loop
12618 12619 12620 |
# File 'lib/syntax_tree.rb', line 12618 def keyword @keyword end |
#node ⇒ Object (readonly)
- Until | UntilMod | While | WhileMod
-
the node that is being formatted
12621 12622 12623 |
# File 'lib/syntax_tree.rb', line 12621 def node @node end |
#statements ⇒ Object (readonly)
- untyped
-
the statements associated with the node
12624 12625 12626 |
# File 'lib/syntax_tree.rb', line 12624 def statements @statements end |
Instance Method Details
#format(q) ⇒ Object
12632 12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 12644 12645 12646 12647 12648 |
# File 'lib/syntax_tree.rb', line 12632 def format(q) if ContainsAssignment.call(node.predicate) format_break(q) q.break_parent return end q.group do q.if_break { format_break(q) }.if_flat do Parentheses.flat(q) do q.format(statements) q.text(" #{keyword} ") q.format(node.predicate) end end end end |