Class: SyntaxTree::MAssign

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

MAssign is a parent node of any kind of multiple assignment. This includes splitting out variables on the left like:

first, second, third = value

as well as splitting out variables on the right, as in:

value = first, second, third

Both sides support splats, as well as variables following them. There’s also destructuring behavior that you can achieve with the following:

first, = value

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(target:, value:, location:) ⇒ MAssign

Returns a new instance of MAssign.



7409
7410
7411
7412
7413
7414
# File 'lib/syntax_tree/node.rb', line 7409

def initialize(target:, value:, location:)
  @target = target
  @value = value
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



7407
7408
7409
# File 'lib/syntax_tree/node.rb', line 7407

def comments
  @comments
end

#targetObject (readonly)

MLHS | MLHSParen

the target of the multiple assignment



7401
7402
7403
# File 'lib/syntax_tree/node.rb', line 7401

def target
  @target
end

#valueObject (readonly)

untyped

the value being assigned



7404
7405
7406
# File 'lib/syntax_tree/node.rb', line 7404

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



7453
7454
7455
# File 'lib/syntax_tree/node.rb', line 7453

def ===(other)
  other.is_a?(MAssign) && target === other.target && value === other.value
end

#accept(visitor) ⇒ Object



7416
7417
7418
# File 'lib/syntax_tree/node.rb', line 7416

def accept(visitor)
  visitor.visit_massign(self)
end

#child_nodesObject Also known as: deconstruct



7420
7421
7422
# File 'lib/syntax_tree/node.rb', line 7420

def child_nodes
  [target, value]
end

#copy(target: nil, value: nil, location: nil) ⇒ Object



7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
# File 'lib/syntax_tree/node.rb', line 7424

def copy(target: nil, value: nil, location: nil)
  node =
    MAssign.new(
      target: target || self.target,
      value: value || self.value,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



7438
7439
7440
# File 'lib/syntax_tree/node.rb', line 7438

def deconstruct_keys(_keys)
  { target: target, value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
# File 'lib/syntax_tree/node.rb', line 7442

def format(q)
  q.group do
    q.group { q.format(target) }
    q.text(" =")
    q.indent do
      q.breakable_space
      q.format(value)
    end
  end
end