Class: SyntaxTree::MLHS

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

MLHS represents a list of values being destructured on the left-hand side of a multiple assignment.

first, second, third = value

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#pretty_print, #to_json

Constructor Details

#initialize(parts:, comma: false, location:, comments: []) ⇒ MLHS

Returns a new instance of MLHS.



6094
6095
6096
6097
6098
6099
# File 'lib/syntax_tree/node.rb', line 6094

def initialize(parts:, comma: false, location:, comments: [])
  @parts = parts
  @comma = comma
  @location = location
  @comments = comments
end

Instance Attribute Details

#commaObject

boolean

whether or not there is a trailing comma at the end of this

list, which impacts destructuring. It’s an attr_accessor so that while the syntax tree is being built it can be set by its parent node



6089
6090
6091
# File 'lib/syntax_tree/node.rb', line 6089

def comma
  @comma
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



6092
6093
6094
# File 'lib/syntax_tree/node.rb', line 6092

def comments
  @comments
end

#partsObject (readonly)

Array[ARefField | ArgStar | Field | Ident | MLHSParen | VarField] the parts of the left-hand side of a multiple assignment



6084
6085
6086
# File 'lib/syntax_tree/node.rb', line 6084

def parts
  @parts
end

Instance Method Details

#accept(visitor) ⇒ Object



6101
6102
6103
# File 'lib/syntax_tree/node.rb', line 6101

def accept(visitor)
  visitor.visit_mlhs(self)
end

#child_nodesObject Also known as: deconstruct



6105
6106
6107
# File 'lib/syntax_tree/node.rb', line 6105

def child_nodes
  parts
end

#deconstruct_keys(keys) ⇒ Object



6111
6112
6113
# File 'lib/syntax_tree/node.rb', line 6111

def deconstruct_keys(keys)
  { parts: parts, location: location, comma: comma, comments: comments }
end

#format(q) ⇒ Object



6115
6116
6117
6118
# File 'lib/syntax_tree/node.rb', line 6115

def format(q)
  q.seplist(parts) { |part| q.format(part) }
  q.text(",") if comma
end