Method: SyntaxTree::MLHS#comma
- Defined in:
- lib/syntax_tree/node.rb
#comma ⇒ Object
- boolean
-
whether or not there is a trailing comma at the end of this
list, which impacts destructuring. It’s an attr_accessor so that while the syntax tree is being built it can be set by its parent node
6982 6983 6984 |
# File 'lib/syntax_tree/node.rb', line 6982 def comma @comma end |