Class: SyntaxTree::MethodAddBlock

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

MethodAddBlock represents a method call with a block argument.

method {}

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#pretty_print, #to_json

Constructor Details

#initialize(call:, block:, location:, comments: []) ⇒ MethodAddBlock

Returns a new instance of MethodAddBlock.



6038
6039
6040
6041
6042
6043
# File 'lib/syntax_tree/node.rb', line 6038

def initialize(call:, block:, location:, comments: [])
  @call = call
  @block = block
  @location = location
  @comments = comments
end

Instance Attribute Details

#blockObject (readonly)

BraceBlock | DoBlock

the block being sent with the method call



6033
6034
6035
# File 'lib/syntax_tree/node.rb', line 6033

def block
  @block
end

#callObject (readonly)

Call | Command | CommandCall | FCall

the method call



6030
6031
6032
# File 'lib/syntax_tree/node.rb', line 6030

def call
  @call
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



6036
6037
6038
# File 'lib/syntax_tree/node.rb', line 6036

def comments
  @comments
end

Instance Method Details

#accept(visitor) ⇒ Object



6045
6046
6047
# File 'lib/syntax_tree/node.rb', line 6045

def accept(visitor)
  visitor.visit_method_add_block(self)
end

#child_nodesObject Also known as: deconstruct



6049
6050
6051
# File 'lib/syntax_tree/node.rb', line 6049

def child_nodes
  [call, block]
end

#deconstruct_keys(keys) ⇒ Object



6055
6056
6057
# File 'lib/syntax_tree/node.rb', line 6055

def deconstruct_keys(keys)
  { call: call, block: block, location: location, comments: comments }
end

#format(q) ⇒ Object



6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
# File 'lib/syntax_tree/node.rb', line 6059

def format(q)
  # If we're at the top of a call chain, then we're going to do some
  # specialized printing in case we can print it nicely. We _only_ do this
  # at the top of the chain to avoid weird recursion issues.
  if !CallChainFormatter.chained?(q.parent) && CallChainFormatter.chained?(call)
    q.group { q.if_break { CallChainFormatter.new(self).format(q) }.if_flat { format_contents(q) } }
  else
    format_contents(q)
  end
end

#format_contents(q) ⇒ Object



6070
6071
6072
6073
# File 'lib/syntax_tree/node.rb', line 6070

def format_contents(q)
  q.format(call)
  q.format(block)
end