Class: SyntaxTree::Next
Overview
Next represents using the next keyword.
next
The next keyword can also optionally be called with an argument:
next value
next can even be called with multiple arguments, but only if parentheses
are omitted, as in:
next first, second, third
If a single value is being given, parentheses can be used, as in:
next(value)
Instance Attribute Summary collapse
-
#arguments ⇒ Object
readonly
[Args] the arguments passed to the next keyword.
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(arguments:, location:, comments: []) ⇒ Next
constructor
A new instance of Next.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(arguments:, location:, comments: []) ⇒ Next
Returns a new instance of Next.
6512 6513 6514 6515 6516 |
# File 'lib/syntax_tree/node.rb', line 6512 def initialize(arguments:, location:, comments: []) @arguments = arguments @location = location @comments = comments end |
Instance Attribute Details
#arguments ⇒ Object (readonly)
[Args] the arguments passed to the next keyword
6507 6508 6509 |
# File 'lib/syntax_tree/node.rb', line 6507 def arguments @arguments end |
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
6510 6511 6512 |
# File 'lib/syntax_tree/node.rb', line 6510 def comments @comments end |
Instance Method Details
#accept(visitor) ⇒ Object
6518 6519 6520 |
# File 'lib/syntax_tree/node.rb', line 6518 def accept(visitor) visitor.visit_next(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
6522 6523 6524 |
# File 'lib/syntax_tree/node.rb', line 6522 def child_nodes [arguments] end |
#deconstruct_keys(_keys) ⇒ Object
6528 6529 6530 |
# File 'lib/syntax_tree/node.rb', line 6528 def deconstruct_keys(_keys) { arguments: arguments, location: location, comments: comments } end |
#format(q) ⇒ Object
6532 6533 6534 |
# File 'lib/syntax_tree/node.rb', line 6532 def format(q) FlowControlFormatter.new("next", self).format(q) end |