Class: SyntaxTree::Next
Overview
Next represents using the next keyword.
next
The next keyword can also optionally be called with an argument:
next value
next can even be called with multiple arguments, but only if parentheses are omitted, as in:
next first, second, third
If a single value is being given, parentheses can be used, as in:
next(value)
Instance Attribute Summary collapse
-
#arguments ⇒ Object
readonly
- Args
-
the arguments passed to the next keyword.
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(arguments:, location:, comments: []) ⇒ Next
constructor
A new instance of Next.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(arguments:, location:, comments: []) ⇒ Next
Returns a new instance of Next.
6480 6481 6482 6483 6484 |
# File 'lib/syntax_tree/node.rb', line 6480 def initialize(arguments:, location:, comments: []) @arguments = arguments @location = location @comments = comments end |
Instance Attribute Details
#arguments ⇒ Object (readonly)
- Args
-
the arguments passed to the next keyword
6475 6476 6477 |
# File 'lib/syntax_tree/node.rb', line 6475 def arguments @arguments end |
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
6478 6479 6480 |
# File 'lib/syntax_tree/node.rb', line 6478 def comments @comments end |
Instance Method Details
#accept(visitor) ⇒ Object
6486 6487 6488 |
# File 'lib/syntax_tree/node.rb', line 6486 def accept(visitor) visitor.visit_next(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
6490 6491 6492 |
# File 'lib/syntax_tree/node.rb', line 6490 def child_nodes [arguments] end |
#deconstruct_keys(_keys) ⇒ Object
6496 6497 6498 |
# File 'lib/syntax_tree/node.rb', line 6496 def deconstruct_keys(_keys) { arguments: arguments, location: location, comments: comments } end |
#format(q) ⇒ Object
6500 6501 6502 |
# File 'lib/syntax_tree/node.rb', line 6500 def format(q) FlowControlFormatter.new("next", self).format(q) end |