Class: SyntaxTree::Next

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Next represents using the next keyword.

next

The next keyword can also optionally be called with an argument:

next value

next can even be called with multiple arguments, but only if parentheses are omitted, as in:

next first, second, third

If a single value is being given, parentheses can be used, as in:

next(value)

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#pretty_print, #to_json

Constructor Details

#initialize(arguments:, location:, comments: []) ⇒ Next

Returns a new instance of Next.



6311
6312
6313
6314
6315
# File 'lib/syntax_tree/node.rb', line 6311

def initialize(arguments:, location:, comments: [])
  @arguments = arguments
  @location = location
  @comments = comments
end

Instance Attribute Details

#argumentsObject (readonly)

Args

the arguments passed to the next keyword



6306
6307
6308
# File 'lib/syntax_tree/node.rb', line 6306

def arguments
  @arguments
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



6309
6310
6311
# File 'lib/syntax_tree/node.rb', line 6309

def comments
  @comments
end

Instance Method Details

#accept(visitor) ⇒ Object



6317
6318
6319
# File 'lib/syntax_tree/node.rb', line 6317

def accept(visitor)
  visitor.visit_next(self)
end

#child_nodesObject Also known as: deconstruct



6321
6322
6323
# File 'lib/syntax_tree/node.rb', line 6321

def child_nodes
  [arguments]
end

#deconstruct_keys(keys) ⇒ Object



6327
6328
6329
# File 'lib/syntax_tree/node.rb', line 6327

def deconstruct_keys(keys)
  { arguments: arguments, location: location, comments: comments }
end

#format(q) ⇒ Object



6331
6332
6333
# File 'lib/syntax_tree/node.rb', line 6331

def format(q)
  FlowControlFormatter.new("next", self).format(q)
end