Class: SyntaxTree::PinnedVarRef
Overview
PinnedVarRef represents a pinned variable reference within a pattern matching pattern.
case value
in ^variable
end
This can be a plain local variable like the example above. It can also be a a class variable, a global variable, or an instance variable.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#value ⇒ Object
readonly
[VarRef] the value of this node.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ PinnedVarRef
constructor
A new instance of PinnedVarRef.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:, comments: []) ⇒ PinnedVarRef
Returns a new instance of PinnedVarRef.
9526 9527 9528 9529 9530 |
# File 'lib/syntax_tree/node.rb', line 9526 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
9524 9525 9526 |
# File 'lib/syntax_tree/node.rb', line 9524 def comments @comments end |
#value ⇒ Object (readonly)
[VarRef] the value of this node
9521 9522 9523 |
# File 'lib/syntax_tree/node.rb', line 9521 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
9532 9533 9534 |
# File 'lib/syntax_tree/node.rb', line 9532 def accept(visitor) visitor.visit_pinned_var_ref(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9536 9537 9538 |
# File 'lib/syntax_tree/node.rb', line 9536 def child_nodes [value] end |
#deconstruct_keys(_keys) ⇒ Object
9542 9543 9544 |
# File 'lib/syntax_tree/node.rb', line 9542 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
9546 9547 9548 9549 9550 9551 |
# File 'lib/syntax_tree/node.rb', line 9546 def format(q) q.group do q.text("^") q.format(value) end end |