Class: SyntaxTree::Program
Overview
Program represents the overall syntax tree.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#statements ⇒ Object
readonly
[Statements] the top-level expressions of the program.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(statements:, location:, comments: []) ⇒ Program
constructor
A new instance of Program.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(statements:, location:, comments: []) ⇒ Program
Returns a new instance of Program.
7018 7019 7020 7021 7022 |
# File 'lib/syntax_tree/node.rb', line 7018 def initialize(statements:, location:, comments: []) @statements = statements @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
7016 7017 7018 |
# File 'lib/syntax_tree/node.rb', line 7016 def comments @comments end |
#statements ⇒ Object (readonly)
[Statements] the top-level expressions of the program
7013 7014 7015 |
# File 'lib/syntax_tree/node.rb', line 7013 def statements @statements end |
Instance Method Details
#accept(visitor) ⇒ Object
7024 7025 7026 |
# File 'lib/syntax_tree/node.rb', line 7024 def accept(visitor) visitor.visit_program(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
7028 7029 7030 |
# File 'lib/syntax_tree/node.rb', line 7028 def child_nodes [statements] end |
#deconstruct_keys(_keys) ⇒ Object
7034 7035 7036 |
# File 'lib/syntax_tree/node.rb', line 7034 def deconstruct_keys(_keys) { statements: statements, location: location, comments: comments } end |
#format(q) ⇒ Object
7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/syntax_tree/node.rb', line 7038 def format(q) q.format(statements) # We're going to put a newline on the end so that it always has one unless # it ends with the special __END__ syntax. In that case we want to # replicate the text exactly so we will just let it be. q.breakable(force: true) unless statements.body.last.is_a?(EndContent) end |