Class: SyntaxTree::Program
Overview
Program represents the overall syntax tree.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#statements ⇒ Object
readonly
- Statements
-
the top-level expressions of the program.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(statements:, location:, comments: []) ⇒ Program
constructor
A new instance of Program.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(statements:, location:, comments: []) ⇒ Program
Returns a new instance of Program.
6986 6987 6988 6989 6990 |
# File 'lib/syntax_tree/node.rb', line 6986 def initialize(statements:, location:, comments: []) @statements = statements @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
6984 6985 6986 |
# File 'lib/syntax_tree/node.rb', line 6984 def comments @comments end |
#statements ⇒ Object (readonly)
- Statements
-
the top-level expressions of the program
6981 6982 6983 |
# File 'lib/syntax_tree/node.rb', line 6981 def statements @statements end |
Instance Method Details
#accept(visitor) ⇒ Object
6992 6993 6994 |
# File 'lib/syntax_tree/node.rb', line 6992 def accept(visitor) visitor.visit_program(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
6996 6997 6998 |
# File 'lib/syntax_tree/node.rb', line 6996 def child_nodes [statements] end |
#deconstruct_keys(_keys) ⇒ Object
7002 7003 7004 |
# File 'lib/syntax_tree/node.rb', line 7002 def deconstruct_keys(_keys) { statements: statements, location: location, comments: comments } end |
#format(q) ⇒ Object
7006 7007 7008 7009 7010 7011 7012 7013 |
# File 'lib/syntax_tree/node.rb', line 7006 def format(q) q.format(statements) # We're going to put a newline on the end so that it always has one unless # it ends with the special __END__ syntax. In that case we want to # replicate the text exactly so we will just let it be. q.breakable(force: true) unless statements.body.last.is_a?(EndContent) end |