Class: SyntaxTree::QWordsBeg
Overview
QWordsBeg represents the beginning of a string literal array.
%w[one two three]
In the snippet above, QWordsBeg represents the “%w[” token. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %w| or %w<).
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the beginning of the array literal.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ QWordsBeg
constructor
A new instance of QWordsBeg.
Methods inherited from Node
#construct_keys, #end_char, #format, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(value:, location:) ⇒ QWordsBeg
Returns a new instance of QWordsBeg.
8814 8815 8816 8817 |
# File 'lib/syntax_tree/node.rb', line 8814 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the beginning of the array literal
8812 8813 8814 |
# File 'lib/syntax_tree/node.rb', line 8812 def value @value end |
Instance Method Details
#===(other) ⇒ Object
8840 8841 8842 |
# File 'lib/syntax_tree/node.rb', line 8840 def ===(other) other.is_a?(QWordsBeg) && value === other.value end |
#accept(visitor) ⇒ Object
8819 8820 8821 |
# File 'lib/syntax_tree/node.rb', line 8819 def accept(visitor) visitor.visit_qwords_beg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8823 8824 8825 |
# File 'lib/syntax_tree/node.rb', line 8823 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
8827 8828 8829 8830 8831 8832 |
# File 'lib/syntax_tree/node.rb', line 8827 def copy(value: nil, location: nil) QWordsBeg.new( value: value || self.value, location: location || self.location ) end |
#deconstruct_keys(_keys) ⇒ Object
8836 8837 8838 |
# File 'lib/syntax_tree/node.rb', line 8836 def deconstruct_keys(_keys) { value: value, location: location } end |