Class: SyntaxTree::QWordsBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

QWordsBeg represents the beginning of a string literal array.

%w[one two three]

In the snippet above, QWordsBeg represents the "%w[" token. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %w| or %w<).

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ QWordsBeg

Returns a new instance of QWordsBeg.



7210
7211
7212
7213
# File 'lib/syntax_tree/node.rb', line 7210

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#value ⇒ Object (readonly)

[String] the beginning of the array literal



7208
7209
7210
# File 'lib/syntax_tree/node.rb', line 7208

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



7215
7216
7217
# File 'lib/syntax_tree/node.rb', line 7215

def accept(visitor)
  visitor.visit_qwords_beg(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



7219
7220
7221
# File 'lib/syntax_tree/node.rb', line 7219

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



7225
7226
7227
# File 'lib/syntax_tree/node.rb', line 7225

def deconstruct_keys(_keys)
  { value: value, location: location }
end