Module: SyntaxTree::Quotes
- Defined in:
- lib/syntax_tree/node.rb
Overview
Responsible for providing information about quotes to be used for strings and dynamic symbols.
Constant Summary collapse
- PAIRS =
The matching pairs of quotes that can be used with % literals.
{ "(" => ")", "[" => "]", "{" => "}", "<" => ">" }.freeze
Class Method Summary collapse
-
.locked?(node, quote) ⇒ Boolean
If there is some part of this string that matches an escape sequence or that contains the interpolation pattern (“#{”), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.).
-
.matching(quote) ⇒ Object
Find the matching closing quote for the given opening quote.
-
.normalize(content, enclosing) ⇒ Object
Escape and unescape single and double quotes as needed to be able to enclose
contentwithenclosing.
Class Method Details
.locked?(node, quote) ⇒ Boolean
If there is some part of this string that matches an escape sequence or that contains the interpolation pattern (“#{”), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.)
4572 4573 4574 4575 4576 |
# File 'lib/syntax_tree/node.rb', line 4572 def self.locked?(node, quote) node.parts.any? do |part| !part.is_a?(TStringContent) || part.value.match?(/\\|#[@${]|#{quote}/) end end |
.matching(quote) ⇒ Object
Find the matching closing quote for the given opening quote.
4579 4580 4581 |
# File 'lib/syntax_tree/node.rb', line 4579 def self.matching(quote) PAIRS.fetch(quote) { quote } end |
.normalize(content, enclosing) ⇒ Object
Escape and unescape single and double quotes as needed to be able to enclose content with enclosing.
4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 |
# File 'lib/syntax_tree/node.rb', line 4585 def self.normalize(content, enclosing) return content if enclosing != "\"" && enclosing != "'" content.gsub(/\\([\s\S])|(['"])/) do _match, escaped, quote = Regexp.last_match.to_a if quote == enclosing "\\#{quote}" elsif quote quote else "\\#{escaped}" end end end |