Module: SyntaxTree::Quotes

Defined in:
lib/syntax_tree/node.rb

Overview

Responsible for providing information about quotes to be used for strings and dynamic symbols.

Constant Summary collapse

PAIRS =

The matching pairs of quotes that can be used with % literals.

{ "(" => ")", "[" => "]", "{" => "}", "<" => ">" }.freeze

Class Method Summary collapse

Class Method Details

.locked?(node) ⇒ Boolean

If there is some part of this string that matches an escape sequence or that contains the interpolation pattern (“#{”), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.)

Returns:

  • (Boolean)


3801
3802
3803
3804
3805
# File 'lib/syntax_tree/node.rb', line 3801

def self.locked?(node)
  node.parts.any? do |part|
    part.is_a?(TStringContent) && part.value.match?(/#[@${]|[\\]/)
  end
end

.matching(quote) ⇒ Object

Find the matching closing quote for the given opening quote.



3808
3809
3810
# File 'lib/syntax_tree/node.rb', line 3808

def self.matching(quote)
  PAIRS.fetch(quote) { quote }
end

.normalize(content, enclosing) ⇒ Object

Escape and unescape single and double quotes as needed to be able to enclose content with enclosing.



3814
3815
3816
3817
3818
3819
3820
3821
3822
3823
3824
3825
3826
3827
3828
# File 'lib/syntax_tree/node.rb', line 3814

def self.normalize(content, enclosing)
  return content if enclosing != "\"" && enclosing != "'"

  content.gsub(/\\([\s\S])|(['"])/) do
    _match, escaped, quote = Regexp.last_match.to_a

    if quote == enclosing
      "\\#{quote}"
    elsif quote
      quote
    else
      "\\#{escaped}"
    end
  end
end