Module: SyntaxTree::Quotes
- Defined in:
- lib/syntax_tree/node.rb
Overview
Responsible for providing information about quotes to be used for strings and dynamic symbols.
Constant Summary collapse
- PAIRS =
The matching pairs of quotes that can be used with % literals.
{ "(" => ")", "[" => "]", "{" => "}", "<" => ">" }.freeze
Class Method Summary collapse
-
.locked?(node) ⇒ Boolean
If there is some part of this string that matches an escape sequence or that contains the interpolation pattern ("#{"), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.).
-
.matching(quote) ⇒ Object
Find the matching closing quote for the given opening quote.
-
.normalize(content, enclosing) ⇒ Object
Escape and unescape single and double quotes as needed to be able to enclose
contentwithenclosing.
Class Method Details
.locked?(node) ⇒ Boolean
If there is some part of this string that matches an escape sequence or that contains the interpolation pattern ("#{"), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.)
4336 4337 4338 4339 4340 |
# File 'lib/syntax_tree/node.rb', line 4336 def self.locked?(node) node.parts.any? do |part| part.is_a?(TStringContent) && part.value.match?(/#[@${]|[\\]/) end end |
.matching(quote) ⇒ Object
Find the matching closing quote for the given opening quote.
4343 4344 4345 |
# File 'lib/syntax_tree/node.rb', line 4343 def self.matching(quote) PAIRS.fetch(quote) { quote } end |
.normalize(content, enclosing) ⇒ Object
Escape and unescape single and double quotes as needed to be able to
enclose content with enclosing.
4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 4363 |
# File 'lib/syntax_tree/node.rb', line 4349 def self.normalize(content, enclosing) return content if enclosing != "\"" && enclosing != "'" content.gsub(/\\([\s\S])|(['"])/) do _match, escaped, quote = Regexp.last_match.to_a if quote == enclosing "\\#{quote}" elsif quote quote else "\\#{escaped}" end end end |