Module: SyntaxTree::Quotes
- Defined in:
- lib/syntax_tree/node.rb
Overview
Responsible for providing information about quotes to be used for strings and dynamic symbols.
Constant Summary collapse
- PAIRS =
The matching pairs of quotes that can be used with % literals.
{ "(" => ")", "[" => "]", "{" => "}", "<" => ">" }.freeze
Class Method Summary collapse
-
.locked?(node) ⇒ Boolean
If there is some part of this string that matches an escape sequence or that contains the interpolation pattern (“#{”), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.).
-
.matching(quote) ⇒ Object
Find the matching closing quote for the given opening quote.
-
.normalize(content, enclosing) ⇒ Object
Escape and unescape single and double quotes as needed to be able to enclose
contentwithenclosing.
Class Method Details
.locked?(node) ⇒ Boolean
If there is some part of this string that matches an escape sequence or that contains the interpolation pattern (“#{”), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.)
4477 4478 4479 4480 4481 |
# File 'lib/syntax_tree/node.rb', line 4477 def self.locked?(node) node.parts.any? do |part| part.is_a?(TStringContent) && part.value.match?(/#[@${]|[\\]/) end end |
.matching(quote) ⇒ Object
Find the matching closing quote for the given opening quote.
4484 4485 4486 |
# File 'lib/syntax_tree/node.rb', line 4484 def self.matching(quote) PAIRS.fetch(quote) { quote } end |
.normalize(content, enclosing) ⇒ Object
Escape and unescape single and double quotes as needed to be able to enclose content with enclosing.
4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 |
# File 'lib/syntax_tree/node.rb', line 4490 def self.normalize(content, enclosing) return content if enclosing != "\"" && enclosing != "'" content.gsub(/\\([\s\S])|(['"])/) do _match, escaped, quote = Regexp.last_match.to_a if quote == enclosing "\\#{quote}" elsif quote quote else "\\#{escaped}" end end end |