Module: SyntaxTree::Quotes

Defined in:
lib/syntax_tree.rb

Overview

Responsible for providing information about quotes to be used for strings and dynamic symbols.

Constant Summary collapse

PAIRS =

The matching pairs of quotes that can be used with % literals.

{ "(" => ")", "[" => "]", "{" => "}", "<" => ">" }.freeze

Class Method Summary collapse

Class Method Details

.locked?(node) ⇒ Boolean

If there is some part of this string that matches an escape sequence or that contains the interpolation pattern (“#{”), then we are locked into whichever quote the user chose. (If they chose single quotes, then double quoting would activate the escape sequence, and if they chose double quotes, then single quotes would deactivate it.)

Returns:

  • (Boolean)


5236
5237
5238
5239
5240
# File 'lib/syntax_tree.rb', line 5236

def self.locked?(node)
  node.parts.any? do |part|
    part.is_a?(TStringContent) && part.value.match?(/#[@${]|[\\]/)
  end
end

.matching(quote) ⇒ Object

Find the matching closing quote for the given opening quote.



5243
5244
5245
# File 'lib/syntax_tree.rb', line 5243

def self.matching(quote)
  PAIRS.fetch(quote) { quote }
end

.normalize(content, enclosing) ⇒ Object

Escape and unescape single and double quotes as needed to be able to enclose content with enclosing.



5249
5250
5251
5252
5253
5254
5255
5256
5257
5258
5259
5260
5261
5262
5263
# File 'lib/syntax_tree.rb', line 5249

def self.normalize(content, enclosing)
  return content if enclosing != "\"" && enclosing != "'"

  content.gsub(/\\([\s\S])|(['"])/) do
    _match, escaped, quote = Regexp.last_match.to_a

    if quote == enclosing
      "\\#{quote}"
    elsif quote
      quote
    else
      "\\#{escaped}"
    end
  end
end