Class: SyntaxTree::RegexpBeg
Overview
RegexpBeg represents the start of a regular expression literal.
/.+/
In the example above, RegexpBeg represents the first / token. Regular expression literals can also be declared using the %r syntax, as in:
%r{.+}
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the beginning of the regular expression.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ RegexpBeg
constructor
A new instance of RegexpBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ RegexpBeg
Returns a new instance of RegexpBeg.
9007 9008 9009 9010 |
# File 'lib/syntax_tree/node.rb', line 9007 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the beginning of the regular expression
9005 9006 9007 |
# File 'lib/syntax_tree/node.rb', line 9005 def value @value end |
Instance Method Details
#===(other) ⇒ Object
9033 9034 9035 |
# File 'lib/syntax_tree/node.rb', line 9033 def ===(other) other.is_a?(RegexpBeg) && value === other.value end |
#accept(visitor) ⇒ Object
9012 9013 9014 |
# File 'lib/syntax_tree/node.rb', line 9012 def accept(visitor) visitor.visit_regexp_beg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9016 9017 9018 |
# File 'lib/syntax_tree/node.rb', line 9016 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
9020 9021 9022 9023 9024 9025 |
# File 'lib/syntax_tree/node.rb', line 9020 def copy(value: nil, location: nil) RegexpBeg.new( value: value || self.value, location: location || self.location ) end |
#deconstruct_keys(_keys) ⇒ Object
9029 9030 9031 |
# File 'lib/syntax_tree/node.rb', line 9029 def deconstruct_keys(_keys) { value: value, location: location } end |