Class: SyntaxTree::RegexpBeg

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree.rb

Overview

RegexpBeg represents the start of a regular expression literal.

/.+/

In the example above, RegexpBeg represents the first / token. Regular expression literals can also be declared using the %r syntax, as in:

%r{.+}

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value:, location:) ⇒ RegexpBeg

Returns a new instance of RegexpBeg.



10101
10102
10103
10104
# File 'lib/syntax_tree.rb', line 10101

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#locationObject (readonly)

Location

the location of this node



10099
10100
10101
# File 'lib/syntax_tree.rb', line 10099

def location
  @location
end

#valueObject (readonly)

String

the beginning of the regular expression



10096
10097
10098
# File 'lib/syntax_tree.rb', line 10096

def value
  @value
end