Class: SyntaxTree::RegexpEnd

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

RegexpEnd represents the end of a regular expression literal.

/.+/m

In the example above, the RegexpEnd event represents the /m at the end of the regular expression literal. You can also declare regular expression literals using %r, as in:

%r{.+}m

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ RegexpEnd



9052
9053
9054
9055
# File 'lib/syntax_tree/node.rb', line 9052

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the end of the regular expression



9050
9051
9052
# File 'lib/syntax_tree/node.rb', line 9050

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



9078
9079
9080
# File 'lib/syntax_tree/node.rb', line 9078

def ===(other)
  other.is_a?(RegexpEnd) && value === other.value
end

#accept(visitor) ⇒ Object



9057
9058
9059
# File 'lib/syntax_tree/node.rb', line 9057

def accept(visitor)
  visitor.visit_regexp_end(self)
end

#child_nodesObject Also known as: deconstruct



9061
9062
9063
# File 'lib/syntax_tree/node.rb', line 9061

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



9065
9066
9067
9068
9069
9070
# File 'lib/syntax_tree/node.rb', line 9065

def copy(value: nil, location: nil)
  RegexpEnd.new(
    value: value || self.value,
    location: location || self.location
  )
end

#deconstruct_keys(_keys) ⇒ Object



9074
9075
9076
# File 'lib/syntax_tree/node.rb', line 9074

def deconstruct_keys(_keys)
  { value: value, location: location }
end