Class: SyntaxTree::RegexpEnd

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

RegexpEnd represents the end of a regular expression literal.

/.+/m

In the example above, the RegexpEnd event represents the /m at the end of the regular expression literal. You can also declare regular expression literals using %r, as in:

%r{.+}m

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ RegexpEnd

Returns a new instance of RegexpEnd.



7402
7403
7404
7405
# File 'lib/syntax_tree/node.rb', line 7402

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

[String] the end of the regular expression



7400
7401
7402
# File 'lib/syntax_tree/node.rb', line 7400

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



7407
7408
7409
# File 'lib/syntax_tree/node.rb', line 7407

def accept(visitor)
  visitor.visit_regexp_end(self)
end

#child_nodesObject Also known as: deconstruct



7411
7412
7413
# File 'lib/syntax_tree/node.rb', line 7411

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



7417
7418
7419
# File 'lib/syntax_tree/node.rb', line 7417

def deconstruct_keys(_keys)
  { value: value, location: location }
end