Class: SyntaxTree::SClass
Overview
SClass represents a block of statements that should be evaluated within the context of the singleton class of an object. It’s frequently used to define singleton methods.
class << self
end
Instance Attribute Summary collapse
-
#bodystmt ⇒ Object
readonly
- BodyStmt
-
the expressions to be executed.
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#target ⇒ Object
readonly
- Node
-
the target of the singleton class to enter.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(target: nil, bodystmt: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(target:, bodystmt:, location:) ⇒ SClass
constructor
A new instance of SClass.
Methods inherited from Node
#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(target:, bodystmt:, location:) ⇒ SClass
Returns a new instance of SClass.
9819 9820 9821 9822 9823 9824 |
# File 'lib/syntax_tree/node.rb', line 9819 def initialize(target:, bodystmt:, location:) @target = target @bodystmt = bodystmt @location = location @comments = [] end |
Instance Attribute Details
#bodystmt ⇒ Object (readonly)
- BodyStmt
-
the expressions to be executed
9814 9815 9816 |
# File 'lib/syntax_tree/node.rb', line 9814 def bodystmt @bodystmt end |
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
9817 9818 9819 |
# File 'lib/syntax_tree/node.rb', line 9817 def comments @comments end |
#target ⇒ Object (readonly)
- Node
-
the target of the singleton class to enter
9811 9812 9813 |
# File 'lib/syntax_tree/node.rb', line 9811 def target @target end |
Instance Method Details
#===(other) ⇒ Object
9870 9871 9872 9873 |
# File 'lib/syntax_tree/node.rb', line 9870 def ===(other) other.is_a?(SClass) && target === other.target && bodystmt === other.bodystmt end |
#accept(visitor) ⇒ Object
9826 9827 9828 |
# File 'lib/syntax_tree/node.rb', line 9826 def accept(visitor) visitor.visit_sclass(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9830 9831 9832 |
# File 'lib/syntax_tree/node.rb', line 9830 def child_nodes [target, bodystmt] end |
#copy(target: nil, bodystmt: nil, location: nil) ⇒ Object
9834 9835 9836 9837 9838 9839 9840 9841 9842 9843 9844 |
# File 'lib/syntax_tree/node.rb', line 9834 def copy(target: nil, bodystmt: nil, location: nil) node = SClass.new( target: target || self.target, bodystmt: bodystmt || self.bodystmt, location: location || self.location ) node.comments.concat(comments.map(&:copy)) node end |
#deconstruct_keys(_keys) ⇒ Object
9848 9849 9850 9851 9852 9853 9854 9855 |
# File 'lib/syntax_tree/node.rb', line 9848 def deconstruct_keys(_keys) { target: target, bodystmt: bodystmt, location: location, comments: comments } end |
#format(q) ⇒ Object
9857 9858 9859 9860 9861 9862 9863 9864 9865 9866 9867 9868 |
# File 'lib/syntax_tree/node.rb', line 9857 def format(q) q.text("class << ") q.group do q.format(target) q.indent do q.breakable_force q.format(bodystmt) end q.breakable_force end q.text("end") end |