Class: SyntaxTree::SClass

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

SClass represents a block of statements that should be evaluated within the context of the singleton class of an object. It’s frequently used to define singleton methods.

class << self
end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(target:, bodystmt:, location:) ⇒ SClass

Returns a new instance of SClass.



9755
9756
9757
9758
9759
9760
# File 'lib/syntax_tree/node.rb', line 9755

def initialize(target:, bodystmt:, location:)
  @target = target
  @bodystmt = bodystmt
  @location = location
  @comments = []
end

Instance Attribute Details

#bodystmtObject (readonly)

BodyStmt

the expressions to be executed



9750
9751
9752
# File 'lib/syntax_tree/node.rb', line 9750

def bodystmt
  @bodystmt
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



9753
9754
9755
# File 'lib/syntax_tree/node.rb', line 9753

def comments
  @comments
end

#targetObject (readonly)

Node

the target of the singleton class to enter



9747
9748
9749
# File 'lib/syntax_tree/node.rb', line 9747

def target
  @target
end

Instance Method Details

#===(other) ⇒ Object



9806
9807
9808
9809
# File 'lib/syntax_tree/node.rb', line 9806

def ===(other)
  other.is_a?(SClass) && target === other.target &&
    bodystmt === other.bodystmt
end

#accept(visitor) ⇒ Object



9762
9763
9764
# File 'lib/syntax_tree/node.rb', line 9762

def accept(visitor)
  visitor.visit_sclass(self)
end

#child_nodesObject Also known as: deconstruct



9766
9767
9768
# File 'lib/syntax_tree/node.rb', line 9766

def child_nodes
  [target, bodystmt]
end

#copy(target: nil, bodystmt: nil, location: nil) ⇒ Object



9770
9771
9772
9773
9774
9775
9776
9777
9778
9779
9780
# File 'lib/syntax_tree/node.rb', line 9770

def copy(target: nil, bodystmt: nil, location: nil)
  node =
    SClass.new(
      target: target || self.target,
      bodystmt: bodystmt || self.bodystmt,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



9784
9785
9786
9787
9788
9789
9790
9791
# File 'lib/syntax_tree/node.rb', line 9784

def deconstruct_keys(_keys)
  {
    target: target,
    bodystmt: bodystmt,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
# File 'lib/syntax_tree/node.rb', line 9793

def format(q)
  q.text("class << ")
  q.group do
    q.format(target)
    q.indent do
      q.breakable_force
      q.format(bodystmt)
    end
    q.breakable_force
  end
  q.text("end")
end