Class: SyntaxTree::SClass

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

SClass represents a block of statements that should be evaluated within the context of the singleton class of an object. It's frequently used to define singleton methods.

class << self
end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(target:, bodystmt:, location:, comments: []) ⇒ SClass

Returns a new instance of SClass.



7975
7976
7977
7978
7979
7980
# File 'lib/syntax_tree/node.rb', line 7975

def initialize(target:, bodystmt:, location:, comments: [])
  @target = target
  @bodystmt = bodystmt
  @location = location
  @comments = comments
end

Instance Attribute Details

#bodystmt ⇒ Object (readonly)

[BodyStmt] the expressions to be executed



7970
7971
7972
# File 'lib/syntax_tree/node.rb', line 7970

def bodystmt
  @bodystmt
end

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



7973
7974
7975
# File 'lib/syntax_tree/node.rb', line 7973

def comments
  @comments
end

#target ⇒ Object (readonly)

[untyped] the target of the singleton class to enter



7967
7968
7969
# File 'lib/syntax_tree/node.rb', line 7967

def target
  @target
end

Instance Method Details

#accept(visitor) ⇒ Object



7982
7983
7984
# File 'lib/syntax_tree/node.rb', line 7982

def accept(visitor)
  visitor.visit_sclass(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



7986
7987
7988
# File 'lib/syntax_tree/node.rb', line 7986

def child_nodes
  [target, bodystmt]
end

#deconstruct_keys(_keys) ⇒ Object



7992
7993
7994
7995
7996
7997
7998
7999
# File 'lib/syntax_tree/node.rb', line 7992

def deconstruct_keys(_keys)
  {
    target: target,
    bodystmt: bodystmt,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



8001
8002
8003
8004
8005
8006
8007
8008
8009
8010
# File 'lib/syntax_tree/node.rb', line 8001

def format(q)
  q.group(0, "class << ", "end") do
    q.format(target)
    q.indent do
      q.breakable(force: true)
      q.format(bodystmt)
    end
    q.breakable(force: true)
  end
end