Class: SyntaxTree::SClass

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

SClass represents a block of statements that should be evaluated within the context of the singleton class of an object. It’s frequently used to define singleton methods.

class << self
end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(target:, bodystmt:, location:, comments: []) ⇒ SClass

Returns a new instance of SClass.



7943
7944
7945
7946
7947
7948
# File 'lib/syntax_tree/node.rb', line 7943

def initialize(target:, bodystmt:, location:, comments: [])
  @target = target
  @bodystmt = bodystmt
  @location = location
  @comments = comments
end

Instance Attribute Details

#bodystmtObject (readonly)

BodyStmt

the expressions to be executed



7938
7939
7940
# File 'lib/syntax_tree/node.rb', line 7938

def bodystmt
  @bodystmt
end

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



7941
7942
7943
# File 'lib/syntax_tree/node.rb', line 7941

def comments
  @comments
end

#targetObject (readonly)

untyped

the target of the singleton class to enter



7935
7936
7937
# File 'lib/syntax_tree/node.rb', line 7935

def target
  @target
end

Instance Method Details

#accept(visitor) ⇒ Object



7950
7951
7952
# File 'lib/syntax_tree/node.rb', line 7950

def accept(visitor)
  visitor.visit_sclass(self)
end

#child_nodesObject Also known as: deconstruct



7954
7955
7956
# File 'lib/syntax_tree/node.rb', line 7954

def child_nodes
  [target, bodystmt]
end

#deconstruct_keys(_keys) ⇒ Object



7960
7961
7962
7963
7964
7965
7966
7967
# File 'lib/syntax_tree/node.rb', line 7960

def deconstruct_keys(_keys)
  {
    target: target,
    bodystmt: bodystmt,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



7969
7970
7971
7972
7973
7974
7975
7976
7977
7978
# File 'lib/syntax_tree/node.rb', line 7969

def format(q)
  q.group(0, "class << ", "end") do
    q.format(target)
    q.indent do
      q.breakable(force: true)
      q.format(bodystmt)
    end
    q.breakable(force: true)
  end
end