Class: SyntaxTree::StringDVar

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

StringDVar represents shorthand interpolation of a variable into a string. It allows you to take an instance variable, class variable, or global variable and omit the braces when interpolating.

"#@variable"

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(variable:, location:, comments: []) ⇒ StringDVar

Returns a new instance of StringDVar.



8283
8284
8285
8286
8287
# File 'lib/syntax_tree/node.rb', line 8283

def initialize(variable:, location:, comments: [])
  @variable = variable
  @location = location
  @comments = comments
end

Instance Attribute Details

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



8281
8282
8283
# File 'lib/syntax_tree/node.rb', line 8281

def comments
  @comments
end

#variable ⇒ Object (readonly)

[Backref | VarRef] the variable being interpolated



8278
8279
8280
# File 'lib/syntax_tree/node.rb', line 8278

def variable
  @variable
end

Instance Method Details

#accept(visitor) ⇒ Object



8289
8290
8291
# File 'lib/syntax_tree/node.rb', line 8289

def accept(visitor)
  visitor.visit_string_dvar(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



8293
8294
8295
# File 'lib/syntax_tree/node.rb', line 8293

def child_nodes
  [variable]
end

#deconstruct_keys(_keys) ⇒ Object



8299
8300
8301
# File 'lib/syntax_tree/node.rb', line 8299

def deconstruct_keys(_keys)
  { variable: variable, location: location, comments: comments }
end

#format(q) ⇒ Object



8303
8304
8305
8306
8307
# File 'lib/syntax_tree/node.rb', line 8303

def format(q)
  q.text('#{')
  q.format(variable)
  q.text("}")
end