Class: SyntaxTree::StringDVar
Overview
StringDVar represents shorthand interpolation of a variable into a string. It allows you to take an instance variable, class variable, or global variable and omit the braces when interpolating.
"#@variable"
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#variable ⇒ Object
readonly
- Backref | VarRef
-
the variable being interpolated.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(variable:, location:, comments: []) ⇒ StringDVar
constructor
A new instance of StringDVar.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(variable:, location:, comments: []) ⇒ StringDVar
Returns a new instance of StringDVar.
8251 8252 8253 8254 8255 |
# File 'lib/syntax_tree/node.rb', line 8251 def initialize(variable:, location:, comments: []) @variable = variable @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
8249 8250 8251 |
# File 'lib/syntax_tree/node.rb', line 8249 def comments @comments end |
#variable ⇒ Object (readonly)
- Backref | VarRef
-
the variable being interpolated
8246 8247 8248 |
# File 'lib/syntax_tree/node.rb', line 8246 def variable @variable end |
Instance Method Details
#accept(visitor) ⇒ Object
8257 8258 8259 |
# File 'lib/syntax_tree/node.rb', line 8257 def accept(visitor) visitor.visit_string_dvar(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8261 8262 8263 |
# File 'lib/syntax_tree/node.rb', line 8261 def child_nodes [variable] end |
#deconstruct_keys(_keys) ⇒ Object
8267 8268 8269 |
# File 'lib/syntax_tree/node.rb', line 8267 def deconstruct_keys(_keys) { variable: variable, location: location, comments: comments } end |
#format(q) ⇒ Object
8271 8272 8273 8274 8275 |
# File 'lib/syntax_tree/node.rb', line 8271 def format(q) q.text('#{') q.format(variable) q.text("}") end |