Class: SyntaxTree::SymBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

SymBeg represents the beginning of a symbol literal.

:symbol

SymBeg is also used for dynamic symbols, as in:

:"symbol"

Finally, SymBeg is also used for symbols using the %s syntax, as in:

s[symbol]

The value of this node is a string. In most cases (as in the first example above) it will contain just “:”. In the case of dynamic symbols it will contain “:‘” or “:"”. In the case of %s symbols, it will contain the start of the symbol including the %s and the delimiter.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ SymBeg



10350
10351
10352
10353
# File 'lib/syntax_tree/node.rb', line 10350

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the beginning of the symbol



10348
10349
10350
# File 'lib/syntax_tree/node.rb', line 10348

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



10376
10377
10378
# File 'lib/syntax_tree/node.rb', line 10376

def ===(other)
  other.is_a?(SymBeg) && value === other.value
end

#accept(visitor) ⇒ Object



10355
10356
10357
# File 'lib/syntax_tree/node.rb', line 10355

def accept(visitor)
  visitor.visit_symbeg(self)
end

#child_nodesObject Also known as: deconstruct



10359
10360
10361
# File 'lib/syntax_tree/node.rb', line 10359

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



10363
10364
10365
10366
10367
10368
# File 'lib/syntax_tree/node.rb', line 10363

def copy(value: nil, location: nil)
  SymBeg.new(
    value: value || self.value,
    location: location || self.location
  )
end

#deconstruct_keys(_keys) ⇒ Object



10372
10373
10374
# File 'lib/syntax_tree/node.rb', line 10372

def deconstruct_keys(_keys)
  { value: value, location: location }
end