Class: SyntaxTree::SymBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

SymBeg represents the beginning of a symbol literal.

:symbol

SymBeg is also used for dynamic symbols, as in:

:"symbol"

Finally, SymBeg is also used for symbols using the %s syntax, as in:

%s[symbol]

The value of this node is a string. In most cases (as in the first example above) it will contain just ":". In the case of dynamic symbols it will contain ":'" or ":"". In the case of %s symbols, it will contain the start of the symbol including the %s and the delimiter.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ SymBeg

Returns a new instance of SymBeg.



8497
8498
8499
8500
# File 'lib/syntax_tree/node.rb', line 8497

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#value ⇒ Object (readonly)

[String] the beginning of the symbol



8495
8496
8497
# File 'lib/syntax_tree/node.rb', line 8495

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



8502
8503
8504
# File 'lib/syntax_tree/node.rb', line 8502

def accept(visitor)
  visitor.visit_symbeg(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



8506
8507
8508
# File 'lib/syntax_tree/node.rb', line 8506

def child_nodes
  []
end

#deconstruct_keys(_keys) ⇒ Object



8512
8513
8514
# File 'lib/syntax_tree/node.rb', line 8512

def deconstruct_keys(_keys)
  { value: value, location: location }
end