Class: SyntaxTree::SymBeg
Overview
SymBeg represents the beginning of a symbol literal.
:symbol
SymBeg is also used for dynamic symbols, as in:
:"symbol"
Finally, SymBeg is also used for symbols using the %s syntax, as in:
%s[symbol]
The value of this node is a string. In most cases (as in the first example above) it will contain just “:”. In the case of dynamic symbols it will contain “:‘” or “:\”“. In the case of %s symbols, it will contain the start of the symbol including the %s and the delimiter.
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the beginning of the symbol.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ SymBeg
constructor
A new instance of SymBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ SymBeg
Returns a new instance of SymBeg.
8466 8467 8468 8469 |
# File 'lib/syntax_tree/node.rb', line 8466 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the beginning of the symbol
8464 8465 8466 |
# File 'lib/syntax_tree/node.rb', line 8464 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
8471 8472 8473 |
# File 'lib/syntax_tree/node.rb', line 8471 def accept(visitor) visitor.visit_symbeg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8475 8476 8477 |
# File 'lib/syntax_tree/node.rb', line 8475 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
8481 8482 8483 |
# File 'lib/syntax_tree/node.rb', line 8481 def deconstruct_keys(_keys) { value: value, location: location } end |