Class: SyntaxTree::SymBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

SymBeg represents the beginning of a symbol literal.

:symbol

SymBeg is also used for dynamic symbols, as in:

:"symbol"

Finally, SymBeg is also used for symbols using the %s syntax, as in:

%s[symbol]

The value of this node is a string. In most cases (as in the first example above) it will contain just “:”. In the case of dynamic symbols it will contain “:‘” or “:\”“. In the case of %s symbols, it will contain the start of the symbol including the %s and the delimiter.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ SymBeg

Returns a new instance of SymBeg.



8281
8282
8283
8284
# File 'lib/syntax_tree/node.rb', line 8281

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the beginning of the symbol



8279
8280
8281
# File 'lib/syntax_tree/node.rb', line 8279

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



8286
8287
8288
# File 'lib/syntax_tree/node.rb', line 8286

def accept(visitor)
  visitor.visit_symbeg(self)
end

#child_nodesObject Also known as: deconstruct



8290
8291
8292
# File 'lib/syntax_tree/node.rb', line 8290

def child_nodes
  []
end

#deconstruct_keys(keys) ⇒ Object



8296
8297
8298
# File 'lib/syntax_tree/node.rb', line 8296

def deconstruct_keys(keys)
  { value: value, location: location }
end