Class: SyntaxTree::SymBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

SymBeg represents the beginning of a symbol literal.

:symbol

SymBeg is also used for dynamic symbols, as in:

:"symbol"

Finally, SymBeg is also used for symbols using the %s syntax, as in:

%s[symbol]

The value of this node is a string. In most cases (as in the first example above) it will contain just “:”. In the case of dynamic symbols it will contain “:‘” or “:\”“. In the case of %s symbols, it will contain the start of the symbol including the %s and the delimiter.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#child_nodes, #deconstruct, #deconstruct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ SymBeg

Returns a new instance of SymBeg.



9547
9548
9549
9550
# File 'lib/syntax_tree/node.rb', line 9547

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the beginning of the symbol



9545
9546
9547
# File 'lib/syntax_tree/node.rb', line 9545

def value
  @value
end