Class: SyntaxTree::SymbolsBeg
Overview
SymbolsBeg represents the start of a symbol array literal with interpolation.
I[one two three]
In the snippet above, SymbolsBeg represents the “%I[” token. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %I| or %I<).
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the beginning of the symbol literal array.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ SymbolsBeg
constructor
A new instance of SymbolsBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ SymbolsBeg
Returns a new instance of SymbolsBeg.
10564 10565 10566 10567 |
# File 'lib/syntax_tree/node.rb', line 10564 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the beginning of the symbol literal array
10562 10563 10564 |
# File 'lib/syntax_tree/node.rb', line 10562 def value @value end |
Instance Method Details
#===(other) ⇒ Object
10590 10591 10592 |
# File 'lib/syntax_tree/node.rb', line 10590 def ===(other) other.is_a?(SymbolsBeg) && value === other.value end |
#accept(visitor) ⇒ Object
10569 10570 10571 |
# File 'lib/syntax_tree/node.rb', line 10569 def accept(visitor) visitor.visit_symbols_beg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
10573 10574 10575 |
# File 'lib/syntax_tree/node.rb', line 10573 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
10577 10578 10579 10580 10581 10582 |
# File 'lib/syntax_tree/node.rb', line 10577 def copy(value: nil, location: nil) SymbolsBeg.new( value: value || self.value, location: location || self.location ) end |
#deconstruct_keys(_keys) ⇒ Object
10586 10587 10588 |
# File 'lib/syntax_tree/node.rb', line 10586 def deconstruct_keys(_keys) { value: value, location: location } end |