Class: SyntaxTree::SymbolsBeg
Overview
SymbolsBeg represents the start of a symbol array literal with interpolation.
%I[one two three]
In the snippet above, SymbolsBeg represents the "%I[" token. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %I| or %I<).
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
[String] the beginning of the symbol literal array.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ SymbolsBeg
constructor
A new instance of SymbolsBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ SymbolsBeg
Returns a new instance of SymbolsBeg.
8658 8659 8660 8661 |
# File 'lib/syntax_tree/node.rb', line 8658 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
[String] the beginning of the symbol literal array
8656 8657 8658 |
# File 'lib/syntax_tree/node.rb', line 8656 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
8663 8664 8665 |
# File 'lib/syntax_tree/node.rb', line 8663 def accept(visitor) visitor.visit_symbols_beg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8667 8668 8669 |
# File 'lib/syntax_tree/node.rb', line 8667 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
8673 8674 8675 |
# File 'lib/syntax_tree/node.rb', line 8673 def deconstruct_keys(_keys) { value: value, location: location } end |