Class: SyntaxTree::TLamBeg
Overview
TLamBeg represents the beginning of the body of a lambda literal using braces.
-> { value }
In the example above the TLamBeg represents the { operator.
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the beginning of the body of the lambda literal.
Attributes inherited from Node
Instance Method Summary collapse
- #===(other) ⇒ Object
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #copy(value: nil, location: nil) ⇒ Object
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ TLamBeg
constructor
A new instance of TLamBeg.
Methods inherited from Node
#construct_keys, #end_char, #format, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(value:, location:) ⇒ TLamBeg
Returns a new instance of TLamBeg.
10738 10739 10740 10741 |
# File 'lib/syntax_tree/node.rb', line 10738 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the beginning of the body of the lambda literal
10736 10737 10738 |
# File 'lib/syntax_tree/node.rb', line 10736 def value @value end |
Instance Method Details
#===(other) ⇒ Object
10764 10765 10766 |
# File 'lib/syntax_tree/node.rb', line 10764 def ===(other) other.is_a?(TLamBeg) && value === other.value end |
#accept(visitor) ⇒ Object
10743 10744 10745 |
# File 'lib/syntax_tree/node.rb', line 10743 def accept(visitor) visitor.visit_tlambeg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
10747 10748 10749 |
# File 'lib/syntax_tree/node.rb', line 10747 def child_nodes [] end |
#copy(value: nil, location: nil) ⇒ Object
10751 10752 10753 10754 10755 10756 |
# File 'lib/syntax_tree/node.rb', line 10751 def copy(value: nil, location: nil) TLamBeg.new( value: value || self.value, location: location || self.location ) end |
#deconstruct_keys(_keys) ⇒ Object
10760 10761 10762 |
# File 'lib/syntax_tree/node.rb', line 10760 def deconstruct_keys(_keys) { value: value, location: location } end |