Class: SyntaxTree::TLamBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

TLamBeg represents the beginning of the body of a lambda literal using braces.

-> { value }

In the example above the TLamBeg represents the { operator.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ TLamBeg

Returns a new instance of TLamBeg.



10645
10646
10647
10648
# File 'lib/syntax_tree/node.rb', line 10645

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the beginning of the body of the lambda literal



10643
10644
10645
# File 'lib/syntax_tree/node.rb', line 10643

def value
  @value
end

Instance Method Details

#===(other) ⇒ Object



10671
10672
10673
# File 'lib/syntax_tree/node.rb', line 10671

def ===(other)
  other.is_a?(TLamBeg) && value === other.value
end

#accept(visitor) ⇒ Object



10650
10651
10652
# File 'lib/syntax_tree/node.rb', line 10650

def accept(visitor)
  visitor.visit_tlambeg(self)
end

#child_nodesObject Also known as: deconstruct



10654
10655
10656
# File 'lib/syntax_tree/node.rb', line 10654

def child_nodes
  []
end

#copy(value: nil, location: nil) ⇒ Object



10658
10659
10660
10661
10662
10663
# File 'lib/syntax_tree/node.rb', line 10658

def copy(value: nil, location: nil)
  TLamBeg.new(
    value: value || self.value,
    location: location || self.location
  )
end

#deconstruct_keys(_keys) ⇒ Object



10667
10668
10669
# File 'lib/syntax_tree/node.rb', line 10667

def deconstruct_keys(_keys)
  { value: value, location: location }
end