Class: SyntaxTree::TLamBeg
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::TLamBeg
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
TLamBeg represents the beginning of the body of a lambda literal using braces.
-> { value }
In the example above the TLamBeg represents the { operator.
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the beginning of the body of the lambda literal.
Attributes inherited from Node
#location
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ TLamBeg
10619
10620
10621
10622
|
# File 'lib/syntax_tree/node.rb', line 10619
def initialize(value:, location:)
@value = value
@location = location
end
|
Instance Attribute Details
#value ⇒ Object
- String
-
the beginning of the body of the lambda literal
10617
10618
10619
|
# File 'lib/syntax_tree/node.rb', line 10617
def value
@value
end
|
Instance Method Details
#===(other) ⇒ Object
10645
10646
10647
|
# File 'lib/syntax_tree/node.rb', line 10645
def ===(other)
other.is_a?(TLamBeg) && value === other.value
end
|
#accept(visitor) ⇒ Object
10624
10625
10626
|
# File 'lib/syntax_tree/node.rb', line 10624
def accept(visitor)
visitor.visit_tlambeg(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
10628
10629
10630
|
# File 'lib/syntax_tree/node.rb', line 10628
def child_nodes
[]
end
|
#copy(value: nil, location: nil) ⇒ Object
10632
10633
10634
10635
10636
10637
|
# File 'lib/syntax_tree/node.rb', line 10632
def copy(value: nil, location: nil)
TLamBeg.new(
value: value || self.value,
location: location || self.location
)
end
|
#deconstruct_keys(_keys) ⇒ Object
10641
10642
10643
|
# File 'lib/syntax_tree/node.rb', line 10641
def deconstruct_keys(_keys)
{ value: value, location: location }
end
|