Class: SyntaxTree::TLamBeg
Overview
TLamBeg represents the beginning of the body of a lambda literal using braces.
-> { value }
In the example above the TLamBeg represents the { operator.
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
[String] the beginning of the body of the lambda literal.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ TLamBeg
constructor
A new instance of TLamBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ TLamBeg
Returns a new instance of TLamBeg.
8717 8718 8719 8720 |
# File 'lib/syntax_tree/node.rb', line 8717 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
[String] the beginning of the body of the lambda literal
8715 8716 8717 |
# File 'lib/syntax_tree/node.rb', line 8715 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
8722 8723 8724 |
# File 'lib/syntax_tree/node.rb', line 8722 def accept(visitor) visitor.visit_tlambeg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8726 8727 8728 |
# File 'lib/syntax_tree/node.rb', line 8726 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
8732 8733 8734 |
# File 'lib/syntax_tree/node.rb', line 8732 def deconstruct_keys(_keys) { value: value, location: location } end |