Class: SyntaxTree::TLamBeg
Overview
TLamBeg represents the beginning of the body of a lambda literal using braces.
-> { value }
In the example above the TLamBeg represents the { operator.
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
[String] the beginning of the body of the lambda literal.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ TLamBeg
constructor
A new instance of TLamBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ TLamBeg
Returns a new instance of TLamBeg.
8686 8687 8688 8689 |
# File 'lib/syntax_tree/node.rb', line 8686 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
[String] the beginning of the body of the lambda literal
8684 8685 8686 |
# File 'lib/syntax_tree/node.rb', line 8684 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
8691 8692 8693 |
# File 'lib/syntax_tree/node.rb', line 8691 def accept(visitor) visitor.visit_tlambeg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8695 8696 8697 |
# File 'lib/syntax_tree/node.rb', line 8695 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
8701 8702 8703 |
# File 'lib/syntax_tree/node.rb', line 8701 def deconstruct_keys(_keys) { value: value, location: location } end |