Class: SyntaxTree::TLamBeg
Overview
TLamBeg represents the beginning of the body of a lambda literal using braces.
-> { value }
In the example above the TLamBeg represents the { operator.
Instance Attribute Summary collapse
-
#location ⇒ Object
readonly
[Location] the location of this node.
-
#value ⇒ Object
readonly
[String] the beginning of the body of the lambda literal.
Instance Method Summary collapse
-
#initialize(value:, location:) ⇒ TLamBeg
constructor
A new instance of TLamBeg.
Methods inherited from Node
#child_nodes, #deconstruct, #deconstruct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ TLamBeg
Returns a new instance of TLamBeg.
10133 10134 10135 10136 |
# File 'lib/syntax_tree/node.rb', line 10133 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#location ⇒ Object (readonly)
[Location] the location of this node
10131 10132 10133 |
# File 'lib/syntax_tree/node.rb', line 10131 def location @location end |
#value ⇒ Object (readonly)
[String] the beginning of the body of the lambda literal
10128 10129 10130 |
# File 'lib/syntax_tree/node.rb', line 10128 def value @value end |