Class: SyntaxTree::TLamBeg

Inherits:
Object
  • Object
show all
Defined in:
lib/syntax_tree.rb

Overview

TLamBeg represents the beginning of the body of a lambda literal using braces.

-> { value }

In the example above the TLamBeg represents the { operator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(value:, location:) ⇒ TLamBeg

Returns a new instance of TLamBeg.



11923
11924
11925
11926
# File 'lib/syntax_tree.rb', line 11923

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#locationObject (readonly)

Location

the location of this node



11921
11922
11923
# File 'lib/syntax_tree.rb', line 11921

def location
  @location
end

#valueObject (readonly)

String

the beginning of the body of the lambda literal



11918
11919
11920
# File 'lib/syntax_tree.rb', line 11918

def value
  @value
end