Class: SyntaxTree::TLamBeg
- Inherits:
-
Object
- Object
- SyntaxTree::TLamBeg
- Defined in:
- lib/syntax_tree.rb
Overview
TLamBeg represents the beginning of the body of a lambda literal using braces.
-> { value }
In the example above the TLamBeg represents the { operator.
Instance Attribute Summary collapse
-
#location ⇒ Object
readonly
- Location
-
the location of this node.
-
#value ⇒ Object
readonly
- String
-
the beginning of the body of the lambda literal.
Instance Method Summary collapse
-
#initialize(value:, location:) ⇒ TLamBeg
constructor
A new instance of TLamBeg.
Constructor Details
#initialize(value:, location:) ⇒ TLamBeg
Returns a new instance of TLamBeg.
11923 11924 11925 11926 |
# File 'lib/syntax_tree.rb', line 11923 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#location ⇒ Object (readonly)
- Location
-
the location of this node
11921 11922 11923 |
# File 'lib/syntax_tree.rb', line 11921 def location @location end |
#value ⇒ Object (readonly)
- String
-
the beginning of the body of the lambda literal
11918 11919 11920 |
# File 'lib/syntax_tree.rb', line 11918 def value @value end |