Class: SyntaxTree::TStringContent
Overview
TStringContent represents plain characters inside of an entity that accepts string content like a string, heredoc, command string, or regular expression.
"string"
In the example above, TStringContent represents the string token contained within the string.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- String
-
the content of the string.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ TStringContent
constructor
A new instance of TStringContent.
- #match?(pattern) ⇒ Boolean
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:, comments: []) ⇒ TStringContent
Returns a new instance of TStringContent.
8832 8833 8834 8835 8836 |
# File 'lib/syntax_tree/node.rb', line 8832 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
8830 8831 8832 |
# File 'lib/syntax_tree/node.rb', line 8830 def comments @comments end |
#value ⇒ Object (readonly)
- String
-
the content of the string
8827 8828 8829 |
# File 'lib/syntax_tree/node.rb', line 8827 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
8842 8843 8844 |
# File 'lib/syntax_tree/node.rb', line 8842 def accept(visitor) visitor.visit_tstring_content(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8846 8847 8848 |
# File 'lib/syntax_tree/node.rb', line 8846 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
8852 8853 8854 |
# File 'lib/syntax_tree/node.rb', line 8852 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
8856 8857 8858 |
# File 'lib/syntax_tree/node.rb', line 8856 def format(q) q.text(value) end |
#match?(pattern) ⇒ Boolean
8838 8839 8840 |
# File 'lib/syntax_tree/node.rb', line 8838 def match?(pattern) value.match?(pattern) end |