Class: SyntaxTree::TopConstField
Overview
TopConstField is always the child node of some kind of assignment. It represents when you're assigning to a constant that is being referenced at the top level.
::Constant = value
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#constant ⇒ Object
readonly
[Const] the constant being assigned.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(constant:, location:, comments: []) ⇒ TopConstField
constructor
A new instance of TopConstField.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(constant:, location:, comments: []) ⇒ TopConstField
Returns a new instance of TopConstField.
8750 8751 8752 8753 8754 |
# File 'lib/syntax_tree/node.rb', line 8750 def initialize(constant:, location:, comments: []) @constant = constant @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
8748 8749 8750 |
# File 'lib/syntax_tree/node.rb', line 8748 def comments @comments end |
#constant ⇒ Object (readonly)
[Const] the constant being assigned
8745 8746 8747 |
# File 'lib/syntax_tree/node.rb', line 8745 def constant @constant end |
Instance Method Details
#accept(visitor) ⇒ Object
8756 8757 8758 |
# File 'lib/syntax_tree/node.rb', line 8756 def accept(visitor) visitor.visit_top_const_field(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8760 8761 8762 |
# File 'lib/syntax_tree/node.rb', line 8760 def child_nodes [constant] end |
#deconstruct_keys(_keys) ⇒ Object
8766 8767 8768 |
# File 'lib/syntax_tree/node.rb', line 8766 def deconstruct_keys(_keys) { constant: constant, location: location, comments: comments } end |
#format(q) ⇒ Object
8770 8771 8772 8773 |
# File 'lib/syntax_tree/node.rb', line 8770 def format(q) q.text("::") q.format(constant) end |