Class: SyntaxTree::TopConstField
Overview
TopConstField is always the child node of some kind of assignment. It represents when you’re assigning to a constant that is being referenced at the top level.
::Constant = value
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#constant ⇒ Object
readonly
- Const
-
the constant being assigned.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(constant:, location:, comments: []) ⇒ TopConstField
constructor
A new instance of TopConstField.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(constant:, location:, comments: []) ⇒ TopConstField
Returns a new instance of TopConstField.
8719 8720 8721 8722 8723 |
# File 'lib/syntax_tree/node.rb', line 8719 def initialize(constant:, location:, comments: []) @constant = constant @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
8717 8718 8719 |
# File 'lib/syntax_tree/node.rb', line 8717 def comments @comments end |
#constant ⇒ Object (readonly)
- Const
-
the constant being assigned
8714 8715 8716 |
# File 'lib/syntax_tree/node.rb', line 8714 def constant @constant end |
Instance Method Details
#accept(visitor) ⇒ Object
8725 8726 8727 |
# File 'lib/syntax_tree/node.rb', line 8725 def accept(visitor) visitor.visit_top_const_field(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
8729 8730 8731 |
# File 'lib/syntax_tree/node.rb', line 8729 def child_nodes [constant] end |
#deconstruct_keys(_keys) ⇒ Object
8735 8736 8737 |
# File 'lib/syntax_tree/node.rb', line 8735 def deconstruct_keys(_keys) { constant: constant, location: location, comments: comments } end |
#format(q) ⇒ Object
8739 8740 8741 8742 |
# File 'lib/syntax_tree/node.rb', line 8739 def format(q) q.text("::") q.format(constant) end |