Class: SyntaxTree::Undef::UndefArgumentFormatter
- Inherits:
-
Object
- Object
- SyntaxTree::Undef::UndefArgumentFormatter
- Defined in:
- lib/syntax_tree/node.rb
Overview
Undef accepts a variable number of arguments that can be either DynaSymbol or SymbolLiteral objects. For SymbolLiteral objects we descend directly into the value in order to have it come out as bare words.
Instance Attribute Summary collapse
-
#node ⇒ Object
readonly
- DynaSymbol | SymbolLiteral
-
the symbol to undefine.
Instance Method Summary collapse
- #comments ⇒ Object
- #format(q) ⇒ Object
-
#initialize(node) ⇒ UndefArgumentFormatter
constructor
A new instance of UndefArgumentFormatter.
Constructor Details
#initialize(node) ⇒ UndefArgumentFormatter
Returns a new instance of UndefArgumentFormatter.
11091 11092 11093 |
# File 'lib/syntax_tree/node.rb', line 11091 def initialize(node) @node = node end |
Instance Attribute Details
#node ⇒ Object (readonly)
- DynaSymbol | SymbolLiteral
-
the symbol to undefine
11089 11090 11091 |
# File 'lib/syntax_tree/node.rb', line 11089 def node @node end |
Instance Method Details
#comments ⇒ Object
11095 11096 11097 11098 11099 11100 11101 |
# File 'lib/syntax_tree/node.rb', line 11095 def comments if node.is_a?(SymbolLiteral) node.comments + node.value.comments else node.comments end end |
#format(q) ⇒ Object
11103 11104 11105 |
# File 'lib/syntax_tree/node.rb', line 11103 def format(q) node.is_a?(SymbolLiteral) ? q.format(node.value) : q.format(node) end |