Class: SyntaxTree::UnlessNode

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Unless represents the first clause in an unless chain.

unless predicate
end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(predicate:, statements:, consequent:, location:) ⇒ UnlessNode

Returns a new instance of UnlessNode.



11154
11155
11156
11157
11158
11159
11160
# File 'lib/syntax_tree/node.rb', line 11154

def initialize(predicate:, statements:, consequent:, location:)
  @predicate = predicate
  @statements = statements
  @consequent = consequent
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



11152
11153
11154
# File 'lib/syntax_tree/node.rb', line 11152

def comments
  @comments
end

#consequentObject (readonly)

nil | Elsif | Else

the next clause in the chain



11149
11150
11151
# File 'lib/syntax_tree/node.rb', line 11149

def consequent
  @consequent
end

#predicateObject (readonly)

untyped

the expression to be checked



11143
11144
11145
# File 'lib/syntax_tree/node.rb', line 11143

def predicate
  @predicate
end

#statementsObject (readonly)

Statements

the expressions to be executed



11146
11147
11148
# File 'lib/syntax_tree/node.rb', line 11146

def statements
  @statements
end

Instance Method Details

#===(other) ⇒ Object



11199
11200
11201
11202
# File 'lib/syntax_tree/node.rb', line 11199

def ===(other)
  other.is_a?(UnlessNode) && predicate === other.predicate &&
    statements === other.statements && consequent === other.consequent
end

#accept(visitor) ⇒ Object



11162
11163
11164
# File 'lib/syntax_tree/node.rb', line 11162

def accept(visitor)
  visitor.visit_unless(self)
end

#child_nodesObject Also known as: deconstruct



11166
11167
11168
# File 'lib/syntax_tree/node.rb', line 11166

def child_nodes
  [predicate, statements, consequent]
end

#copy(predicate: nil, statements: nil, consequent: nil, location: nil) ⇒ Object



11170
11171
11172
11173
11174
11175
11176
11177
11178
11179
11180
11181
# File 'lib/syntax_tree/node.rb', line 11170

def copy(predicate: nil, statements: nil, consequent: nil, location: nil)
  node =
    UnlessNode.new(
      predicate: predicate || self.predicate,
      statements: statements || self.statements,
      consequent: consequent || self.consequent,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



11185
11186
11187
11188
11189
11190
11191
11192
11193
# File 'lib/syntax_tree/node.rb', line 11185

def deconstruct_keys(_keys)
  {
    predicate: predicate,
    statements: statements,
    consequent: consequent,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



11195
11196
11197
# File 'lib/syntax_tree/node.rb', line 11195

def format(q)
  ConditionalFormatter.new("unless", self).format(q)
end

#modifier?Boolean

Checks if the node was originally found in the modifier form.

Returns:

  • (Boolean)


11205
11206
11207
# File 'lib/syntax_tree/node.rb', line 11205

def modifier?
  predicate.location.start_char > statements.location.start_char
end