Class: SyntaxTree::VCall

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

VCall represent any plain named object with Ruby that could be either a local variable or a method call.

variable

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ VCall

Returns a new instance of VCall.



9535
9536
9537
9538
9539
# File 'lib/syntax_tree/node.rb', line 9535

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



9533
9534
9535
# File 'lib/syntax_tree/node.rb', line 9533

def comments
  @comments
end

#valueObject (readonly)

Ident

the value of this expression



9530
9531
9532
# File 'lib/syntax_tree/node.rb', line 9530

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



9541
9542
9543
# File 'lib/syntax_tree/node.rb', line 9541

def accept(visitor)
  visitor.visit_vcall(self)
end

#child_nodesObject Also known as: deconstruct



9545
9546
9547
# File 'lib/syntax_tree/node.rb', line 9545

def child_nodes
  [value]
end

#deconstruct_keys(_keys) ⇒ Object



9551
9552
9553
# File 'lib/syntax_tree/node.rb', line 9551

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



9555
9556
9557
# File 'lib/syntax_tree/node.rb', line 9555

def format(q)
  q.format(value)
end