Class: SyntaxTree::VCall
Overview
VCall represent any plain named object with Ruby that could be either a local variable or a method call.
variable
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- Ident
-
the value of this expression.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ VCall
constructor
A new instance of VCall.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:, comments: []) ⇒ VCall
Returns a new instance of VCall.
9535 9536 9537 9538 9539 |
# File 'lib/syntax_tree/node.rb', line 9535 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
9533 9534 9535 |
# File 'lib/syntax_tree/node.rb', line 9533 def comments @comments end |
#value ⇒ Object (readonly)
- Ident
-
the value of this expression
9530 9531 9532 |
# File 'lib/syntax_tree/node.rb', line 9530 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
9541 9542 9543 |
# File 'lib/syntax_tree/node.rb', line 9541 def accept(visitor) visitor.visit_vcall(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9545 9546 9547 |
# File 'lib/syntax_tree/node.rb', line 9545 def child_nodes [value] end |
#deconstruct_keys(_keys) ⇒ Object
9551 9552 9553 |
# File 'lib/syntax_tree/node.rb', line 9551 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
9555 9556 9557 |
# File 'lib/syntax_tree/node.rb', line 9555 def format(q) q.format(value) end |