Class: SyntaxTree::VarAlias

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

VarAlias represents when you’re using the alias keyword with global variable arguments.

alias $new $old

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(left:, right:, location:, comments: []) ⇒ VarAlias

Returns a new instance of VarAlias.



9366
9367
9368
9369
9370
9371
# File 'lib/syntax_tree/node.rb', line 9366

def initialize(left:, right:, location:, comments: [])
  @left = left
  @right = right
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



9364
9365
9366
# File 'lib/syntax_tree/node.rb', line 9364

def comments
  @comments
end

#leftObject (readonly)

GVar

the new alias of the variable



9358
9359
9360
# File 'lib/syntax_tree/node.rb', line 9358

def left
  @left
end

#rightObject (readonly)

Backref | GVar

the current name of the variable to be aliased



9361
9362
9363
# File 'lib/syntax_tree/node.rb', line 9361

def right
  @right
end

Instance Method Details

#accept(visitor) ⇒ Object



9373
9374
9375
# File 'lib/syntax_tree/node.rb', line 9373

def accept(visitor)
  visitor.visit_var_alias(self)
end

#child_nodesObject Also known as: deconstruct



9377
9378
9379
# File 'lib/syntax_tree/node.rb', line 9377

def child_nodes
  [left, right]
end

#deconstruct_keys(_keys) ⇒ Object



9383
9384
9385
# File 'lib/syntax_tree/node.rb', line 9383

def deconstruct_keys(_keys)
  { left: left, right: right, location: location, comments: comments }
end

#format(q) ⇒ Object



9387
9388
9389
9390
9391
9392
9393
9394
# File 'lib/syntax_tree/node.rb', line 9387

def format(q)
  keyword = "alias "

  q.text(keyword)
  q.format(left)
  q.text(" ")
  q.format(right)
end