Class: SyntaxTree::VarField

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

VarField represents a variable that is being assigned a value. As such, it is always a child of an assignment type node.

variable = value

In the example above, the VarField node represents the variable token.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ VarField

Returns a new instance of VarField.



9410
9411
9412
9413
9414
# File 'lib/syntax_tree/node.rb', line 9410

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



9408
9409
9410
# File 'lib/syntax_tree/node.rb', line 9408

def comments
  @comments
end

#valueObject (readonly)

nil | Const | CVar | GVar | Ident | IVar

the target of this node



9405
9406
9407
# File 'lib/syntax_tree/node.rb', line 9405

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



9416
9417
9418
# File 'lib/syntax_tree/node.rb', line 9416

def accept(visitor)
  visitor.visit_var_field(self)
end

#child_nodesObject Also known as: deconstruct



9420
9421
9422
# File 'lib/syntax_tree/node.rb', line 9420

def child_nodes
  [value]
end

#deconstruct_keys(_keys) ⇒ Object



9426
9427
9428
# File 'lib/syntax_tree/node.rb', line 9426

def deconstruct_keys(_keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



9430
9431
9432
9433
9434
9435
9436
# File 'lib/syntax_tree/node.rb', line 9430

def format(q)
  if value == :nil
    q.text("nil")
  elsif value
    q.format(value)
  end
end