Class: SyntaxTree::VarField
Overview
VarField represents a variable that is being assigned a value. As such, it is always a child of an assignment type node.
variable = value
In the example above, the VarField node represents the variable token.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
- Array[ Comment | EmbDoc ]
-
the comments attached to this node.
-
#value ⇒ Object
readonly
- nil | Const | CVar | GVar | Ident | IVar
-
the target of this node.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ VarField
constructor
A new instance of VarField.
Methods inherited from Node
Constructor Details
#initialize(value:, location:, comments: []) ⇒ VarField
Returns a new instance of VarField.
9218 9219 9220 9221 9222 |
# File 'lib/syntax_tree/node.rb', line 9218 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
- Array[ Comment | EmbDoc ]
-
the comments attached to this node
9216 9217 9218 |
# File 'lib/syntax_tree/node.rb', line 9216 def comments @comments end |
#value ⇒ Object (readonly)
- nil | Const | CVar | GVar | Ident | IVar
-
the target of this node
9213 9214 9215 |
# File 'lib/syntax_tree/node.rb', line 9213 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
9224 9225 9226 |
# File 'lib/syntax_tree/node.rb', line 9224 def accept(visitor) visitor.visit_var_field(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9228 9229 9230 |
# File 'lib/syntax_tree/node.rb', line 9228 def child_nodes [value] end |
#deconstruct_keys(keys) ⇒ Object
9234 9235 9236 |
# File 'lib/syntax_tree/node.rb', line 9234 def deconstruct_keys(keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
9238 9239 9240 9241 9242 9243 9244 |
# File 'lib/syntax_tree/node.rb', line 9238 def format(q) if value == :nil q.text("nil") elsif value q.format(value) end end |