Class: SyntaxTree::VarRef
Overview
VarRef represents a variable reference.
true
This can be a plain local variable like the example above. It can also be a
constant, a class variable, a global variable, an instance variable, a
keyword (like self, nil, true, or false), or a numbered block
variable.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#value ⇒ Object
readonly
[Const | CVar | GVar | Ident | IVar | Kw] the value of this node.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(value:, location:, comments: []) ⇒ VarRef
constructor
A new instance of VarRef.
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:, comments: []) ⇒ VarRef
Returns a new instance of VarRef.
9496 9497 9498 9499 9500 |
# File 'lib/syntax_tree/node.rb', line 9496 def initialize(value:, location:, comments: []) @value = value @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
9494 9495 9496 |
# File 'lib/syntax_tree/node.rb', line 9494 def comments @comments end |
#value ⇒ Object (readonly)
[Const | CVar | GVar | Ident | IVar | Kw] the value of this node
9491 9492 9493 |
# File 'lib/syntax_tree/node.rb', line 9491 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
9502 9503 9504 |
# File 'lib/syntax_tree/node.rb', line 9502 def accept(visitor) visitor.visit_var_ref(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9506 9507 9508 |
# File 'lib/syntax_tree/node.rb', line 9506 def child_nodes [value] end |
#deconstruct_keys(_keys) ⇒ Object
9512 9513 9514 |
# File 'lib/syntax_tree/node.rb', line 9512 def deconstruct_keys(_keys) { value: value, location: location, comments: comments } end |
#format(q) ⇒ Object
9516 9517 9518 |
# File 'lib/syntax_tree/node.rb', line 9516 def format(q) q.format(value) end |