Class: SyntaxTree::VarRef

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

VarRef represents a variable reference.

true

This can be a plain local variable like the example above. It can also be a constant, a class variable, a global variable, an instance variable, a keyword (like self, nil, true, or false), or a numbered block variable.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#pretty_print, #to_json

Constructor Details

#initialize(value:, location:, comments: []) ⇒ VarRef

Returns a new instance of VarRef.



9262
9263
9264
9265
9266
# File 'lib/syntax_tree/node.rb', line 9262

def initialize(value:, location:, comments: [])
  @value = value
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



9260
9261
9262
# File 'lib/syntax_tree/node.rb', line 9260

def comments
  @comments
end

#valueObject (readonly)

Const | CVar | GVar | Ident | IVar | Kw

the value of this node



9257
9258
9259
# File 'lib/syntax_tree/node.rb', line 9257

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



9268
9269
9270
# File 'lib/syntax_tree/node.rb', line 9268

def accept(visitor)
  visitor.visit_var_ref(self)
end

#child_nodesObject Also known as: deconstruct



9272
9273
9274
# File 'lib/syntax_tree/node.rb', line 9272

def child_nodes
  [value]
end

#deconstruct_keys(keys) ⇒ Object



9278
9279
9280
# File 'lib/syntax_tree/node.rb', line 9278

def deconstruct_keys(keys)
  { value: value, location: location, comments: comments }
end

#format(q) ⇒ Object



9282
9283
9284
# File 'lib/syntax_tree/node.rb', line 9282

def format(q)
  q.format(value)
end