Class: SyntaxTree::When

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

When represents a when clause in a case chain.

case value
when predicate
end

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(arguments:, statements:, consequent:, location:, comments: []) ⇒ When

Returns a new instance of When.



9644
9645
9646
9647
9648
9649
9650
9651
9652
9653
9654
9655
9656
# File 'lib/syntax_tree/node.rb', line 9644

def initialize(
  arguments:,
  statements:,
  consequent:,
  location:,
  comments: []
)
  @arguments = arguments
  @statements = statements
  @consequent = consequent
  @location = location
  @comments = comments
end

Instance Attribute Details

#arguments ⇒ Object (readonly)

[Args] the arguments to the when clause



9633
9634
9635
# File 'lib/syntax_tree/node.rb', line 9633

def arguments
  @arguments
end

#comments ⇒ Object (readonly)

[Array[ Comment | EmbDoc ]] the comments attached to this node



9642
9643
9644
# File 'lib/syntax_tree/node.rb', line 9642

def comments
  @comments
end

#consequent ⇒ Object (readonly)

[nil | Else | When] the next clause in the chain



9639
9640
9641
# File 'lib/syntax_tree/node.rb', line 9639

def consequent
  @consequent
end

#statements ⇒ Object (readonly)

[Statements] the expressions to be executed



9636
9637
9638
# File 'lib/syntax_tree/node.rb', line 9636

def statements
  @statements
end

Instance Method Details

#accept(visitor) ⇒ Object



9658
9659
9660
# File 'lib/syntax_tree/node.rb', line 9658

def accept(visitor)
  visitor.visit_when(self)
end

#child_nodes ⇒ Object Also known as: deconstruct



9662
9663
9664
# File 'lib/syntax_tree/node.rb', line 9662

def child_nodes
  [arguments, statements, consequent]
end

#deconstruct_keys(_keys) ⇒ Object



9668
9669
9670
9671
9672
9673
9674
9675
9676
# File 'lib/syntax_tree/node.rb', line 9668

def deconstruct_keys(_keys)
  {
    arguments: arguments,
    statements: statements,
    consequent: consequent,
    location: location,
    comments: comments
  }
end

#format(q) ⇒ Object



9678
9679
9680
9681
9682
9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
9694
9695
9696
9697
9698
9699
9700
9701
9702
9703
9704
9705
9706
9707
9708
9709
9710
9711
9712
9713
9714
# File 'lib/syntax_tree/node.rb', line 9678

def format(q)
  keyword = "when "

  q.group do
    q.group do
      q.text(keyword)
      q.nest(keyword.length) do
        if arguments.comments.any?
          q.format(arguments)
        else
          separator = -> { q.group { q.comma_breakable } }
          q.seplist(arguments.parts, separator) { |part| q.format(part) }
        end

        # Very special case here. If you're inside of a when clause and the
        # last argument to the predicate is and endless range, then you are
        # forced to use the "then" keyword to make it parse properly.
        last = arguments.parts.last
        if (last.is_a?(Dot2) || last.is_a?(Dot3)) && !last.right
          q.text(" then")
        end
      end
    end

    unless statements.empty?
      q.indent do
        q.breakable(force: true)
        q.format(statements)
      end
    end

    if consequent
      q.breakable(force: true)
      q.format(consequent)
    end
  end
end