Class: SyntaxTree::When::Separator
- Inherits:
-
Object
- Object
- SyntaxTree::When::Separator
- Defined in:
- lib/syntax_tree/node.rb
Overview
We have a special separator here for when clauses which causes them to fill as much of the line as possible as opposed to everything breaking into its own line as soon as you hit the print limit.
Instance Method Summary collapse
Instance Method Details
#call(q) ⇒ Object
11738 11739 11740 11741 11742 11743 |
# File 'lib/syntax_tree/node.rb', line 11738 def call(q) q.group do q.text(",") q.breakable_space end end |