Class: SyntaxTree::Word
- Inherits:
-
Node
- Object
- Node
- SyntaxTree::Word
show all
- Defined in:
- lib/syntax_tree/node.rb
Overview
Word represents an element within a special array literal that accepts
interpolation.
%W[a#{b}c xyz]
In the example above, there would be two Word nodes within a parent Words
node.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#parts ⇒ Object
readonly
[Array[ StringEmbExpr | StringDVar | TStringContent ]] the parts of the word.
Attributes inherited from Node
#location
Instance Method Summary
collapse
Methods inherited from Node
#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid
Constructor Details
#initialize(parts:, location:) ⇒ Word
Returns a new instance of Word.
12028
12029
12030
12031
12032
|
# File 'lib/syntax_tree/node.rb', line 12028
def initialize(parts:, location:)
@parts = parts
@location = location
@comments = []
end
|
Instance Attribute Details
[Array[ Comment | EmbDoc ]] the comments attached to this node
12026
12027
12028
|
# File 'lib/syntax_tree/node.rb', line 12026
def
@comments
end
|
#parts ⇒ Object
[Array[ StringEmbExpr | StringDVar | TStringContent ]] the parts of the
word
12023
12024
12025
|
# File 'lib/syntax_tree/node.rb', line 12023
def parts
@parts
end
|
Instance Method Details
#===(other) ⇒ Object
12067
12068
12069
|
# File 'lib/syntax_tree/node.rb', line 12067
def ===(other)
other.is_a?(Word) && ArrayMatch.call(parts, other.parts)
end
|
#accept(visitor) ⇒ Object
12038
12039
12040
|
# File 'lib/syntax_tree/node.rb', line 12038
def accept(visitor)
visitor.visit_word(self)
end
|
#child_nodes ⇒ Object
Also known as:
deconstruct
12042
12043
12044
|
# File 'lib/syntax_tree/node.rb', line 12042
def child_nodes
parts
end
|
#copy(parts: nil, location: nil) ⇒ Object
12046
12047
12048
12049
12050
12051
12052
12053
12054
12055
|
# File 'lib/syntax_tree/node.rb', line 12046
def copy(parts: nil, location: nil)
node =
Word.new(
parts: parts || self.parts,
location: location || self.location
)
node..concat(.map(&:copy))
node
end
|
#deconstruct_keys(_keys) ⇒ Object
12059
12060
12061
|
# File 'lib/syntax_tree/node.rb', line 12059
def deconstruct_keys(_keys)
{ parts: parts, location: location, comments: }
end
|
12063
12064
12065
|
# File 'lib/syntax_tree/node.rb', line 12063
def format(q)
q.format_each(parts)
end
|
#match?(pattern) ⇒ Boolean
12034
12035
12036
|
# File 'lib/syntax_tree/node.rb', line 12034
def match?(pattern)
parts.any? { |part| part.is_a?(TStringContent) && part.match?(pattern) }
end
|