Class: SyntaxTree::Word

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Word represents an element within a special array literal that accepts interpolation.

%W[a#{b}c xyz]

In the example above, there would be two Word nodes within a parent Words node.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #end_char, #pretty_print, #start_char, #to_json, #to_mermaid

Constructor Details

#initialize(parts:, location:) ⇒ Word

Returns a new instance of Word.



11964
11965
11966
11967
11968
# File 'lib/syntax_tree/node.rb', line 11964

def initialize(parts:, location:)
  @parts = parts
  @location = location
  @comments = []
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



11962
11963
11964
# File 'lib/syntax_tree/node.rb', line 11962

def comments
  @comments
end

#partsObject (readonly)

Array[ StringEmbExpr | StringDVar | TStringContent ]

the parts of the

word



11959
11960
11961
# File 'lib/syntax_tree/node.rb', line 11959

def parts
  @parts
end

Instance Method Details

#===(other) ⇒ Object



12003
12004
12005
# File 'lib/syntax_tree/node.rb', line 12003

def ===(other)
  other.is_a?(Word) && ArrayMatch.call(parts, other.parts)
end

#accept(visitor) ⇒ Object



11974
11975
11976
# File 'lib/syntax_tree/node.rb', line 11974

def accept(visitor)
  visitor.visit_word(self)
end

#child_nodesObject Also known as: deconstruct



11978
11979
11980
# File 'lib/syntax_tree/node.rb', line 11978

def child_nodes
  parts
end

#copy(parts: nil, location: nil) ⇒ Object



11982
11983
11984
11985
11986
11987
11988
11989
11990
11991
# File 'lib/syntax_tree/node.rb', line 11982

def copy(parts: nil, location: nil)
  node =
    Word.new(
      parts: parts || self.parts,
      location: location || self.location
    )

  node.comments.concat(comments.map(&:copy))
  node
end

#deconstruct_keys(_keys) ⇒ Object



11995
11996
11997
# File 'lib/syntax_tree/node.rb', line 11995

def deconstruct_keys(_keys)
  { parts: parts, location: location, comments: comments }
end

#format(q) ⇒ Object



11999
12000
12001
# File 'lib/syntax_tree/node.rb', line 11999

def format(q)
  q.format_each(parts)
end

#match?(pattern) ⇒ Boolean

Returns:

  • (Boolean)


11970
11971
11972
# File 'lib/syntax_tree/node.rb', line 11970

def match?(pattern)
  parts.any? { |part| part.is_a?(TStringContent) && part.match?(pattern) }
end