Class: SyntaxTree::Word
Overview
Word represents an element within a special array literal that accepts interpolation.
%W[a#{b}c xyz]
In the example above, there would be two Word nodes within a parent Words node.
Instance Attribute Summary collapse
-
#comments ⇒ Object
readonly
[Array[ Comment | EmbDoc ]] the comments attached to this node.
-
#parts ⇒ Object
readonly
[Array[ StringEmbExpr | StringDVar | TStringContent ]] the parts of the word.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
- #format(q) ⇒ Object
-
#initialize(parts:, location:, comments: []) ⇒ Word
constructor
A new instance of Word.
- #match?(pattern) ⇒ Boolean
Methods inherited from Node
#construct_keys, #pretty_print, #to_json
Constructor Details
#initialize(parts:, location:, comments: []) ⇒ Word
Returns a new instance of Word.
9865 9866 9867 9868 9869 |
# File 'lib/syntax_tree/node.rb', line 9865 def initialize(parts:, location:, comments: []) @parts = parts @location = location @comments = comments end |
Instance Attribute Details
#comments ⇒ Object (readonly)
[Array[ Comment | EmbDoc ]] the comments attached to this node
9863 9864 9865 |
# File 'lib/syntax_tree/node.rb', line 9863 def comments @comments end |
#parts ⇒ Object (readonly)
[Array[ StringEmbExpr | StringDVar | TStringContent ]] the parts of the word
9860 9861 9862 |
# File 'lib/syntax_tree/node.rb', line 9860 def parts @parts end |
Instance Method Details
#accept(visitor) ⇒ Object
9875 9876 9877 |
# File 'lib/syntax_tree/node.rb', line 9875 def accept(visitor) visitor.visit_word(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9879 9880 9881 |
# File 'lib/syntax_tree/node.rb', line 9879 def child_nodes parts end |
#deconstruct_keys(_keys) ⇒ Object
9885 9886 9887 |
# File 'lib/syntax_tree/node.rb', line 9885 def deconstruct_keys(_keys) { parts: parts, location: location, comments: comments } end |
#format(q) ⇒ Object
9889 9890 9891 |
# File 'lib/syntax_tree/node.rb', line 9889 def format(q) q.format_each(parts) end |
#match?(pattern) ⇒ Boolean
9871 9872 9873 |
# File 'lib/syntax_tree/node.rb', line 9871 def match?(pattern) parts.any? { |part| part.is_a?(TStringContent) && part.match?(pattern) } end |