Class: SyntaxTree::Word

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

Word represents an element within a special array literal that accepts interpolation.

%W[a#{b}c xyz]

In the example above, there would be two Word nodes within a parent Words node.

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#construct_keys, #pretty_print, #to_json

Constructor Details

#initialize(parts:, location:, comments: []) ⇒ Word

Returns a new instance of Word.



9823
9824
9825
9826
9827
# File 'lib/syntax_tree/node.rb', line 9823

def initialize(parts:, location:, comments: [])
  @parts = parts
  @location = location
  @comments = comments
end

Instance Attribute Details

#commentsObject (readonly)

Array[ Comment | EmbDoc ]

the comments attached to this node



9821
9822
9823
# File 'lib/syntax_tree/node.rb', line 9821

def comments
  @comments
end

#partsObject (readonly)

Array[ StringEmbExpr | StringDVar | TStringContent ]

the parts of the

word



9818
9819
9820
# File 'lib/syntax_tree/node.rb', line 9818

def parts
  @parts
end

Instance Method Details

#accept(visitor) ⇒ Object



9833
9834
9835
# File 'lib/syntax_tree/node.rb', line 9833

def accept(visitor)
  visitor.visit_word(self)
end

#child_nodesObject Also known as: deconstruct



9837
9838
9839
# File 'lib/syntax_tree/node.rb', line 9837

def child_nodes
  parts
end

#deconstruct_keys(_keys) ⇒ Object



9843
9844
9845
# File 'lib/syntax_tree/node.rb', line 9843

def deconstruct_keys(_keys)
  { parts: parts, location: location, comments: comments }
end

#format(q) ⇒ Object



9847
9848
9849
# File 'lib/syntax_tree/node.rb', line 9847

def format(q)
  q.format_each(parts)
end

#match?(pattern) ⇒ Boolean

Returns:

  • (Boolean)


9829
9830
9831
# File 'lib/syntax_tree/node.rb', line 9829

def match?(pattern)
  parts.any? { |part| part.is_a?(TStringContent) && part.match?(pattern) }
end