Class: SyntaxTree::WordsBeg
Overview
WordsBeg represents the beginning of a string literal array with interpolation.
%W[one two three]
In the snippet above, a WordsBeg would be created with the value of “%W[”. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %W| or %W<).
Instance Attribute Summary collapse
-
#value ⇒ Object
readonly
- String
-
the start of the word literal array.
Attributes inherited from Node
Instance Method Summary collapse
- #accept(visitor) ⇒ Object
- #child_nodes ⇒ Object (also: #deconstruct)
- #deconstruct_keys(_keys) ⇒ Object
-
#initialize(value:, location:) ⇒ WordsBeg
constructor
A new instance of WordsBeg.
Methods inherited from Node
#construct_keys, #format, #pretty_print, #to_json
Constructor Details
#initialize(value:, location:) ⇒ WordsBeg
Returns a new instance of WordsBeg.
9924 9925 9926 9927 |
# File 'lib/syntax_tree/node.rb', line 9924 def initialize(value:, location:) @value = value @location = location end |
Instance Attribute Details
#value ⇒ Object (readonly)
- String
-
the start of the word literal array
9922 9923 9924 |
# File 'lib/syntax_tree/node.rb', line 9922 def value @value end |
Instance Method Details
#accept(visitor) ⇒ Object
9929 9930 9931 |
# File 'lib/syntax_tree/node.rb', line 9929 def accept(visitor) visitor.visit_words_beg(self) end |
#child_nodes ⇒ Object Also known as: deconstruct
9933 9934 9935 |
# File 'lib/syntax_tree/node.rb', line 9933 def child_nodes [] end |
#deconstruct_keys(_keys) ⇒ Object
9939 9940 9941 |
# File 'lib/syntax_tree/node.rb', line 9939 def deconstruct_keys(_keys) { value: value, location: location } end |