Class: SyntaxTree::WordsBeg

Inherits:
Node
  • Object
show all
Defined in:
lib/syntax_tree/node.rb

Overview

WordsBeg represents the beginning of a string literal array with interpolation.

%W[one two three]

In the snippet above, a WordsBeg would be created with the value of “%W[”. Note that these kinds of arrays can start with a lot of different delimiter types (e.g., %W| or %W<).

Instance Attribute Summary collapse

Attributes inherited from Node

#location

Instance Method Summary collapse

Methods inherited from Node

#format, #pretty_print, #to_json

Constructor Details

#initialize(value:, location:) ⇒ WordsBeg

Returns a new instance of WordsBeg.



9732
9733
9734
9735
# File 'lib/syntax_tree/node.rb', line 9732

def initialize(value:, location:)
  @value = value
  @location = location
end

Instance Attribute Details

#valueObject (readonly)

String

the start of the word literal array



9730
9731
9732
# File 'lib/syntax_tree/node.rb', line 9730

def value
  @value
end

Instance Method Details

#accept(visitor) ⇒ Object



9737
9738
9739
# File 'lib/syntax_tree/node.rb', line 9737

def accept(visitor)
  visitor.visit_words_beg(self)
end

#child_nodesObject Also known as: deconstruct



9741
9742
9743
# File 'lib/syntax_tree/node.rb', line 9741

def child_nodes
  []
end

#deconstruct_keys(keys) ⇒ Object



9747
9748
9749
# File 'lib/syntax_tree/node.rb', line 9747

def deconstruct_keys(keys)
  { value: value, location: location }
end