Class: SyntaxTree::YARV::Defined
- Inherits:
-
Object
- Object
- SyntaxTree::YARV::Defined
- Defined in:
- lib/syntax_tree/yarv/instructions.rb
Overview
### Summary
defined checks if the top value of the stack is defined. If it is, it pushes its value onto the stack. Otherwise it pushes nil.
### Usage
~~~ruby defined?(x) ~~~
Constant Summary collapse
- TYPE_NIL =
1- TYPE_IVAR =
2- TYPE_LVAR =
3- TYPE_GVAR =
4- TYPE_CVAR =
5- TYPE_CONST =
6- TYPE_METHOD =
7- TYPE_YIELD =
8- TYPE_ZSUPER =
9- TYPE_SELF =
10- TYPE_TRUE =
11- TYPE_FALSE =
12- TYPE_ASGN =
13- TYPE_EXPR =
14- TYPE_REF =
15- TYPE_FUNC =
16- TYPE_CONST_FROM =
17
Instance Attribute Summary collapse
-
#message ⇒ Object
readonly
Returns the value of attribute message.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
Instance Method Summary collapse
- #call(vm) ⇒ Object
- #canonical ⇒ Object
- #disasm(fmt) ⇒ Object
-
#initialize(type, name, message) ⇒ Defined
constructor
A new instance of Defined.
- #length ⇒ Object
- #pops ⇒ Object
- #pushes ⇒ Object
- #to_a(_iseq) ⇒ Object
Constructor Details
#initialize(type, name, message) ⇒ Defined
847 848 849 850 851 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 847 def initialize(type, name, ) @type = type @name = name @message = end |
Instance Attribute Details
#message ⇒ Object (readonly)
Returns the value of attribute message.
845 846 847 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 845 def @message end |
#name ⇒ Object (readonly)
Returns the value of attribute name.
845 846 847 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 845 def name @name end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
845 846 847 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 845 def type @type end |
Instance Method Details
#call(vm) ⇒ Object
918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 918 def call(vm) object = vm.pop result = case type when TYPE_NIL, TYPE_SELF, TYPE_TRUE, TYPE_FALSE, TYPE_ASGN, TYPE_EXPR when TYPE_IVAR if vm.frame._self.instance_variable_defined?(name) when TYPE_LVAR raise NotImplementedError, "defined TYPE_LVAR" when TYPE_GVAR if global_variables.include?(name) when TYPE_CVAR clazz = vm.frame._self clazz = clazz.singleton_class unless clazz.is_a?(Module) if clazz.class_variable_defined?(name) when TYPE_CONST clazz = vm.frame._self clazz = clazz.singleton_class unless clazz.is_a?(Module) if clazz.const_defined?(name) when TYPE_METHOD raise NotImplementedError, "defined TYPE_METHOD" when TYPE_YIELD raise NotImplementedError, "defined TYPE_YIELD" when TYPE_ZSUPER raise NotImplementedError, "defined TYPE_ZSUPER" when TYPE_REF raise NotImplementedError, "defined TYPE_REF" when TYPE_FUNC if object.respond_to?(name, true) when TYPE_CONST_FROM defined = vm.frame.nesting.any? { |scope| scope.const_defined?(name, true) } if defined end vm.push(result) end |
#canonical ⇒ Object
914 915 916 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 914 def canonical self end |
#disasm(fmt) ⇒ Object
853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 853 def disasm(fmt) type_name = case type when TYPE_NIL "nil" when TYPE_IVAR "ivar" when TYPE_LVAR "lvar" when TYPE_GVAR "gvar" when TYPE_CVAR "cvar" when TYPE_CONST "const" when TYPE_METHOD "method" when TYPE_YIELD "yield" when TYPE_ZSUPER "zsuper" when TYPE_SELF "self" when TYPE_TRUE "true" when TYPE_FALSE "false" when TYPE_ASGN "asgn" when TYPE_EXPR "expr" when TYPE_REF "ref" when TYPE_FUNC "func" when TYPE_CONST_FROM "constant-from" end fmt.instruction( "defined", [type_name, fmt.object(name), fmt.object()] ) end |
#length ⇒ Object
902 903 904 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 902 def length 4 end |
#pops ⇒ Object
906 907 908 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 906 def pops 1 end |
#pushes ⇒ Object
910 911 912 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 910 def pushes 1 end |
#to_a(_iseq) ⇒ Object
898 899 900 |
# File 'lib/syntax_tree/yarv/instructions.rb', line 898 def to_a(_iseq) [:defined, type, name, ] end |